<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author			Raymond Benc
 * @package 		Phpfox
 * @version 		$Id: abstract.class.php 1552 2010-04-20 09:56:44Z Raymond_Benc $
 */
abstract class Foxporter_Abstract implements Foxporter_Interface
{	
	public function __construct()
	{	
	}
	
	public function database()
	{
		return Phpfox::getLib('database');	
	}
	
	public function parseInput()
	{
		return Phpfox::getLib('parse.input');	
	}	
	
	public function getSteps()
	{
		return $this->_aSteps;
	}
	
	public function getDetails()
	{
		return $this->_aDetails;
	}
	
	/**
	 * Adds a user.
	 * Required fields:
	 * - full_name - string(255) - Used as the site wide display name
	 * - email - string(255) - Users unique email
	 * 
	 * Option fields:
	 * - user_name - string(100) - Used to create vanity URL, if not passed we will create one from the "full_name"
	 * - birth_year - int - Users birth year
	 * - birth_month - int - Users birth month
	 * - birth_day - int - Users birth day
	 * - gender - string - Users gender (Must be "male" or "female")
	 * - country - string - Users location (eg. United States, Sweden etc...)
	 * - city - string - Users city (eg. Miami, Stockholm etc...)
	 * - state - string - Users state/province (eg. Florida, Skane etc...)
	 * - joined - int - Time stamp of when the user joined (Must be a UNIX time stamp)
	 *
	 * @param array $aVals Holds an array of all the required/option fields
	 */
	public function addUser($aVals)
	{
		static $aCacheData = null;
		
		if ($aCacheData === null)
		{
			$aRows = $this->database()->select('country_iso, name')
				->from(Phpfox::getT('country'))
				->execute('getRows');
			foreach ($aRows as $aRow)
			{
				$aCacheData['country'][strtolower($aRow['name'])] = $aRow['country_iso'];
			}
			
			$aRows = $this->database()->select('child_id, name')
				->from(Phpfox::getT('country_child'))
				->execute('getRows');
			foreach ($aRows as $aRow)
			{
				$aCacheData['country_child'][strtolower($aRow['name'])] = $aRow['child_id'];
			}			
		}
		
		if (empty($aVals['full_name']) || empty($aVals['email']))
		{
			return false;
		}
		
		$aUser = array(
			'user_group_id' => '2',
			'full_name' => $aVals['full_name'],
			'email' => $aVals['email']
		);
		
		$iEmailCheck = $this->database()->select('COUNT(*)')
			->from(Phpfox::getT('user'))
			->where('email = \'' . $this->database()->escape($aVals['email']) . '\'')
			->execute('getField');
			
		if ($iEmailCheck)
		{
			return false;
		}
		
		if (empty($aVals['password']))
		{
			$sSalt = '';
			for ($i = 0; $i < 3; $i++)
			{
				$sSalt .= chr(rand(33, 91));
			}			
		}		
		
		if (!empty($aVals['birth_year']))
		{
			$aVals['day'] = (int) (empty($aUser['day']) ? date('d') : $aVals['birth_day']);
			$aVals['month'] = (int) (empty($aUser['month']) ? date('m') : $aVals['birth_month']);
			$aVals['year'] = (int) (empty($aUser['year']) ? date('Y') : $aVals['birth_year']);
			if ($aVals['day'] === 0 || $aVals['day'] > 31)
			{
				$aVals['day'] = 1;
			}
			if ($aVals['month'] === 0 || $aVals['month'] > 12)
			{
				$aVals['month'] = 1;
			}
			if ($aVals['year'] < 1900)
			{
				$aVals['year'] = 1982;
			}		
			
			$aUser['birthday'] = Phpfox::getService('user')->buildAge($aVals['day'], $aVals['month'], $aVals['year']);
			$aUser['birthday_search'] = Phpfox::getLib('date')->mktime(0, 0, 0, $aVals['month'], $aVals['day'], $aVals['year']);
		}
		
		if (!empty($aVals['gender']))
		{
			$aUser['gender'] = (strtolower($aVals['gender']) == 'male' ? '1' : '2');	
		}
		
		if (empty($aVals['user_name']))
		{
			$aVals['user_name'] = $aVals['full_name'];	
		}			
		$aUser['user_name'] = Phpfox::getLib('parse.input')->cleanTitle($aVals['user_name']);
		Phpfox::getService('user.validate')->user($aUser['user_name']);
		// $aErrors = Phpfox_Error::get();		
		if (!Phpfox_Error::isPassed())
		{
			Phpfox_Error::reset();
			$aUser['user_name'] = $aUser['user_name'] . '_' . uniqid();
		}		
		
		if (!empty($aVals['country']) && isset($aCacheData['country']) && isset($aCacheData['country'][strtolower($aVals['country'])]))
		{
			$aUser['country_iso'] = $aCacheData['country'][strtolower($aVals['country'])];
		}
		
		$sPassword = '';
		if (empty($aVals['password']))
		{		   	
			for ($i = 1; $i <= 10; $i++)
		   	{
		    	$sPassword .= substr('0123456789aBcDeF/()$#!', rand(0, 21), 1);
			}			
			
			$aUser['password'] = md5(md5($sPassword) . md5($sSalt));
			$aUser['password_salt'] = $sSalt;			
		}
		
		$iId = $this->database()->insert(Phpfox::getT('user'), $aUser);
		
		$aUserField = array(
			'user_id' => $iId
		);
		
		if (!empty($aVals['city']))
		{
			$aUserField['city_location'] = $this->parseInput()->clean($aVals['city']);	
		}

		if (!empty($aVals['state']) && isset($aCacheData['country_child']) && isset($aCacheData['country_child'][strtolower($aVals['state'])]))
		{			
			$aUserField['country_child_id'] = $aCacheData['country_child'][strtolower($aVals['state'])];
		}		
		
		if (!empty($aVals['zip']))
		{
			$aUserField['postal_code'] = $this->parseInput()->clean($aVals['zip']);	
		}		
		
		if (!empty($aVals['birth_year']))
		{
			$aUserField['birthday_range'] = Phpfox::getService('user')->buildAge($aVals['day'], $aVals['month']);
		}
		
		$this->database()->insert(Phpfox::getT('user_field'), $aUserField);
		
		$aExtra = array(
			'user_id' => $iId
		);
		$this->database()->insert(Phpfox::getT('user_activity'), $aExtra);
		$this->database()->insert(Phpfox::getT('user_space'), $aExtra);
		$this->database()->insert(Phpfox::getT('user_count'), $aExtra);
		
		return array(
			'user_id' => $iId,
			'password' => $sPassword,
			'user_name' => $aUser['user_name']
		);
	}
}

?>