<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Bulletin
 * @version 		$Id: add.class.php 1508 2010-03-09 13:57:21Z Miguel_Espinoza $
 */
class Bulletin_Component_Controller_Add extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{
		Phpfox::isUser(true);
		(($sPlugin = Phpfox_Plugin::get('bulletin.component_controller_add__start')) ? eval($sPlugin) : false);
		$bIsEditing = false;
		$bCanEditPersonalData = true;
		
		Phpfox::getUserParam('bulletin.can_add_bulletin', true);
		
		// user is editing a bulletin
		if ($iId = $this->request()->getInt('id'))
		{
			// get the bulletin:
			$aBulletin = Phpfox::getService('bulletin.bulletin')->getBulletin($iId, true);
			
			if (isset($aBulletin['bulletin_id']))
			{			
				// check if user is the owner of the bulletin and can edit the bulletin
				if (Phpfox::getUserId() == $aBulletin['user_id'])
				{
					Phpfox::getUserParam('bulletin.bulletin_edit_own', true);
				}
				else
				{
					Phpfox::getUserParam('bulletin.bulletin_can_edit_others', true);	
				}
				
				$bIsEditing = true;
				if (Phpfox::getUserParam('bulletin.bulletin_can_edit_others') && Phpfox::getUserId() != $aBulletin['user_id'])
				{
					$bCanEditPersonalData = false;
				}				
				
				// assign values to the input fields
				$this->template()->assign(array(
						'aForms' => $aBulletin
					)
				);				
			}
		}
		
		if (Phpfox::isModule('attachment') && Phpfox::getUserParam('attachment.can_attach_on_bulletin') && $bCanEditPersonalData)
		{
			$this->template()->setHeader('<script type="text/javascript">var Attachment = {sCategory: "bulletin", iItemId: "' . (isset($aBulletin['bulletin_id']) ? $aBulletin['bulletin_id'] : '') . '"};</script>');
		}		
		
		// check input fields
		$aValidation = array(
			'title' => array(
				'def' => 'required',
				'title' => Phpfox::getPhrase('bulletin.fill_subject')
			),
			'text' => array(
				'def' => 'required',
				'title' => Phpfox::getPhrase('bulletin.fill_text')
			)
		);		
		
		// do they need to complete a captcha challenge?
		if (Phpfox::isModule('captcha') && Phpfox::getUserParam('bulletin.bulletin_enable_captcha') == true)
		{
			$aValidation['image_verification'] = Phpfox::getPhrase('captcha.complete_captcha_challenge');
		}
		
		$oValid = Phpfox::getLib('validator')->set(array(
				'sFormName' => 'js_form',	
				'aParams' => $aValidation
			)
		);
		
		// Is the user adding a bulletin
		if ($aVals = $this->request()->getArray('val'))
		{
			
			if ($oValid->isValid($aVals))
			{
				$bJustPosted = false;
				// check for flood
				$iFlood = Phpfox::getUserParam('bulletin.bulletin_flood_control');
				
				if ($iFlood != '0' && !$bIsEditing)
				{
					$aFlood = array(
						'action' => 'last_post', // The SPAM action
		 				'params' => array(
		 					'field' => 'time_stamp', // The time stamp field
		 					'table' => Phpfox::getT('bulletin'), // Database table we plan to check
		 					'condition' => 'user_id = ' . Phpfox::getUserId(), // Database WHERE query
		 					'time_stamp' => $iFlood * 60 // Seconds);	
		 				)
		 			);
		 			// actually check if flooding
		 			if (Phpfox::getLib('spam')->check($aFlood))
		 			{
						// Set an error
		 				Phpfox_Error::set(Phpfox::getPhrase('bulletin.bulletin_flood_control', array('x' => $iFlood)));			
		 			}
				}
				
				// if bIsEditing == true means that it already passed the validations.
				if ($bIsEditing)
				{					
					if (Phpfox_Error::isPassed() && ($iId = Phpfox::getService('bulletin.process')->update($aBulletin['bulletin_id'], $aBulletin['user_id'], $aVals)))
					{
						$this->url()->send('bulletin.view', array('id' => $aBulletin['bulletin_id']), Phpfox::getPhrase('bulletin.bulletin_successfully_updated'));
					}
				}
				else
				{
					// Use isPassed() to check if everything is okay and then attempt to add the bulletin.
					if (Phpfox_Error::isPassed() && ($iId = Phpfox::getService('bulletin.process')->add(Phpfox::getUserId(), $aVals)))
					{
						$this->url()->send('bulletin.view', array('id' => $iId), Phpfox::getPhrase('bulletin.bulletin_successfully_added'));
					}
				}
			}			
		}		

		(($sPlugin = Phpfox_Plugin::get('bulletin.component_controller_add__end')) ? eval($sPlugin) : false);
		$this->template()->setTitle(Phpfox::getPhrase('bulletin.bulletins'))
			->setTitle(Phpfox::getPhrase('bulletin.post'))
			->setBreadcrumb(Phpfox::getPhrase('bulletin.bulletins'), $this->url()->makeUrl('bulletin'))
			->setBreadcrumb(Phpfox::getPhrase('bulletin.post'), $this->url()->makeUrl('bulletin.add'))
			->setHeader('cache', array(
					'switch_legend.js' => 'static_script',
					'switch_menu.js' => 'static_script'				
				)			
			)
			->setEditor(array('wysiwyg' => true))
			->assign(array(
					'sCreateJs' => $oValid->createJS(),
					'sGetJsForm' => $oValid->getJsForm()
				)
			);
	}
	
	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('bulletin.component_controller_add_clean')) ? eval($sPlugin) : false);
	}
}

?>