<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Miguel Espinoza
 * @package  		Module_Bulletin
 * @version 		$Id: view.class.php 1722 2010-08-13 14:56:11Z Miguel_Espinoza $
 */
class Bulletin_Component_Controller_View extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{			
		// check if this user group can view bulletins
		Phpfox::getUserParam('bulletin.bulletin_can_view_bulletins',true);
		
		// get this bulletin
		$iBulletin = $this->request()->getInt('id');
		$aBulletin = Phpfox::getService('bulletin.bulletin')->getBulletin($iBulletin);
		
		if (empty($aBulletin))
		{
			return Phpfox_Error::display(Phpfox::getPhrase('bulletin.bulletin_does_not_exist'));
		}		
		
		if ($this->request()->get('approve') && Phpfox::getUserParam('bulletin.can_approve_bulletins'))
		{
			if (Phpfox::getService('bulletin.process')->approve($aBulletin['bulletin_id']))
			{
				$this->url()->send('bulletin.view', array('id' => $aBulletin['bulletin_id']), Phpfox::getPhrase('bulletin.bulletin_has_successfully_been_approved'));
			}
		}

		// check for attachments only if needed.
		$aAttachments = array();
		if ($aBulletin['total_attachment'] > 0)
		{
			list($iCnt, $aAttachments) = Phpfox::getService('attachment')->get(array('AND attachment.item_id = ' . $aBulletin['bulletin_id'] . ' AND attachment.category_id = \'bulletin\' AND is_inline = 0'), 'attachment.attachment_id DESC', '', '', false);
		}		
					
		// ajax check
		// check input fields
		$aValidation = array(			
			'message' => array(
				'def' => 'required',
				'title' => Phpfox::getPhrase('bulletin.fill_text')
			)
		);
		$oValid = Phpfox::getLib('validator')->set(array(
				'sFormName' => 'js_form',				
				'aParams' => $aValidation
			)
		);
		
		// check if the setting to be public is on
		if (!Phpfox::getParam('bulletin.is_bulletin_public')  && !Phpfox::isAdmin())
		{
			// Check if they are friends
			if (Phpfox::getUserId() != $aBulletin['user_id'] && (!Phpfox::getService('friend.friend')->isFriend($aBulletin['user_id'], Phpfox::getUserId())))
			{	
				// they are, so lets show them the bulletin			
				return Phpfox_Error::display(Phpfox::getPhrase('bulletin.friends_only_bulletin'));
			}			
		}
		
		// Check if user is sending a message
		if ($aMessage = $this->request()->getArray('val'))
		{
			// flood control check
			$iReplyFloodControl = (int) Phpfox::getParam('bulletin.bulletin_reply_flood_control');
			
			if ($iReplyFloodControl > 0)
			{// is the reply flood restriction enabled?
				
				$aCheck = array(
					'action' => 'last_post',
					'params' => array(
						'field' => 'time_stamp',
						'table' => Phpfox::getT('mail'),
						'condition' => 'owner_user_id = ' . Phpfox::getUserId(),
						'time_stamp' => $iReplyFloodControl * 60
					)
				);

				//they cant post just yet
				if (Phpfox::getLib('spam')->check($aCheck))
				{ 
					Phpfox_Error::set(Phpfox::getPhrase('bulletin.you_can_t_post_just_yet'));						
				}				
			} // if it wasnt then the default value should be true
			
			// check if sending a message to self
			if (Phpfox::getUserId() == $aBulletin['user_id']) 
			{
				Phpfox_Error::set(Phpfox::getPhrase('bulletin.you_cannot_message_yourself'));
			}			
			
			if (Phpfox_Error::isPassed())
			{
				// check the input validation
				if ($oValid->isValid($aMessage))
				{
					// send the message
					$aVals = array(
						'to' => $aBulletin['user_id'],
						'message' => Phpfox::getLib('parse.input')->clean($aMessage['message']) . '[quote=' . $aBulletin['user_id'] . ']' . Phpfox::getLib('parse.output')->parse($aBulletin['text']) . '[/quote]',
						'subject' => Phpfox::getPhrase('bulletin.reply_to_bulletin') . ': ' . Phpfox::getLib('parse.output')->clean($aBulletin['title'])
					);
					
					if ($aIds = Phpfox::getService('mail.process')->add($aVals))
					{
						$this->url()->send('current', null, Phpfox::getPhrase('bulletin.message_successfully_sent'));
					}					
				}
			}
		}
		
		if (Phpfox::isModule('notification') && $aBulletin['user_id'] == Phpfox::getUserId())
		{
			Phpfox::getService('notification.process')->delete('bulletin_notifyLike', $aBulletin['bulletin_id'], Phpfox::getUserId());
		}		
		
		if ($aBulletin['view_id'] == '1' && Phpfox::getUserId() != $aBulletin['user_id'])
		{
			if (!Phpfox::getUserParam('bulletin.can_approve_bulletins'))
			{
				return Phpfox_Error::display(Phpfox::getPhrase('bulletin.bulletin_does_not_exist'));
			}
		}
		
		$this->template()->setTitle(Phpfox::getPhrase('bulletin.bulletins'))
			->setTitle($aBulletin['title'])
			->setBreadcrumb(Phpfox::getPhrase('bulletin.bulletins'), $this->url()->makeUrl('bulletin'))
			->setBreadcrumb($aBulletin['title'], $this->url()->makeUrl('bulletin.view', array('id' => $iBulletin)), true)
			->setEditor()
			->setHeader('cache', array(
					'jquery/plugin/jquery.highlightFade.js' => 'static_script',
					'jquery/plugin/jquery.scrollTo.js' => 'static_script',
					'quick_edit.js' => 'static_script',
					'comment.css' => 'style_css',
					'pager.css' => 'style_css'
				)
			)
			->assign(array(
					'sCreateJs' => $oValid->createJS(),
					'sGetJsForm' => $oValid->getJsForm(),
					'aAttachments' => $aAttachments,
					'aBulletin' => $aBulletin
				)
			);
	}
	
	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('bulletin.component_controller_view_clean')) ? eval($sPlugin) : false);
	}
}

?>