<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Event
 * @version 		$Id: index.class.php 2007 2010-10-29 15:23:36Z Miguel_Espinoza $
 */
class Event_Component_Controller_Index extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{
		Phpfox::getUserParam('event.can_access_event', true);
		
		if (($iRedirectId = $this->request()->getInt('redirect')) 
			&& ($aEvent = Phpfox::getService('event')->getEvent($iRedirectId, true)) 
			&& $aEvent['module_id'] != 'event'
			&& Phpfox::hasCallback($aEvent['module_id'], 'getEventRedirect')
		)
		{
			if (($sForward = Phpfox::callback($aEvent['module_id'] . '.getEventRedirect', $aEvent['event_id'])))
			{	
				Phpfox::getService('notification.process')->delete('event_invite', $aEvent['event_id'], Phpfox::getUserId());
				
				$this->url()->forward($sForward);
			}
		}			
		
		if (($iDeleteId = $this->request()->getInt('delete')))
		{
			if (Phpfox::getService('event.process')->delete($iDeleteId))
			{
				$this->url()->send('event', null, Phpfox::getPhrase('event.event_successfully_deleted'));
			}
		}
		
		if (($iRedirectId = $this->request()->getInt('redirect')) && ($aEvent = Phpfox::getService('event')->getEvent($iRedirectId, true)))
		{
			Phpfox::getService('notification.process')->delete('event_invite', $aEvent['event_id'], Phpfox::getUserId());
			
			$this->url()->send('event', array('view', $aEvent['title_url']));	
		}
		
		$oServiceEventBrowse = Phpfox::getService('event.browse');
		$oDatabase = Phpfox::getLib('database');
		$oParseInput = Phpfox::getLib('parse.input');
		$iPage = $this->request()->get('page');
		$iPageSize = 25;
		$sCategory = null;
		$iTimeDisplay = Phpfox::getLib('date')->mktime(0, 0, 0, Phpfox::getTime('m'), Phpfox::getTime('d'), Phpfox::getTime('Y'));
		$aCacheCategories = array();
		$iRequestCount = 0;
		$sView = $this->request()->get('view', false);
		$aCallback = $this->getParam('aCallback', false);	
		$sCategoryUrl = '';			
		
		$aRequests = $this->request()->getRequests();			
		foreach ($aRequests as $sKey => $sValue)
		{			
			if (!preg_match("/req[0-9]/", $sKey))
			{
				continue;
			}
			
			$iRequestCount++;
			
			$aCacheCategories[] = $sValue;
			
			$this->url()->setParam($sKey, $sValue);
			
			if ($aCallback !== false)
			{
				if ($iRequestCount > $aCallback['category_request'])
				{
					$sCategory = $sValue;
					$sCategoryUrl .= '.' . $sValue;
				}
			}
			else 
			{
				if ($sKey != 'req1')
				{
					$sCategory = $sValue;
					$sCategoryUrl .= '.' . $sValue;
				}
			}
		}		
		
		$this->setParam('sCategory', $sCategory);
		
		$aPages = array(12, 15, 18, 21);
		$aDisplays = array();
		foreach ($aPages as $iPageCnt)
		{
			$aDisplays[$iPageCnt] = Phpfox::getPhrase('core.per_page', array('total' => $iPageCnt));
		}		
	
		$aFilters = array(
			'display' => array(
				'type' => 'select',
				'options' => $aDisplays,
				'default' => '12'
			),
			'country' => array(
				'type' => 'select',
				'options' => Phpfox::getService('core.country')->get(),
				'search' => 'AND m.country_iso = \'[VALUE]\'',
				'style' => 'width:90%;',
				'id' => 'country_iso',
				'add_any' => true
			),
			'country_child_id' => array(
				'type' => 'select',
				'search' => 'AND m.country_child_id = \'[VALUE]\'',
				'clone' => true
			),
			'sort' => array(
				'type' => 'select',
				'options' => array(
					'time_stamp' => Phpfox::getPhrase('event.date_added'),
					'title' => Phpfox::getPhrase('event.name')
				),
				'default' => 'time_stamp',
				'alias' => 'm'
			),
			'sort_by' => array(
				'type' => 'select',
				'options' => array(
					'DESC' => Phpfox::getPhrase('core.descending'),
					'ASC' => Phpfox::getPhrase('core.ascending')
				),
				'default' => 'DESC'
			),
			'keyword' => array(
				'type' => 'input:text',
				'size' => 20,
				'search' => 'AND m.title LIKE \'%[VALUE]%\''
			),
			'city' => array(
				'type' => 'input:text',
				'size' => 20,
				'search' => 'AND m.city LIKE \'%[VALUE]%\''
			),
			'zip' => array(
				'type' => 'input:text',
				'size' => 10,
				'search' => 'AND m.postal_code = \'[VALUE]\''
			)			
		);
		
		$oFilter = Phpfox::getLib('search')
			->set(array(
				'type' => 'browse',
				'filters' => $aFilters,
				'search' => 'keyword',
				'prepare' => false
			)
		);			
	
		$bPrivate = true;
		if ($sView)
		{
			Phpfox::isUser(true);
			
			switch ($sView)
			{
				case 'my':					
					$oFilter->setCondition('AND m.user_id = \'' . Phpfox::getUserId() . '\'');
					$bPrivate = false;
					break;
				case 'attending':					
					$oServiceEventBrowse->attending(1);
					$bPrivate = false;
					break;
				case 'maybe':
					$oServiceEventBrowse->attending(2);
					$bPrivate = false;
					break;
				case 'not-attending':
					$oServiceEventBrowse->attending(3);
					$bPrivate = false;
					break;
				case 'invitation':
					$oServiceEventBrowse->attending(0);
					$bPrivate = false;
					break;
				case 'pending':
					if (Phpfox::getUserParam('event.can_approve_events'))
					{
						$oFilter->setCondition('AND m.view_id = 1');
					}
					break;
				default:
					
					break;
			}
		}
		else 
		{
			if ($iUserId = $this->request()->getInt('user'))
			{
				$oFilter->setCondition('AND m.user_id = ' . (int) $iUserId);
			}
		}
		
		$oFilter->setCondition((($sView != 'my' && !Phpfox::getUserParam('event.can_approve_events')) ? 'AND m.view_id = 0 ' : '') . ($bPrivate ? 'AND m.privacy ' . (Phpfox::getUserParam('event.can_view_pirvate_events') ? 'IN(0,1)' : '= 0') . '' : '') . ' AND m.module_id = \'' . ($aCallback !== false ? $aCallback['module'] : 'event') . '\' AND m.item_id = ' . ($aCallback !== false ? (int) $aCallback['item'] : 0));
		if ($sView && $sView == 'past')
		{
			$oFilter->setCondition('AND m.start_time < \'' . $iTimeDisplay . '\'');
		}
		else 
		{
			switch ($sView)
			{
				case 'invitation':
				
					break;
				case 'this-weekend':
					$oFilter->setCondition('AND m.start_time >= \'' . Phpfox::getLib('date')->getSaturday() . '\' AND m.start_time <= \'' . Phpfox::getLib('date')->getSunday() . '\'');
					break;
				case 'this-week':
					$oFilter->setCondition('AND m.start_time >= \'' . $iTimeDisplay . '\' AND m.start_time <= \'' . Phpfox::getLib('date')->getSunday() . '\'');
					break;
				case 'tomorrow':
					$oFilter->setCondition('AND m.start_time >= \'' . Phpfox::getLib('date')->mktime(0, 0, 0, Phpfox::getTime('m'), (Phpfox::getTime('d') + 1), Phpfox::getTime('Y')) . '\' AND m.start_time <= \'' . Phpfox::getLib('date')->mktime(23, 59, 59, Phpfox::getTime('m'), (Phpfox::getTime('d') + 2), Phpfox::getTime('Y')) . '\'');
					break;
				case 'today':
					$oFilter->setCondition('AND m.start_time >= \'' . Phpfox::getLib('date')->convertToGmt($iTimeDisplay) . '\' AND m.start_time <= \'' . Phpfox::getLib('date')->convertToGmt(Phpfox::getLib('date')->mktime(23, 59, 59, Phpfox::getTime('m'), Phpfox::getTime('d'), Phpfox::getTime('Y'))) . '\'');
					break;					
				default:
					$oFilter->setCondition('AND m.start_time >= \'' . $iTimeDisplay . '\'');	
					break;
			}			
		}		

		if ($this->request()->getInt('sponsor') == 1)
		{
		    $oFilter->setCondition('AND m.is_sponsor != 1');
		    Phpfox::addMessage(Phpfox::getPhrase('event.sponsor_help'));
		}
		$oServiceEventBrowse->condition($oFilter->getConditions())
			->callback($aCallback)
			->category($sCategory)
			->order(($this->request()->get('view') == 'past' ? 'm.time_stamp DESC ' :  $oFilter->getSort()))
			->page($iPage)
			->size($oFilter->getDisplay())
			->execute();		
			
		Phpfox::getLib('pager')->set(array('page' => $iPage, 'size' => $oFilter->getDisplay(), 'count' => $oFilter->getSearchTotal($oServiceEventBrowse->getCount())));		
		
		$iFilterCount = 0;
		$aFilterMenuCache = array();
		if (!defined('PHPFOX_IS_USER_PROFILE'))
		{
			$aFilterMenu = array(
				Phpfox::getPhrase('event.recent_events') => '',
				Phpfox::getPhrase('event.today') => 'today',
				Phpfox::getPhrase('event.tomorrow') => 'tomorrow',
				Phpfox::getPhrase('event.this_week') => 'this-week',
				Phpfox::getPhrase('event.this_weekend') => 'this-weekend'
			);		
			
			if (Phpfox::getUserParam('event.can_approve_events') && $aCallback === false)
			{
				$aFilterMenu[Phpfox::getPhrase('event.pending')] = 'pending';
			}					
			
			foreach ($aFilterMenu as $sMenuName => $sMenuLink)
			{
				$iFilterCount++;
				$aFilterMenuCache[] = array(
					'name' => $sMenuName,
					'link' => $this->url()->makeUrl(($aCallback !== false ? $aCallback['url_home'][0] . '.' . implode('.', array_merge($aCallback['url_home'][1], array('event'))) : 'event' ) . (empty($sCategoryUrl) ? '' : $sCategoryUrl), array('view' => $sMenuLink)),
					'active' => ($sView == $sMenuLink ? true : false),
					'last' => (count($aFilterMenu) === $iFilterCount ? true : false)
				);	
				
				if ($sView == $sMenuLink)
				{
					$this->template()->setTitle($sMenuName)->setBreadcrumb($sMenuName, null, true);
				}
			}	
			
			if (empty($sView))
			{				
				$this->template()->setTitle(Phpfox::getPhrase('event.recent_events'))->setBreadcrumb(Phpfox::getPhrase('event.recent_events'), null, true);
			}
		}
		
		$this->template()->setTitle(Phpfox::getPhrase('event.events'))->setBreadcrumb(Phpfox::getPhrase('event.events'), ($aCallback !== false ? $this->url()->makeUrl($aCallback['url_home'][0], array_merge($aCallback['url_home'][1], array('event'))) : $this->url()->makeUrl('event')))
			->setHeader('cache', array(
					'pager.css' => 'style_css',
					'country.js' => 'module_core'
				)
			)
			->assign(array(
					'aEvents' => $oServiceEventBrowse->get(),
					'sView' => $sView,
					'aCallback' => $aCallback,
					'sCategoryUrl' => $sCategoryUrl,
					'sParentLink' => ($aCallback !== false ? $aCallback['url_home'][0] . '.' . implode('.', $aCallback['url_home'][1]) . '.event' : 'event'),
					'aFilterMenus' => $aFilterMenuCache,
					'iEventApproveCnt' => (Phpfox::getUserParam('event.can_approve_events') ? Phpfox::getService('event')->getPendingTotal() : 0),
					'sApproveLink' => $this->url()->makeUrl('event', array('view' => 'pending'))
				)
			);
			
		if ($sCategory !== null)
		{
			$aCategories = Phpfox::getService('event.category')->getParentBreadcrumb($sCategory);			
			$iCnt = 0;
			foreach ($aCategories as $aCategory)
			{
				$iCnt++;
				
				$this->template()->setTitle($aCategory[0]);
				
				if ($aCallback !== false)
				{
					$sHomeUrl = '/' . Phpfox::getLib('url')->doRewrite($aCallback['url_home'][0]) . '/' . implode('/', $aCallback['url_home'][1]) . '/' . Phpfox::getLib('url')->doRewrite('event') . '/';	
					$aCategory[1] = preg_replace('/^http:\/\/(.*?)\/' . Phpfox::getLib('url')->doRewrite('event') . '\/(.*?)$/i', 'http://\\1' . $sHomeUrl . '\\2', $aCategory[1]);						
				}
				
				$this->template()->setBreadcrumb($aCategory[0], $aCategory[1], ($iCnt === count($aCategories) ? true : false));
			}			
		}
		
		if ($aCallback !== false)
		{
			$this->template()->rebuildMenu('event.index', $aCallback['url_home']);			
		}
	}
	
	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('event.component_controller_index_clean')) ? eval($sPlugin) : false);
	}
}

?>