<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package 		Phpfox_Service
 * @version 		$Id: browse.class.php 2006 2010-10-29 14:07:18Z Raymond_Benc $
 */
class Event_Service_Browse extends Phpfox_Service 
{
	private $_aConditions = array();
	
	private $_iCnt = 0;
	
	private $_iPage = 0;
	
	private $_iPageSize = 25;
	
	private $_sOrder = 'm.is_featured DESC, m.start_time ASC';
	
	private $_aListings = array();
	
	private $_sCategory = null;
	
	private $_iAttending = null;
	
	private $_aCallback = false;
	
	private $_bFull = false;
	
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('event');
	}
	
	public function condition($aConditions)
	{
		$this->_aConditions = $aConditions;
		
		return $this;
	}
	
	public function page($iPage)
	{
		$this->_iPage = $iPage;
		
		return $this;
	}
	
	public function size($iPageSize)
	{
		$this->_iPageSize = $iPageSize;
		
		return $this;
	}
	
	public function order($sOrder)
	{
		if ($sOrder != 'm.time_stamp DESC')
		{		
			$this->_sOrder = $sOrder;
		}
		
		return $this;
	}	
	
	public function category($sCategory)
	{
		$this->_sCategory = $sCategory;
		
		return $this;
	}
	
	public function attending($iAttending)
	{
		$this->_iAttending = $iAttending;
		
		return $this;
	}
	
	public function callback($aCallback)
	{
		$this->_aCallback = $aCallback;
		
		return $this;
	}
	
	public function full($bFull)
	{
		$this->_bFull = $bFull;
		
		return $this;
	}
	
	public function execute()
	{
		if ($this->_sCategory !== null)
		{
			$sCategories = Phpfox::getService('event.category')->getAllCategories($this->_sCategory);
		
			$this->database()->innerJoin(Phpfox::getT('event_category_data'), 'mcd', 'mcd.event_id = m.event_id');
			
			$this->_aConditions[] = ' AND mcd.category_id IN(' . $sCategories . ')';
		}
		
		if ($this->_iAttending !== null)
		{
			$this->database()->join(Phpfox::getT('event_invite'), 'ei', 'ei.event_id = m.event_id AND ei.rsvp_id = ' . (int) $this->_iAttending . ' AND ei.invited_user_id = ' . Phpfox::getUserId());
		}

		$this->_iCnt = $this->database()->select(($this->_sCategory !== null ? 'COUNT(DISTINCT m.event_id)' : 'COUNT(*)'))
			->from($this->_sTable, 'm')
			->where($this->_aConditions)
			->execute('getSlaveField');
			
		if ($this->_iCnt)
		{
			if ($this->_sCategory !== null)
			{			
				$this->database()->innerJoin(Phpfox::getT('event_category_data'), 'mcd', 'mcd.event_id = m.event_id')->group('m.event_id');
			}
			
			if ($this->_iAttending !== null)
			{
				$this->database()->select('ei.rsvp_id, ')->join(Phpfox::getT('event_invite'), 'ei', 'ei.event_id = m.event_id AND ei.rsvp_id = ' . (int) $this->_iAttending . ' AND ei.invited_user_id = ' . Phpfox::getUserId());
			}	
			
			if ($this->_bFull === true)
			{
				$this->database()->select('' . (Phpfox::getParam('core.allow_html') ? 'et.description_parsed' : 'et.description') . ' AS description, ')->leftJoin(Phpfox::getT('event_text'), 'et', 'et.event_id = m.event_id');
			}
			
			$aListings = $this->database()->select('m.*, ' . Phpfox::getUserField())
				->from($this->_sTable, 'm')
				->join(Phpfox::getT('user'), 'u', 'u.user_id = m.user_id')
				->where($this->_aConditions)
				->order($this->_sOrder)
				->limit($this->_iPage, $this->_iPageSize, $this->_iCnt)
				->execute('getSlaveRows');
				
			if ($this->_bFull === true)
			{
				$this->_aListings = $aListings;
				
				return;
			}
				
			foreach ($aListings as $aListing)
			{
				$aEvent['start_time'] = Phpfox::getLib('date')->convertFromGmt($aListing['start_time'], $aListing['start_gmt_offset']);
				
				$iDate = Phpfox::getTime('dmy', $aListing['start_time']);		
				
				if ($iDate == Phpfox::getTime('dmy', PHPFOX_TIME))
				{
					$iDate = Phpfox::getPhrase('event.today');
				}
				elseif ($iDate == Phpfox::getTime('dmy', (PHPFOX_TIME + 86400)))
				{
					$iDate = Phpfox::getPhrase('event.tomorrow');
				}
				else 
				{
					 $iDate = Phpfox::getTime(Phpfox::getParam('event.event_browse_time_stamp'), $aListing['start_time']);
				}
				
				$aListing['start_time_int'] = Phpfox::getTime(Phpfox::getParam('event.event_browse_time_stamp'), $aListing['start_time']);
				$aListing['start_time_phrase'] = Phpfox::getTime(Phpfox::getParam('event.event_browse_time_stamp'), $aListing['start_time']);
				$aListing['location_phrase'] = Phpfox::getLib('parse.output')->clean($aListing['location']);
				$aListing['user_name_link'] = '<a href="' . Phpfox::getLib('url')->makeUrl($aListing['user_name']) . '">' . Phpfox::getLib('parse.output')->clean($aListing['full_name']) . '</a>';
				$aListing['time_stamp_phrase'] = Phpfox::getTime(Phpfox::getParam('event.event_browse_time_stamp'), $aListing['time_stamp']);				
				
				$aListing['breadcrumb'] = Phpfox::getService('event.category')->getCategoriesById($aListing['event_id']);
				
				if ($this->_aCallback !== false)
				{
					$sHomeUrl = '/' . Phpfox::getLib('url')->doRewrite($this->_aCallback['url_home'][0]) . '/' . implode('/', $this->_aCallback['url_home'][1]) . '/' . Phpfox::getLib('url')->doRewrite('event') . '/';			
					
					foreach ($aListing['breadcrumb'] as $iKey => $aCategory)
					{				
						$aListing['breadcrumb'][$iKey][1] = preg_replace('/^http:\/\/(.*?)\/' . Phpfox::getLib('url')->doRewrite('event') . '\/(.*?)$/i', 'http://\\1' . $sHomeUrl . '\\2', $aCategory[1]);						
					}		
				}
				
				$aListing['url'] = ($this->_aCallback !== false ? Phpfox::getLib('url')->makeUrl($this->_aCallback['url'][0], array_merge($this->_aCallback['url'][1], array($aListing['title_url']))) : Phpfox::getLib('url')->makeUrl('event.view', $aListing['title_url']));
				
				$this->_aListings[$iDate][] = $aListing;
			}
		}		
	}	
		
	public function get()
	{
		return $this->_aListings;
	}

	public function getCount()
	{
		return $this->_iCnt;
	}	
	
	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('event.service_browse__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}	
}

?>