<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Event
 * @version 		$Id: callback.class.php 2044 2010-11-02 16:10:30Z Raymond_Benc $
 */
class Event_Service_Callback extends Phpfox_Service 
{
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('event');
	}
	
	public function getAjaxCommentVar()
	{
		return 'event.can_post_comment_on_event';
	}	
	
	public function getCommentItem($iId)
	{
		$aEvent = $this->database()->select('event_id AS comment_item_id, user_id AS comment_user_id')
			->from($this->_sTable)
			->where('event_id = ' . (int) $iId)
			->execute('getSlaveRow');
		
		$aEvent['comment_view_id'] = 1;
			
		return $aEvent;
	}	
	
	public function addComment($aVals, $iUserId = null, $sUserName = null)
	{
		$aEvent = $this->database()->select('m.event_id, m.item_id, m.title, m.privacy, m.title_url, u.full_name, u.user_id, u.user_name')
			->from($this->_sTable, 'm')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = m.user_id')
			->where('m.event_id = ' . (int) $aVals['item_id'])
			->execute('getSlaveRow');
			
		if (!isset($aEvent['event_id']))
		{
			return Phpfox_Error::trigger('Invalid callback on event.');
		}
		
		if (isset($aVals['parent_group_id']))
		{
			if (Phpfox::getService('group')->checkAccess($aVals['parent_group_id'], 'can_use_event') > 1 && !defined('PHPFOX_SKIP_FEED_ENTRY'))
			{
				define('PHPFOX_SKIP_FEED_ENTRY', true);
			}			
		}		
		if ($aEvent['privacy'] == 1)
		{
			define('PHPFOX_SKIP_FEED_ENTRY', true);
		}
		if (!defined('PHPFOX_SKIP_FEED_ENTRY'))
		{		
			(Phpfox::isModule('feed') ? Phpfox::getService('feed.process')->add('comment_event', $aVals['item_id'], serialize(array('content' => $aVals['text_parsed'], 'title' => $aEvent['title'])), $iUserId, $aEvent['user_id'], $aVals['comment_id']) : null);
		}
		
		if ($aEvent['item_id'])
		{
			$aGroup = $this->database()->select('title_url')
				->from(Phpfox::getT('group'))
				->where('group_id = ' . (int) $aEvent['item_id'])
				->execute('getRow');		
			$sLink = Phpfox::getLib('url')->makeUrl('group.' . $aGroup['title_url'] . '.event.view' , array($aEvent['title_url']));
		}
		else 
		{		
			$sLink = Phpfox::getLib('url')->makeUrl('event.view', $aEvent['title_url']);
		}
		
		Phpfox::getLib('mail')
			->to($aEvent['user_id'])
			->subject(array('event.user_name_left_you_a_comment_on_site_title', array('user_name' => $sUserName, 'site_title' => Phpfox::getParam('core.site_title'))))
			->message(array('event.user_name_left_you_a_comment_on_your_event_title', array('user_name' => $sUserName, 'title' => $aEvent['title'], 'link' => $sLink)))
			->fromName(Phpfox::getUserBy('full_name'))
			->notification('comment.add_new_comment')
			->send();
				
		$this->database()->updateCounter('event', 'total_comment', 'event_id', $aEvent['event_id']);
	}

	/**
	 * Enables a sponsor after being paid for or admin approved
	 * @param <type> $iId
	 * @param <type> $sSection
	 */
	public function enableSponsor($aParams)
	{
	    return Phpfox::getService('event.process')->sponsor((int)$aParams['item_id'], 1);	    
	}
	
	public function updateCommentText($aVals, $sText)
	{
		$aEvent = $this->database()->select('m.event_id, m.title, m.title_url, u.full_name, u.user_id, u.user_name')
			->from($this->_sTable, 'm')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = m.user_id')
			->where('m.event_id = ' . (int) $aVals['item_id'])
			->execute('getSlaveRow');
	
		(Phpfox::isModule('feed') ? Phpfox::getService('feed.process')->update('comment_event', $aVals['item_id'], serialize(array('content' => $sText, 'title' => $aEvent['title'])), $aVals['comment_id']) : null);
	}	
	
	public function getItemName($iId, $sName)
	{
		return '<a href="' . Phpfox::getLib('url')->makeUrl('comment.view', array('id' => $iId)) . '">On ' . $sName . '\'s event.</a>';
	}	

	public function getLink($aParams)
	{
	    // get the owner of this song
	    $aEvent = $this->database()->select('e.title_url')
		    ->from(Phpfox::getT('event'),'e')
		    ->where('e.event_id = ' . (int)$aParams['item_id'])
		    ->execute('getSlaveRow');
	    if (empty($aEvent))
	    {
		return false;
	    }
	    return Phpfox::getLib('url')->makeUrl('event.view.' . $aEvent['title_url'] );
	}

	public function getCommentNewsFeed($aRow)
	{		
		$oUrl = Phpfox::getLib('url');
		$oParseOutput = Phpfox::getLib('parse.output');		
		
		if (!Phpfox::getLib('parse.format')->isSerialized($aRow['content']))
		{
			return false;
		}
		
		$aParts = unserialize($aRow['content']);	
		$aRow['text'] = Phpfox::getPhrase('event.a_href_user_link_user_name_a_added_a_comment_on_the_event_a_href_title_link_title_a', array(
				'user_name' => $aRow['owner_full_name'],
				'user_link' => $oUrl->makeUrl('feed.user', array('id' => $aRow['user_id'])),	
				'title_link' => $aRow['link'],		
				'title' => Phpfox::getService('feed')->shortenTitle($aParts['title'])
			)
		);
			
		$aRow['text'] .= Phpfox::getService('feed')->quote($aParts['content']);
		
		return $aRow;
	}	
	
	public function getFeedRedirectFeedLike($iId, $iChild)
	{
		return $this->getFeedRedirect($iChild);
	}
	
	public function getFeedRedirect($iId, $iChild = 0)
	{
		$aListing = $this->database()->select('m.event_id, m.title_url, m.module_id, m.item_id')
			->from($this->_sTable, 'm')
			->where('m.event_id = ' . (int) $iId)
			->execute('getSlaveRow');
			
		if (!isset($aListing['event_id']))
		{
			return false;
		}
		
		if ($aListing['module_id'] != 'event')
		{
			return Phpfox::callback($aListing['module_id'] . '.getModuleFeedRedirect', array('event', 'view', $aListing['title_url']), $aListing['item_id']);
		}
			
		if ($iChild > 0)
		{
			return Phpfox::getLib('url')->makeUrl('event.view', array($aListing['title_url'], 'comment' => $iChild, '#comment-view'));
		}		
		return Phpfox::getLib('url')->makeUrl('event.view', array($aListing['title_url']));
	}	
	
	public function deleteComment($iId)
	{
		$this->database()->updateCounter('event', 'total_comment', 'event_id', $iId, true);
	}	
	
	public function getReportRedirect($iId)
	{
		return $this->getFeedRedirect($iId);
	}
	
	public function getNewsFeed($aRow)
	{
		if ($sPlugin = Phpfox_Plugin::get('event.service_callback_getnewsfeed_start')){eval($sPlugin);}
		$oUrl = Phpfox::getLib('url');
		$oParseOutput = Phpfox::getLib('parse.output');		
		
		$aRow['text'] = Phpfox::getPhrase('event.owner_full_name_added_a_new_event_title', array(
				'user_link' => $oUrl->makeUrl('feed.user', array('id' => $aRow['user_id'])),
				'owner_full_name' => $aRow['owner_full_name'],
				'title_link' => $aRow['link'],
				'title' => Phpfox::getService('feed')->shortenTitle($aRow['content'])
			)
		);
		
		$aRow['icon'] = 'module/event.png';
		$aRow['enable_like'] = true;
	
		return $aRow;
	}

	public function groupMenu($sGroupUrl, $iGroupId)
	{
		if (!Phpfox::getService('group')->hasAccess($iGroupId, 'can_use_event'))
		{
			return false;
		}
		
		return array(
				Phpfox::getPhrase('event.events') => array(
					'active' => 'event',
					'url' => Phpfox::getLib('url')->makeUrl('group', array($sGroupUrl, 'event')
				)
			)
		);
	}
	
	public function deleteGroup($iId)
	{
		$aEvents = $this->database()->select('*')
			->from($this->_sTable)
			->where('module_id = \'group\' AND item_id = ' . (int) $iId)
			->execute('getRows');
			
		foreach ($aEvents as $aEvent)
		{
			Phpfox::getService('event.process')->delete($aEvent['event_id'], $aEvent);
		}
		
		return true;
	}
	
	public function getDashboardLinks()
	{
		return array(
			'submit' => array(
				'phrase' => Phpfox::getPhrase('event.create_an_event'),
				'link' => 'event.add',
				'image' => 'misc/calendar_add.png'
			),
			'edit' => array(
				'phrase' => Phpfox::getPhrase('event.manage_events'),
				'link' => 'event.view_my',
				'image' => 'misc/calendar_edit.png'
			)
		);
	}	
	
	public function getBlockDetailsProfile()
	{
		return array(
			'title' => Phpfox::getPhrase('event.events')
		);
	}

	public function hideBlockProfile($sType)
	{
		return array(
			'table' => 'user_design_order'
		);		
	}	
	
	/**
	 * Action to take when user cancelled their account
	 * @param int $iUser
	 */
	public function onDeleteUser($iUser)
	{
		$aEvents = $this->database()
			->select('event_id')
			->from($this->_sTable)
			->where('user_id = ' . (int)$iUser)
			->execute('getSlaveRows');

		foreach ($aEvents as $aEvent)
		{
			Phpfox::getService('event.process')->delete($aEvent['event_id']);
		}
	}
	
	public function getGroupPosting()
	{
		return array(
			Phpfox::getPhrase('event.can_create_event') => 'can_create_event'
		);
	}	
	
	public function getGroupAccess()
	{
		return array(
			Phpfox::getPhrase('event.view_events') => 'can_use_event'
		);
	}

	public function getNotificationFeedApproved($aRow)
	{
		return array(
			'message' => Phpfox::getPhrase('event.your_event_title_has_been_approved', array('title' => Phpfox::getLib('parse.output')->shorten($aRow['item_title'], 20, '...'))),
			'link' => Phpfox::getLib('url')->makeUrl('event', array('redirect' => $aRow['item_id'])),
			'path' => 'event.url_image',
			'suffix' => '_120'
		);		
	}	
	
	public function getProfileSettings()
	{
		return array(
			'event.display_on_profile' => array(
				'phrase' => Phpfox::getPhrase('event.events'),
				'default' => '0'				
			)
		);
	}		
	
	public function pendingApproval()
	{
		return array(
			'phrase' => Phpfox::getPhrase('event.events'),
			'value' => Phpfox::getService('event')->getPendingTotal(),
			'link' => Phpfox::getLib('url')->makeUrl('event', array('view' => 'pending'))
		);
	}	
	
	public function getUserCountFieldInvite()
	{
		return 'event_invite';
	}	
	
	public function getNotificationFeedInvite($aRow)
	{		
		return array(
			'message' => Phpfox::getPhrase('event.full_name_invited_you_to_an_event', array(
				'user_link' => Phpfox::getLib('url')->makeUrl($aRow['user_name']),
				'full_name' => $aRow['full_name']
				)
			),
			'link' => Phpfox::getLib('url')->makeUrl('event', array('redirect' => $aRow['item_id']))
		);
	}		
	
	public function getRequestLink()
	{
		if (!Phpfox::getParam('request.display_request_box_on_empty') && !Phpfox::getUserBy('event_invite'))
		{
			return null;
		}

		return '<li><a href="' . Phpfox::getLib('url')->makeUrl('event', array('view' => 'invitation')) . '"' . (!Phpfox::getUserBy('event_invite') ? ' onclick="alert(\'' . Phpfox::getPhrase('event.no_event_invites') . '\'); return false;"' : '') . '><img src="' . Phpfox::getLib('template')->getStyle('image', 'module/event.png') . '" class="v_middle" /> ' . Phpfox::getPhrase('event.event_invites_total', array('total' => Phpfox::getUserBy('event_invite'))) . '</span></a></li>';
	}

	public function reparserList()
	{
		return array(
			'name' => Phpfox::getPhrase('event.event_text'),
			'table' => 'event_text',
			'original' => 'description',
			'parsed' => 'description_parsed',
			'item_field' => 'event_id'
		);
	}		
	
	public function getSiteStatsForAdmins()
	{
		$iToday = mktime(0, 0, 0, date('m'), date('d'), date('Y'));
		
		return array(
			'phrase' => Phpfox::getPhrase('event.events'),
			'value' => $this->database()->select('COUNT(*)')
				->from(Phpfox::getT('event'))
				->where('view_id = 0 AND time_stamp >= ' . $iToday)
				->execute('getSlaveField')
		);
	}

	/**
	  * @param int $iId video_id
	  * @return array in the format:
	     * array(
	     *	'title' => 'item title',		    <-- required
	     *  'link'  => 'makeUrl()'ed link',		    <-- required
	     *  'paypal_msg' => 'message for paypal'	    <-- required
	     *  'item_id' => int			    <-- required
	     *  'user_id;   => owner's user id		    <-- required
	     *	'error' => 'phrase if item doesnt exit'	    <-- optional
	     *	'extra' => 'description'		    <-- optional
	     *	'image' => 'path to an image',		    <-- optional
	     *	'image_dir' => 'photo.url_photo|...	    <-- optional (required if image)	     
	     * )
	    */
	public function getToSponsorInfo($iId)
	{
	    // check that this user has access to this group
	    $aEvent = $this->database()->select('e.user_id, e.event_id as item_id, e.title, e.title_url, e.privacy, e.tag_line, e.location, e.start_time, e.end_time, e.image_path as image, e.server_id,e.user_id')
		    ->from($this->_sTable, 'e')
		    ->where('e.event_id = ' . (int)$iId)
		    ->execute('getSlaveRow');
		    
	    if (empty($aEvent))
	    {
			return array('error' => Phpfox::getPhrase('event.sponsor_error_not_found'));
	    }
	    
	    if ($aEvent['privacy'] > 0)
	    {
			return array('error' => Phpfox::getPhrase('event.sponsor_error_privacy'));
	    }
	    
	    $aEvent['title'] = Phpfox::getPhrase('event.sponsor_title', array('sEventTitle' => $aEvent['title']));
	    $aEvent['paypal_msg'] = Phpfox::getPhrase('event.sponsor_paypal_message', array('sEventTitle' => $aEvent['title']));
	    $aEvent['link'] = Phpfox::getLib('url')->makeUrl('event.view.'.$aEvent['title_url']);	    
	    $aEvent['extra'] = '<b>'.Phpfox::getPhrase('event.date').'</b> ' . Phpfox::getTime('l, F j, Y g:i a', $aEvent['start_time']) . ' - ';
	    
	    if (date('dmy', $aEvent['start_time']) === date('dmy', $aEvent['end_time']))
	    {
			$aEvent['extra'] .= Phpfox::getTime('g:i a', $aEvent['end_time']);
	    }
	    else
	    {
			$aEvent['extra'] .= Phpfox::getTime('l, F j, Y g:i a', $aEvent['end_time']);
	    }
	    
	    if (isset($aEvent['image']) && $aEvent['image'] != '')
	    {
			$aEvent['image_dir'] = 'event.url_image';
			$aEvent['image'] = sprintf($aEvent['image'],'_200');
	    }
	    
	    return $aEvent;
	}

	public function getNewsFeedFeedLike($aRow)
	{
		if ($aRow['owner_user_id'] == $aRow['viewer_user_id'])
		{
			$aRow['text'] = Phpfox::getPhrase('event.a_href_user_link_full_name_a_liked_their_own_a_href_link_event_a', array(
					'full_name' => Phpfox::getLib('parse.output')->clean($aRow['owner_full_name']),
					'user_link' => Phpfox::getLib('url')->makeUrl($aRow['owner_user_name']),
					'link' => $aRow['link']
				)
			);
		}
		else 
		{
			$aRow['text'] = Phpfox::getPhrase('event.a_href_user_link_full_name_a_liked_a_href_view_user_link_view_full_name_a_s_a_href_link_event_a', array(
					'full_name' => Phpfox::getLib('parse.output')->clean($aRow['owner_full_name']),
					'user_link' => Phpfox::getLib('url')->makeUrl($aRow['owner_user_name']),
					'view_full_name' => Phpfox::getLib('parse.output')->clean($aRow['viewer_full_name']),
					'view_user_link' => Phpfox::getLib('url')->makeUrl($aRow['viewer_user_name']),
					'link' => $aRow['link']			
				)
			);
		}
		
		$aRow['icon'] = 'misc/thumb_up.png';

		return $aRow;				
	}	
	
	public function getNotificationFeedNotifyLike($aRow)
	{		
		return array(
			'message' => Phpfox::getPhrase('event.a_href_user_link_full_name_a_liked_your_a_href_link_event_a', array(
					'full_name' => Phpfox::getLib('parse.output')->clean($aRow['full_name']),
					'user_link' => Phpfox::getLib('url')->makeUrl($aRow['user_name']),
					'link' => Phpfox::getLib('url')->makeUrl('event', array('redirect' => $aRow['item_id']))
				)
			),
			'link' => Phpfox::getLib('url')->makeUrl('event', array('redirect' => $aRow['item_id'])),
			'path' => 'event.url_image',
			'suffix' => '_120'
		);				
	}
	
	public function sendLikeEmail($iItemId)
	{
		return Phpfox::getPhrase('event.a_href_user_link_full_name_a_liked_your_a_href_link_event_a', array(
					'full_name' => Phpfox::getLib('parse.output')->clean(Phpfox::getUserBy('full_name')),
					'user_link' => Phpfox::getLib('url')->makeUrl(Phpfox::getUserBy('user_name')),
					'link' => Phpfox::getLib('url')->makeUrl('event', array('redirect' => $iItemId))
				)
			);
	}

	public function getRedirectComment($iId)
	{
		return $this->getFeedRedirect($iId);
	}	

	public function getSqlTitleField()
	{
		return array(
			'table' => 'event',
			'field' => 'title'
		);
	}		
	
	public function updateCounterList()
	{
		$aList = array();				

		$aList[] =	array(
			'name' => Phpfox::getPhrase('event.event_invite_count'),
			'id' => 'event-invite-count'
		);

		return $aList;
	}		
	
	public function updateCounter($iId, $iPage, $iPageLimit)
	{
		if ($iId == 'event-invite-count')
		{
			$iCnt = $this->database()->select('COUNT(*)')
				->from(Phpfox::getT('user'))
				->execute('getSlaveField');
				
			$aRows = $this->database()->select('u.user_id, COUNT(gi.invite_id) AS total_invites')
				->from(Phpfox::getT('user'), 'u')
				->leftJoin(Phpfox::getT('event_invite'), 'gi', 'gi.invited_user_id = u.user_id')
				->group('u.user_id')
				->limit($iPage, $iPageLimit, $iCnt)
				->execute('getSlaveRows');

			foreach ($aRows as $aRow)
			{
				$this->database()->update(Phpfox::getT('user_count'), array('event_invite' => $aRow['total_invites']), 'user_id = ' . (int) $aRow['user_id']);
			}
				
			return $iCnt;			
		}		
	}	

	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('event.service_callback__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}	
}

?>