<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 *
 *
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Feed
 * @version 		$Id: feed.class.php 2666 2011-06-14 09:33:02Z Miguel_Espinoza $
 */
class Feed_Service_Feed extends Phpfox_Service 
{	
	/**
	 * Class constructor
	 */
	public function __construct()
	{
		$this->_sTable = Phpfox::getT('feed');

		(($sPlugin = Phpfox_Plugin::get('feed.service_feed___construct')) ? eval($sPlugin) : false);
	}

	/*
	 * http://forums.phpfox.com/project.php?issueid=5083
	 * Problem is with the join, we can just fetch a humongous number of feeds and filter with php, they are cached
	 * now at least but this is prone to become a resource hungry feat.
	 */
	public function get($iUserid = null, $iFeedId = null, $iPage = 0)
	{
		$sCacheId = $this->cache()->set('feed_' . $iUserid . '_' . $iPage . '_' . Phpfox::getLib('locale')->getLangId());
		if ((Phpfox::getParam('feed.cache_timeout') > 0) && ($aFeeds = $this->cache()->get($sCacheId, Phpfox::getParam('feed.cache_timeout') * 60))) // cache is in minutes
		{
			return $aFeeds;
		}

		$oUrl = Phpfox::getLib('url');
		$oParseOutput = Phpfox::getLib('parse.output');

		switch(Phpfox::getParam('feed.feed_time_layout'))
		{
			case 'minutes':
				$iTime = (PHPFOX_TIME - (60 * Phpfox::getParam('feed.display_feeds_from')));
				break;
			case 'hours':
				$iTime = (PHPFOX_TIME - (60 * 60 * Phpfox::getParam('feed.display_feeds_from')));
				break;
			case 'months':
				$iTime = (PHPFOX_TIME - (2629743 * Phpfox::getParam('feed.display_feeds_from')));
				break;
			// days
			default:
				$iTime = (PHPFOX_TIME - (60 * 60 * 24 * Phpfox::getParam('feed.display_feeds_from')));
			}
			
			$iTotalFeeds = (int) Phpfox::getComponentSetting(($iUserid === null ? Phpfox::getUserId() : $iUserid), 'feed.feed_display_limit_' . ($iUserid !== null ? 'profile' : 'dashboard'), Phpfox::getParam('feed.feed_display_limit'));			
			
			if ($iUserid === null && Phpfox::getParam('feed.feed_only_friends'))
			{
				$this->database()->join(Phpfox::getT('friend'), 'friend', "friend.user_id = " . Phpfox::getUserId() . " AND friend.friend_user_id = feed.user_id");
			}
			
			$sExtraWhere = 'feed.view_id = 0 AND ';
			if (Phpfox::isModule('comment') && Phpfox::getUserParam('comment.can_moderate_comments'))
			{
				$sExtraWhere = '';	
			}
			if (Phpfox::isMobile())
			{
				$aMobileTypes = array();
				$aMobileTypes[] = 'user_joined';
				$aMobileTypes[] = 'profile_info';
				$aMobileTypes[] = 'user_status';
				$aMobileTypes[] = 'profile_info';
				$aMobileTypes[] = 'comment_profile_my';
				$aMobileTypes[] = 'friend';
				
				(($sPlugin = Phpfox_Plugin::get('feed.service_feed_get_mobile_types')) ? eval($sPlugin) : false);
				
				$sMobileTypes = '';
				foreach ($aMobileTypes as $sMobileType)
				{
					$sMobileTypes .= '\'' . $this->database()->escape($sMobileType) . '\',';
				}
				$sMobileTypes = rtrim($sMobileTypes, ',');
				$sExtraWhere .= 'feed.type_id IN(' . $sMobileTypes . ') AND ';
			}			
			(($sPlugin = Phpfox_Plugin::get('feed.service_feed_get_integrate_comments')) ? eval($sPlugin) : false);
			
			if (Phpfox::getParam('feed.integrate_comments_into_feeds'))
			{
				$this->database()->where($sExtraWhere . ($iFeedId === null ? '' : 'feed.feed_id = ' . (int) $iFeedId . ' AND ') . ($iUserid === null ? "((feed.type_id != 'comment_profile_my') OR (feed.type_id = 'comment_profile_my')) AND feed.is_like = 0" : "(feed.user_id = " . (int) $iUserid . " OR (feed.type_id = 'comment_profile_my' AND feed.item_user_id = " . (int) $iUserid . "))") . "");
			}
			else 
			{
				$this->database()->where($sExtraWhere . ($iFeedId === null ? '' : 'feed.feed_id = ' . (int) $iFeedId . ' AND ') . ($iUserid === null ? "feed.is_like = 0" : "feed.user_id = " . (int) $iUserid) . "");
			}			
			
			$iCnt = $this->database()->select('COUNT(*)')
				->from($this->_sTable, 'feed')
				->execute('getSlaveField');			

			if ($iUserid === null && Phpfox::getParam('feed.feed_only_friends'))
			{
				$this->database()->join(Phpfox::getT('friend'), 'friend', "friend.user_id = " . Phpfox::getUserId() . " AND friend.friend_user_id = feed.user_id");
			}			
			
			if (Phpfox::getParam('feed.integrate_comments_into_feeds'))
			{
				$this->database()->where($sExtraWhere . ($iFeedId === null ? '' : 'feed.feed_id = ' . (int) $iFeedId . ' AND ') . ($iUserid === null ? "((feed.type_id != 'comment_profile_my') OR (feed.type_id = 'comment_profile_my')) AND feed.is_like = 0" : "(feed.user_id = " . (int) $iUserid . " OR (feed.type_id = 'comment_profile_my' AND feed.item_user_id = " . (int) $iUserid . "))") . "");
			}
			else 
			{
				$this->database()->where($sExtraWhere . ($iFeedId === null ? '' : 'feed.feed_id = ' . (int) $iFeedId . ' AND ') . ($iUserid === null ? "feed.is_like = 0" : "feed.user_id = " . (int) $iUserid) . "");
			}
			
			if (Phpfox::isUser())
			{
				$this->database()->select('fr.feed_id AS has_rating, fr.rating AS actual_rating, ')
					->leftJoin(Phpfox::getT('feed_rating'), 'fr', 'fr.feed_id = feed.feed_id AND fr.user_id = ' . (int) Phpfox::getUserId());
			}			
			
			if (Phpfox::isMobile())
			{
				$this->database()->select('COUNT(cmt.comment_id) AS total_comments, ')->leftJoin(Phpfox::getT('comment'), 'cmt', 'cmt.type_id = \'feed\' AND cmt.item_id = feed.feed_id AND cmt.view_id = 0')->group('feed.feed_id');
			}

			$aRows = $this->database()->select('feed.*, fl.feed_id AS is_liked, ' . Phpfox::getUserField('u1', 'owner_') . ', ' . Phpfox::getUserField('u2', 'viewer_'))
				->from($this->_sTable, 'feed')
				->join(Phpfox::getT('user'), 'u1', 'u1.user_id = feed.user_id')
				->leftJoin(Phpfox::getT('user'), 'u2', 'u2.user_id = feed.item_user_id')
				->leftJoin(Phpfox::getT('feed_like'), 'fl', 'fl.feed_id = feed.feed_id AND fl.user_id = ' . Phpfox::getUserId())
				->order('feed.time_stamp DESC')
				->limit($iPage, $iTotalFeeds, $iCnt)
				->execute('getSlaveRows');
							
			$aLikes = array();
			$aLikesCount = array();
			if (count($aRows))
			{
				$sIds = '';
				foreach ($aRows as $aRow)
				{
					$sIds .= $aRow['feed_id'] . ',';
				}
				$sIds = rtrim($sIds, ',');
				
				if (!empty($sIds))
				{
					$aLikeRows = $this->database()->select('fl.feed_id, ' . Phpfox::getUserField())
						->from(Phpfox::getT('feed_like'), 'fl')
						->join(Phpfox::getT('user'), 'u', 'u.user_id = fl.user_id')
						->where('fl.feed_id IN(' . $sIds . ')')
						->execute('getSlaveRows');
					foreach ($aLikeRows as $aLikeRow)
					{
						if (!isset($aLikesCount[$aLikeRow['feed_id']]))
						{
							$aLikesCount[$aLikeRow['feed_id']] = 0;
						}
						
						$aLikesCount[$aLikeRow['feed_id']]++;
						
						if ($aLikesCount[$aLikeRow['feed_id']] > 3)
						{
							continue;
						}
						
						$aLikes[$aLikeRow['feed_id']][] = $aLikeRow;	
					}
					
					unset($aLikeRows, $aLikeRow, $sIds);
				}
			}			
			
			$aFeeds = array();
			foreach ($aRows as $aRow)
			{
				$aRow['link'] = $oUrl->makeUrl('feed.view', array('id' => $aRow['feed_id']));

				$aParts1 = explode('.', $aRow['type_id']);
				$sModule = $aParts1[0];
				if (strpos($sModule, '_'))
				{
					$aParts = explode('_', $sModule);
					$sModule = $aParts[0];
					if ($sModule == 'comment' && isset($aParts[1]) && !Phpfox::isModule($aParts[1]))
					{
					    continue;
					}
				}				
				
				if (!Phpfox::isModule($sModule))
				{
					continue;
				}
				
				if (($aFeed = Phpfox::callback($aRow['type_id'] . '.getNewsFeed', $aRow, $iUserid)))
				{
					if (isset($aLikes[$aFeed['feed_id']]))
					{
						$aFeed['like_rows'] = $aLikes[$aFeed['feed_id']];
					}
					
					if (isset($aLikesCount[$aFeed['feed_id']]))
					{
						$aFeed['like_count'] = ($aLikesCount[$aFeed['feed_id']] - count($aFeed['like_rows']));
					}					
					
					$aFeeds[] = $aFeed;
				}
			}
			if ((Phpfox::getParam('feed.cache_timeout') > 0))
			{
				$this->cache()->save($sCacheId, array($iCnt, $aFeeds));
			} 
			return array($iCnt, $aFeeds);
		}
		
	public function getLikeForFeed($iFeed)
	{
		$aLikeRows = $this->database()->select('fl.feed_id, ' . Phpfox::getUserField())
			->from(Phpfox::getT('feed_like'), 'fl')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = fl.user_id')
			->where('fl.feed_id = ' . (int) $iFeed)
			->execute('getSlaveRows');
						
		$aLikes = array();
		$aLikesCount = array();
		foreach ($aLikeRows as $aLikeRow)
		{
			if (!isset($aLikesCount[$aLikeRow['feed_id']]))
			{
				$aLikesCount[$aLikeRow['feed_id']] = 0;
			}
						
			$aLikesCount[$aLikeRow['feed_id']]++;
						
			if ($aLikesCount[$aLikeRow['feed_id']] > 3)
			{
				continue;
			}
						
			$aLikes[$aLikeRow['feed_id']][] = $aLikeRow;	
		}
					
		return array($aLikesCount, $aLikes);
	}
		
	public function getLikes($iFeed)
	{
		$aLikes = $this->database()->select(Phpfox::getUserField())
			->from(Phpfox::getT('feed_like'), 'fl')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = fl.user_id')
			->where('feed_id = ' . (int) $iFeed)
			->order('u.full_name ASC')
			->execute('getRows');			
					
		return $aLikes;
	}

	/**
	 * We get the redirect URL of the item depending on which module
	 * it belongs to. We use the callback to connect to the correct module.
	 *
	 * @param integer $iId Is the ID# of the feed
	 * @return boolean|string If we are unable to find the correct feed, If we find the correct feed
	 */
	public function getRedirect($iId)
	{
		// Get the feed
		$aFeed = $this->database()->select('feed_id, type_id, item_id, child_item_id')
			->from($this->_sTable)
			->where('feed_id =' . (int) $iId)
			->execute('getSlaveRow');

		// Make sure we found a feed
		if (!isset($aFeed['feed_id']))
		{
			return false;
		}

		// Run the callback so we get the correct link
		return Phpfox::callback($aFeed['type_id'] . '.getFeedRedirect', $aFeed['item_id'], $aFeed['child_item_id']);
	}
	
	public function getFeed($iId)
	{
		return $this->database()->select('*')
			->from($this->_sTable)
			->where('feed_id =' . (int) $iId)
			->execute('getSlaveRow');
	}
	
	public function shortenText($sText)
	{
		$oParseOutput = Phpfox::getLib('parse.output');
		
		return $oParseOutput->split($oParseOutput->shorten($oParseOutput->parse($sText), 300, 'feed.view_more', true), 40);	
	}
	
	public function shortenTitle($sText)
	{
		$oParseOutput = Phpfox::getLib('parse.output');
		
		return $oParseOutput->shorten($oParseOutput->clean($sText), 60, '...');
	}
	
	public function quote($sText)
	{
		Phpfox::getLib('parse.output')->setImageParser(array('width' => 200, 'height' => 200));

		$sNewText = '<div class="p_4">' . $this->shortenText($sText) . '</div>';
		
		Phpfox::getLib('parse.output')->setImageParser(array('clear' => true));
		
		return $sNewText;
	}
	
	public function getForBrowse($aConds, $sSort = 'feed.time_stamp DESC', $iRange = '', $sLimit = '')
	{
		$iCnt = $this->database()->select('COUNT(*)')
			->from($this->_sTable, 'feed')
			->where($aConds)
			->execute('getSlaveField');				
			
			$aRows = $this->database()->select('feed.*, fl.feed_id AS is_liked, ' . Phpfox::getUserField('u1', 'owner_') . ', ' . Phpfox::getUserField('u2', 'viewer_'))
				->from($this->_sTable, 'feed')
				->join(Phpfox::getT('user'), 'u1', 'u1.user_id = feed.user_id')
				->leftJoin(Phpfox::getT('user'), 'u2', 'u2.user_id = feed.item_user_id')
				->leftJoin(Phpfox::getT('feed_like'), 'fl', 'fl.feed_id = feed.feed_id AND fl.user_id = ' . Phpfox::getUserId())
				->where($aConds)
				->order($sSort)
				->limit($iRange, $sLimit, $iCnt)
				->execute('getSlaveRows');			
			
			$aFeeds = array();
			foreach ($aRows as $aRow)
			{
				$aRow['link'] = Phpfox::getLib('url')->makeUrl('feed.view', array('id' => $aRow['feed_id']));

				$aParts1 = explode('.', $aRow['type_id']);
				$sModule = $aParts1[0];
				if (strpos($sModule, '_'))
				{
					$aParts = explode('_', $sModule);
					$sModule = $aParts[0];
					if ($sModule == 'comment' && isset($aParts[1]) && !Phpfox::isModule($aParts[1]))
					{
					    continue;
					}
				}				
				
				if (!Phpfox::isModule($sModule))
				{
					continue;
				}
				
				if (($aFeed = Phpfox::callback($aRow['type_id'] . '.getNewsFeed', $aRow)))
				{
					if (isset($aLikes[$aFeed['feed_id']]))
					{
						$aFeed['like_rows'] = $aLikes[$aFeed['feed_id']];
					}
					
					if (isset($aLikesCount[$aFeed['feed_id']]))
					{
						$aFeed['like_count'] = ($aLikesCount[$aFeed['feed_id']] - count($aFeed['like_rows']));
					}					
					
					$aFeeds[] = $aFeed;
				}
			}
			
		return array($iCnt, $aFeeds);
	}

	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
		{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
			if ($sPlugin = Phpfox_Plugin::get('feed.service_feed__call'))
			{
				return eval($sPlugin);
			}

		/**
		 * No method or plug-in found we must throw a error.
		 */
			Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
		}
}

?>