<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Feed
 * @version 		$Id: process.class.php 2104 2010-11-09 16:04:16Z Miguel_Espinoza $
 */
class Feed_Service_Process extends Phpfox_Service 
{	
	private $_bAllowGuest = false;
	
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('feed');
	}
	
	public function allowGuest()
	{
		$this->_bAllowGuest = true;
		
		return $this;
	}			
	
	public function add($sType, $iItemId, $mContent = null, $iUserId = null, $iItemUserId = null, $iChildId = null, $bIsLike = false)
	{
		//Plugin call
		if ($sPlugin = Phpfox_Plugin::get('feed.service_process_add__start'))
		{
			eval($sPlugin);
		}

		if ( (!Phpfox::isUser() && $this->_bAllowGuest === false) || (defined('PHPFOX_SKIP_FEED') && PHPFOX_SKIP_FEED))
		{
			return false;
		}

		if (Phpfox::getLib('parse.format')->isSerialized($mContent))
		{			
			$aCache = unserialize($mContent);
			if (isset($aCache['content']))
			{
				$aCache['content'] = $this->_clean($aCache['content']);
			}
			
			$mContent = serialize($aCache);
		}
		else 
		{
			$mContent = $this->_clean($mContent);
		}
		
		$aInsert = array(
			'type_id' => $sType,
			'user_id' => ($iUserId === null ? Phpfox::getUserId() : $iUserId),
			'item_id' => $iItemId,
			'time_stamp' => PHPFOX_TIME,
			'is_like' => ($bIsLike ? '1' : '0')
		);

		if ($mContent !== null)
		{
			$aInsert['content'] = $mContent;
		}
		
		if ($iItemUserId !== null)
		{
			$aInsert['item_user_id'] = (int) $iItemUserId;
		}
		
		if ($iChildId !== null)
		{
			$aInsert['child_item_id'] = (int) $iChildId;
		}
		
		//Plugin call
		if ($sPlugin = Phpfox_Plugin::get('feed.service_process_add__end'))
		{
			eval($sPlugin);
		}

		return $this->database()->insert($this->_sTable, $aInsert);
	}
	
	/**
	 * Deletes an entry from the feeds
	 *
	 * @param string $sType module as defined in: type_id
	 * @param integer $iId numeric as defined in item_id
	 */
	public function delete($sType, $iId)
	{		
		$aFeeds = $this->database()->select('feed_id, user_id')
			->from($this->_sTable)
			->where('type_id = \'' . $sType . '\' AND item_id = ' . (int) $iId)
			->execute('getRows');
			
		foreach ($aFeeds as $aFeed)
		{
			$this->database()->delete(Phpfox::getT('feed_rating'), 'feed_id = ' . $aFeed['feed_id']);
			$this->database()->delete(Phpfox::getT('feed_like'), 'feed_id = ' . $aFeed['feed_id']);
			$this->database()->delete(Phpfox::getT('feed'), 'type_id LIKE \'%feedLike\' AND item_id = ' . $aFeed['feed_id']);
			$this->cache()->remove('feed_' . $aFeed['user_id'], 'substr');			
		}
			
		$this->database()->delete(Phpfox::getT('feed'), 'type_id = \'' . $sType . '\' AND item_id = ' . (int) $iId);
	}
	
	public function deleteChild($sType, $iId)
	{
		$aFeeds = $this->database()->select('feed_id')
			->from($this->_sTable)
			->where('type_id = \'' . $sType . '\' AND child_item_id = ' . (int) $iId)
			->execute('getRows');
			
		foreach ($aFeeds as $aFeed)
		{
			$this->database()->delete(Phpfox::getT('feed_rating'), 'feed_id = ' . $aFeed['feed_id']);
			$this->database()->delete(Phpfox::getT('feed_like'), 'feed_id = ' . $aFeed['feed_id']);
			$this->database()->delete(Phpfox::getT('feed'), 'type_id LIKE \'%feedLike\' AND item_id = ' . $aFeed['feed_id']);			
		}		
		
		$this->database()->delete(Phpfox::getT('feed'), 'type_id = \'' . $sType . '\' AND child_item_id = ' . (int) $iId);
	}
	
	public function deleteFeed($iId)
	{
		$aFeed = Phpfox::getService('feed')->getFeed($iId);
		if (!isset($aFeed['feed_id']))
		{
			return false;
		}
		
		$bCanDelete = false;
		if (Phpfox::getUserParam('feed.can_delete_own_feed') && ($aFeed['user_id'] == Phpfox::getUserId() || $aFeed['item_user_id'] == Phpfox::getUserId()))
		{
			$bCanDelete = true;
		}
		
		if (Phpfox::getUserParam('feed.can_delete_other_feeds'))
		{
			$bCanDelete = true;
		}
		
		if ($bCanDelete === true)
		{
			$this->database()->delete(Phpfox::getT('feed'), 'feed_id = ' . (int) $iId);
			$this->database()->delete(Phpfox::getT('feed_rating'), 'feed_id = ' . (int) $iId);
			$this->database()->delete(Phpfox::getT('feed_like'), 'feed_id = ' . (int) $iId);
			$this->database()->delete(Phpfox::getT('feed'), 'type_id LIKE \'%feedLike\' AND item_id = ' . (int) $iId);
			$this->cache()->remove('feed_' . $aFeed['user_id'], 'substr');			
			return true;
		}
		
		return false;
	}
	
	public function deleteLikes($iFeed)
	{
		
	}

	public function update($sType, $iId, $mContent, $iChildId = null)
	{		
		if (Phpfox::getLib('parse.format')->isSerialized($mContent))
		{			
			$aCache = unserialize($mContent);
			if (isset($aCache['content']))
			{
				$aCache['content'] = $this->_clean($aCache['content']);
			}
			
			$mContent = serialize($aCache);
		}
		else 
		{
			$mContent = $this->_clean($mContent);
		}		
		
		$this->database()->update(Phpfox::getT('feed'), array('content' => $mContent), 'type_id = \'' . $sType . '\' AND item_id = ' . (int) $iId . ($iChildId === null ? '' : ' AND child_item_id = ' . (int) $iChildId));		
	}

	public function addComment($aVals)
	{
		if (empty($aVals['item_id']) || (!empty($aVals['item_id']) && (int) $aVals['item_id'] === 0))
		{
			return false;
		}
		
		Phpfox::getLib('parse.bbcode')->useVideoImage(true);
		
		$iId = $this->database()->insert(Phpfox::getT('feed'), array(
				'view_id' => ((Phpfox::isModule('comment') && Phpfox::getUserParam('comment.approve_all_comments')) ? '1' : '0'),
				'type_id' => 'comment_profile_my',
				'user_id' => (int) $aVals['item_id'],
				'item_id' => (int) $aVals['item_id'],
				'item_user_id' => Phpfox::getUserId(),
				'content' => $this->preParse()->prepare($aVals['feed_text']),
				'time_stamp' => PHPFOX_TIME
			)
		);
		
		if (Phpfox::isModule('comment') && Phpfox::getUserParam('comment.approve_all_comments'))
		{
			return Phpfox_Error::set(Phpfox::getPhrase('comment.your_comment_has_successfully_been_added_however_it_is_pending_an_admins_approval'));
		}
		
		$aUser = Phpfox::getService('user')->getUser($aVals['item_id']);		
		
		$sLink = Phpfox::getLib('url')->makeUrl($aUser['user_name'], array('feed' => $iId));

		if (!empty($aUser['email'])) // http://forums.phpfox.com/project.php?issueid=5160
		{
			Phpfox::getLib('mail')
			->to($aUser['user_id'])
			->subject(array('profile.user_name_left_you_a_comment_on_site_title', array('user_name' => Phpfox::getUserBy('full_name'), 'site_title' => Phpfox::getParam('core.site_title'))))
			->message(array('profile.user_name_left_you_a_comment_on_your_profile_message', array(
						'user_name' => Phpfox::getUserBy('full_name'),
						'link' => $sLink
					)
				)
			)
			->notification('comment.add_new_comment')
			->send();			
		}
		Phpfox::getService('notification.process')->add('comment_profile', $aUser['user_id'], $aUser['user_id'], array(
				'title' => '',
				'user_id' => Phpfox::getUserId(),
				'image' => Phpfox::getUserBy('user_image'),
				'server_id' => Phpfox::getUserBy('server_id')
			)
		);			
		
		return $iId;
	}
	
	public function updateCommentText($iFeed, $sTxt)
	{
		$aFeed = Phpfox::getService('feed')->getFeed($iFeed);
		
		if ((Phpfox::getUserParam('comment.edit_own_comment') && Phpfox::getUserId() == $aFeed['item_user_id']) || Phpfox::getUserParam('comment.edit_user_comment'))
		{
			$this->database()->update(Phpfox::getT('feed'), array(
					'content' => $this->preParse()->prepare($sTxt)
				), 'feed_id = ' . (int) $iFeed
			);
			
			return true;
		}
		
		return false;
	}
	
	public function rate($iId, $sType, $iUserId = null)
	{
		$iUserId = ($iUserId === null ? Phpfox::getUserId() : (int) $iUserId);

		$aRow = $this->database()->select('feed_id, rating')
			->from(Phpfox::getT('feed_rating'))
			->where('feed_id = ' . (int) $iId . ' AND user_id = ' . $iUserId)
			->execute('getRow');

		$bAllowRating = true;
		if ($sType == 'up')
		{
			if (isset($aRow['feed_id']))
			{
				if ($aRow['rating'] == '+1')
				{
					$sNewRating = '+1';
					$bAllowRating = false;
				}
				elseif ($aRow['rating'] == '-1')
				{
					$sNewRating = '0';
				}
				else
				{
					$sNewRating = '+1';
				}
			}
			else
			{
				$sNewRating = '+1';
			}
		}
		else
		{
			if (isset($aRow['feed_id']))
			{
				if ($aRow['rating'] == '+1')
				{
					$sNewRating = '0';
				}
				elseif ($aRow['rating'] == '-1')
				{
					$sNewRating = '-1';
					$bAllowRating = false;
				}
				else
				{
					$sNewRating = '-1';
				}
			}
			else
			{
				$sNewRating = '-1';
			}
		}

		if (isset($aRow['feed_id']))
		{
			$this->database()->update(Phpfox::getT('feed_rating'), array(
				'rating' => $sNewRating
			), 'feed_id = ' . (int) $iId . ' AND user_id = ' . $iUserId);
		}
		else
		{
			$this->database()->insert(Phpfox::getT('feed_rating'), array(
				'feed_id' => (int) $iId,
				'user_id' => $iUserId,
				'rating' => $sNewRating,
				'time_stamp' => PHPFOX_TIME,
				'ip_address' => Phpfox::getLib('request')->getServer('REMOTE_ADDR')
			));
		}

		$sRating = $this->database()->select('rating')
			->from($this->_sTable)
			->where('feed_id = ' . (int) $iId)
			->execute('getField');

		if ($bAllowRating)
		{
			if (is_null($sRating) || $sRating == 0)
			{
				if ($sType == 'up')
				{
					$sRating = '+1';
				}
				else
				{
					$sRating = '-1';
				}
			}
			else
			{
				if (substr($sRating, 0, 1) == '+')
				{
					if ($sType == 'up')
					{
						$sRating = '+' . ((int) substr_replace($sRating, '', 0, 1) + 1);
					}
					else
					{
						$iCnt = (int) substr_replace($sRating, '', 0, 1);

						if ($iCnt == 1)
						{
							$sRating = 0;
						}
						else
						{
							$sRating = '+' . ($iCnt - 1);
						}
					}
				}
				else
				{
					if ($sType == 'up')
					{
						$iCnt = (int) substr_replace($sRating, '', 0, 1);

						if ($iCnt == 1)
						{
							$sRating = 0;
						}
						else
						{
							$sRating = '-' . ((int) substr_replace($sRating, '', 0, 1) - 1);
						}
					}
					else
					{
						$sRating = '-' . ((int) substr_replace($sRating, '', 0, 1) + 1);
					}
				}
			}

			// +1 is counted as a numeric value when using is_numeric() so we don't escape this query
			$this->database()->update($this->_sTable, array('rating' => "'{$sRating}'"), 'feed_id = ' . $iId, false);
		}

		return array($sRating, $sNewRating);
	}
	
	public function like($iFeed, $iType)
	{
		Phpfox::isUser(true);
		
		$aFeed = $this->database()->select('f.feed_id, f.type_id, f.item_id, f.item_user_id, ' . Phpfox::getUserField())
				->from(Phpfox::getT('feed'), 'f')
				->join(Phpfox::getT('user'), 'u', 'u.user_id = f.user_id')
				->where('f.feed_id = ' . (int) $iFeed)
				->execute('getRow');
				
		if (!isset($aFeed['feed_id']))
		{
			return Phpfox_Error::set(Phpfox::getPhrase('feed.the_feed_you_are_trying_to_like_unlike_does_not_exist_any_longer'));
		}
		
		if ((int) $iType === 1)
		{
			$iCheck = $this->database()->select('COUNT(*)')
				->from(Phpfox::getT('feed_like'))
				->where('feed_id = ' . (int) $iFeed . ' AND user_id = ' . Phpfox::getUserId())
				->execute('getField');
		
			if ($iCheck)
			{
				return Phpfox_Error::set(Phpfox::getPhrase('feed.you_have_already_liked_this_feed'));
			}			
				
			$iId = $this->database()->insert(Phpfox::getT('feed_like'), array(
					'feed_id' => (int) $iFeed,
					'user_id' => Phpfox::getUserId(),
					'time_stamp' => PHPFOX_TIME
				)
			);
			
			$iSpamCheck = $this->database()->select('COUNT(*)')
				->from(Phpfox::getT('feed_like_cache'))
				->where('feed_id = ' . (int) $iFeed . ' AND user_id = ' . Phpfox::getUserId())
				->execute('getField');			

			if (!$iSpamCheck)
			{
				$this->database()->insert(Phpfox::getT('feed_like_cache'), array(
						'feed_id' => (int) $iFeed,
						'user_id' => Phpfox::getUserId(),
						'time_stamp' => PHPFOX_TIME
					)
				);			
				
				if ($aFeed['user_id'] != Phpfox::getUserId())
				{								
					$iItemEmailId = $aFeed['user_id'];
					if ($aFeed['type_id'] == 'comment_profile_my')
					{
						$iItemEmailId = $aFeed['item_user_id'];
					}
					
					$sItemPhrase = Phpfox::callback($aFeed['type_id'] . '.sendLikeEmail', $aFeed['item_id'], $aFeed);
					
					Phpfox::getLib('mail')
						->to($iItemEmailId)
						->subject(strip_tags($sItemPhrase))
						->message($sItemPhrase)
						->notification('feed.item_is_liked')
						->send();			
				}				
			}
			
			$mContent = null;
			$iFeedItemId = $aFeed['user_id'];
			if ($aFeed['type_id'] == 'comment_profile_my')
			{
				$mContent = $aFeed['user_name'];	
				$iFeedItemId = $aFeed['item_user_id'];
			}

			if ($aFeed['user_id'] != Phpfox::getUserId()) // Do not add a feed stating that userX liked this if both are the same user
			{
				(Phpfox::isModule('feed') ? Phpfox::getService('feed.process')->add($aFeed['type_id'] . '_feedLike', $aFeed['feed_id'], $mContent, null, $iFeedItemId, $aFeed['item_id'], true) : null);
			}
			
			$iUserId = Phpfox::getUserId();
			if ($aFeed['type_id'] == 'user_status')
			{
				$aFeed['item_id'] = $aFeed['feed_id'];
			}
			elseif ($aFeed['type_id'] == 'user_photo')
			{
				$aFeed['item_id'] = $aFeed['feed_id'];
			}
			elseif ($aFeed['type_id'] == 'comment_profile_my')
			{
				$aFeed['user_id'] = $aFeed['item_user_id'];
				$aFeed['item_id'] = $aFeed['feed_id'];
			}					
			
			if ($sPlugin = Phpfox_Plugin::get('feed.service_process_like_notify'))
			{
				eval($sPlugin);
				return;
			}			
			
			(Phpfox::isModule('notification') ? Phpfox::getService('notification.process')->add($aFeed['type_id'] . '_notifyLike', $aFeed['item_id'], $aFeed['user_id'], Phpfox::getUserId()) : null);
		}
		else
		{
			$this->database()->delete(Phpfox::getT('feed'), 'type_id LIKE \'%feedLike\' AND item_id = ' . (int) $iFeed . ' AND user_id = ' . Phpfox::getUserId());
			$this->database()->delete(Phpfox::getT('feed_like'), 'feed_id = ' . (int) $iFeed . ' AND user_id = ' . Phpfox::getUserId());
			
			(Phpfox::isModule('notification') ? Phpfox::getService('notification.process')->delete($aFeed['type_id'] . '_notifyLike', $aFeed['item_id'], $aFeed['user_id']) : null);
		}
		
		return true;
	}
	
	public function approve($iFeed)
	{
		$aFeed = $this->database()->select('f.*, ' . Phpfox::getUserField())
			->from(Phpfox::getT('feed'), 'f')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = f.user_id')
			->where('f.feed_id = ' . (int) $iFeed)
			->execute('getSlaveRow');
			
		if (!isset($aFeed['feed_id']))
		{
			return false;
		}
		
		$this->database()->update(Phpfox::getT('feed'), array('view_id' => '0'), 'feed_id = ' . $aFeed['feed_id']);
		
		Phpfox::getLib('mail')->to($aFeed['item_user_id'])
			->subject(array('comment.comment_approved_on_site_title', array('site_title' => Phpfox::getParam('core.site_title'))))
			->message(array('comment.one_of_your_comments_on_site_title', array(
						'site_title' => Phpfox::getParam('core.site_title'),
						'link' => Phpfox::getLib('url')->makeUrl($aFeed['user_name'], array('feed' => $aFeed['feed_id'], '#feed'))
					)
				)
			)					
			->send();		
		
		return true;
	}

	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('feed.service_process__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}	
	
	private function _clean($mContent)
	{
		$mContent = str_replace(array('\n', '\t', '\r'), ' ', $mContent);
		$mContent = preg_replace("#<br( /)?>#siU", " ", $mContent);		
		$mContent = str_replace('  ', ' ', $mContent);
		// $mContent = Phpfox::getLib('parse.input')->stripInnerHtml($mContent);

		return $mContent;	
	}
}

?>