<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Friend
 * @version 		$Id: process.class.php 1496 2010-03-05 17:15:05Z Raymond_Benc $
 */
class Friend_Service_List_Process extends Phpfox_Service 
{
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('friend_list');
	}
	
	/**
	 * Adds a new folder to the friends folder list
	 *
	 * @param String $sName name of the new folder
	 * @return bolean value for success
	 */
	public function add($sName)
	{		
		return $this->database()->insert($this->_sTable, array(
			'user_id' => Phpfox::getUserId(),
			'name' => Phpfox::getLib('parse.input')->clean($sName, 255),
			'time_stamp' => PHPFOX_TIME,
			'used' => 0 // this is a new folder
		));		
	}
	
	public function update($aVals)
	{
		$oFriendList = Phpfox::getService('friend.list');
		
		foreach ($aVals['name'] as $iFolder => $sName)
		{
			if ($oFriendList->isFolder($sName))
			{
				continue;
			}
			
			$this->database()->update($this->_sTable, array(
					'name' => Phpfox::getLib('parse.input')->clean($sName, 255),
				), 'list_id = ' . (int) $iFolder . ' AND user_id = ' . Phpfox::getUserId()
			);
		}
		
		(($sPlugin = Phpfox_Plugin::get('friend.service_list_process_update')) ? eval($sPlugin) : false);
		
		return true;
	}	
	
	public function delete($iId)
	{
		$aRows = $this->database()->select('f.friend_id')
			->from(Phpfox::getT('friend'), 'f')
			->where('f.list_id = ' . (int) $iId . ' AND f.user_id = ' . Phpfox::getUserId())
			->execute('getRows');
			
		foreach ($aRows as $aRow)
		{
			$this->database()->update(Phpfox::getT('friend'), array(
				'list_id' => 0
			), 'friend_id = ' . $aRow['friend_id']);
		}
		
		$this->database()->delete($this->_sTable, 'list_id = ' . (int) $iId);
		
		(($sPlugin = Phpfox_Plugin::get('friend.service_list_process_delete')) ? eval($sPlugin) : false);
		
		return true;
	}

	public function move($mFolder, $aIds)
	{
		
		// how many friends are in destination list:
		$oService = Phpfox::getService('friend.list');
		$iCountDest = $oService->getCountForFolder($mFolder);
		
		foreach ($aIds as $iId)
		{	
		
			// update the source folder's count
			$iFolderId = $oService->getFolderPerUser($iId);			
			$iCountSrc = $oService->getCountForFolder($iFolderId);		
			$iCountSrc = ($iCountSrc > 0) ? $iCountSrc-1 : 0;
			
			$this->database()->update($this->_sTable,array(
				'used'=>$iCountSrc
				),'list_id = \''.$iFolderId.'\'');
			
			// update the destination folder
			$iCountDest = $iCountDest +1;
			$this->database()->update($this->_sTable,array(
				'used'=>$iCountDest
				),'list_id = \''.$mFolder.'\'');
			
			// move friend
			$this->database()->update(Phpfox::getT('friend'), array(
				'list_id' => (int) $mFolder
			), 'friend_id = ' . (int) $iId . ' AND user_id = ' . Phpfox::getUserId());		
			
		}
		
		(($sPlugin = Phpfox_Plugin::get('friend.service_list_process_move')) ? eval($sPlugin) : false);
		
		return true;
	}
	
	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('friend.service_list_process__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}	
}

?>