<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package 		Phpfox_Service
 * @version 		$Id: im.class.php 1496 2010-03-05 17:15:05Z Raymond_Benc $
 */
class Im_Service_Im extends Phpfox_Service 
{	
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('im');
	}
	
	public function getChat($iId, $bStatic = true)
	{
		static $aChat;
		
		if ($aChat && $bStatic)
		{
			return $aChat;
		}
		
		$aChat = $this->database()->select('i.im_id, i.parent_id, ls.user_id AS is_logged_in, ls.im_status, ls.im_hide, ib.user_id AS is_blocked_user, ' . Phpfox::getUserField())
			->from($this->_sTable, 'i')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = i.owner_user_id')
			->leftJoin(Phpfox::getT('log_session'), 'ls', 'ls.user_id = i.owner_user_id')
			->leftJoin(Phpfox::getT('user_blocked'), 'ib', '(ib.user_id = i.owner_user_id AND ib.block_user_id = ' . Phpfox::getUserId() . ')')
			->where('i.parent_id = ' . (int) $iId . ' AND i.user_id = ' . Phpfox::getUserId())
			->execute('getSlaveRow');
			
		if (!isset($aChat['im_id']))
		{
			return false;
		}
			
		if ($aChat['is_blocked_user'])
		{
			$aChat['is_logged_in'] = 0;
		}
		
		if ($aChat['im_hide'] > 0)
		{
			$aChat['is_logged_in'] = 0;
		}
		
		return $aChat;
	}
	
	public function getOnlineFriendsCount($iUserId)
	{
		$iCnt = $this->database()->select('COUNT(DISTINCT u.user_id)')
			->from(Phpfox::getT('friend'), 'f')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = f.friend_user_id')
			->join(Phpfox::getT('log_session'), 'ls', 'ls.user_id = f.friend_user_id AND ls.im_hide = 0')
			->where('f.user_id = ' . (int) $iUserId)
			->execute('getSlaveField');

		if ($iCnt > 0)
		{
			$aBlocked = $this->database()->select('ib.block_user_id')
				->from(Phpfox::getT('user_blocked'), 'ib')
				->join(Phpfox::getT('user'), 'u', 'u.user_id = ib.block_user_id')
				->join(Phpfox::getT('log_session'), 'ls', 'ls.user_id = ib.block_user_id')
				->where('ib.user_id = ' . (int) $iUserId . ' OR ib.block_user_id = ' . (int) $iUserId)
				->group('u.user_id')
				->execute('getSlaveRows');
	
			foreach ($aBlocked as $aUser)
			{				
				$iCnt--;	
			}
		}
			
		return $iCnt;
	}
	
	public function getOnlineFriends($iUserId, $aCond, $iPage = '', $sLimit = '')
	{
		$iCnt = $this->getOnlineFriendsCount($iUserId);
		
		$aUsers = $this->database()->select('ib.user_id AS is_blocked_user, ls.im_status, u.status, ' . Phpfox::getUserField())
			->from(Phpfox::getT('friend'), 'f')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = f.friend_user_id')
			->join(Phpfox::getT('log_session'), 'ls', 'ls.user_id = f.friend_user_id AND ls.im_hide = 0')
			->leftJoin(Phpfox::getT('user_blocked'), 'ib', '(ib.user_id = f.friend_user_id AND ib.block_user_id = ' . (int) $iUserId . ') OR (ib.user_id = ' . (int) $iUserId . ' AND ib.block_user_id = f.friend_user_id)')
			// ->where('f.user_id = ' . (int) $iUserId)
			->where($aCond)
			->limit($iPage, $sLimit, $iCnt)
			->order('u.full_name ASC')
			->group('u.user_id')
			->execute('getSlaveRows');
		
		foreach ($aUsers as $iKey => $aUser)
		{
			if ($aUser['is_blocked_user'])
			{
				unset($aUsers[$iKey]);
			}
		}
		
		return array($iCnt, $aUsers);
	}
	
	public function getRooms()
	{
		$aRooms = $this->database()->select('i.*, ls.user_id AS is_logged_in, ls.im_status, ls.im_hide, ib.user_id AS is_blocked_user, ' . Phpfox::getUserField())
			->from($this->_sTable, 'i')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = i.owner_user_id')
			->leftJoin(Phpfox::getT('log_session'), 'ls', 'ls.user_id = i.owner_user_id')
			->leftJoin(Phpfox::getT('user_blocked'), 'ib', '(ib.user_id = i.owner_user_id AND ib.block_user_id = ' . Phpfox::getUserId() . ')')
			->where('i.user_id = ' . Phpfox::getUserId() . ' AND i.is_active = 1')
			->group('u.user_id')
			->order('i.ordering ASC')
			->execute('getSlaveRows');
			
		foreach ($aRooms as $iKey => $aRoom)
		{
			if ($aRooms[$iKey]['is_blocked_user'])
			{
				$aRooms[$iKey]['is_logged_in'] = 0;
			}			
			
			if ($aRooms[$iKey]['im_hide'] > 0)
			{
				$aRooms[$iKey]['is_logged_in'] = 0;
			}			
		}
			
		return $aRooms;
	}
	
	public function canAddAlert($iUserId, $iId)
	{
		$aAlert = $this->database()->select('is_seen')
			->from(Phpfox::getT('im_alert'))
			->where('user_id = ' . (int) $iUserId . ' AND room_id = ' . (int) $iId . '')
			->execute('getSlaveRow');		

		if (!isset($aAlert['is_seen']))		
		{
			return true;
		}
		
		return ($aAlert['is_seen'] == '0' ? true : false);
	}	
	
	public function hasAlert($iUserId, $iId)
	{
		$aAlert = $this->database()->select('is_seen')
			->from(Phpfox::getT('im_alert'))
			->where('user_id = ' . (int) $iUserId . ' AND room_id = ' . (int) $iId . '')
			->execute('getSlaveRow');			
			
		$this->database()->update(Phpfox::getT('im_alert'), array('is_seen' => '1'), 'user_id = ' . (int) $iUserId . ' AND room_id = ' . (int) $iId);		
		
		return ((isset($aAlert['is_seen']) && $aAlert['is_seen'] == '0') ? true : false);
	}
	
	public function getMessages($iId)
	{
		$aMessages = $this->database()->select('it.*, ' . Phpfox::getUserField())
			->from(Phpfox::getT('im_text'), 'it')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = it.user_id')
			->where('it.parent_id = ' . (int) $iId)
			->order('it.time_stamp DESC')
			->limit(50)
			->execute('getSlaveRows');
			
		$aMessages = array_reverse($aMessages);
	
		foreach ($aMessages as $iKey => $aMessage)
		{
			$aMessages[$iKey]['is_today'] = (Phpfox::getTime('d', $aMessage['time_stamp']) == Phpfox::getTime('d') ? true : false);
		}
		
		return $aMessages;
	}
	
	public function getStatuses()
	{
		$aStatuses = array(
			'0' => Phpfox::getPhrase('im.online'),
			'1' => Phpfox::getPhrase('im.away'),
			'2' => Phpfox::getPhrase('im.appear_offline')
		);
		
		return $aStatuses;
	}
	
	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('im.service_im__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}	
}

?>