<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package 		Phpfox_Component
 * @version 		$Id: index.class.php 2433 2011-03-24 11:59:23Z Raymond_Benc $
 */
class Marketplace_Component_Controller_Index extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{
		Phpfox::getUserParam('marketplace.can_access_marketplace', true);

		// certain conditions need to apply to sponsor a listing
		if ($this->request()->get('sponsor') == 'help')
		{
		    // check if the user can sponsor items
		    if (!Phpfox::getUserParam('marketplace.can_purchase_sponsor') &&
			!Phpfox::getUserParam('marketplace.can_sponsor_marketplace'))
		    {
				$this->url()->forward($this->url()->makeUrl('marketplace'), Phpfox::getPhrase('subscribe.the_feature_or_section_you_are_attempting_to_use_is_not_permitted_with_your_membership_level'));
		    }
		    else
		    {
				Phpfox::addMessage(Phpfox::getPhrase('marketplace.sponsor_help'));
		    }
		}
		
		if (($iDeleteId = $this->request()->getInt('delete')))
		{
			if (Phpfox::getService('marketplace.process')->delete($iDeleteId))
			{
				$this->url()->send('marketplace', null, Phpfox::getPhrase('marketplace.listing_successfully_deleted'));
			}
		}
		
		if (($iRedirectId = $this->request()->getInt('redirect')) && ($aListing = Phpfox::getService('marketplace')->getListing($iRedirectId, true)))
		{
			$this->url()->send('marketplace.view', array($aListing['title_url']));
		}		
	
		$oServiceMarketplaceBrowse = Phpfox::getService('marketplace.browse');
		$oDatabase = Phpfox::getLib('database');
		$oParseInput = Phpfox::getLib('parse.input');
		$aConditions = array();
		$iPage = $this->request()->get('page');
		$iPageSize = 25;
		$sCategory = null;
		$aForms = array();
		$aCacheCategories = array();
		$iRequestCount = 0;
		$bIsUserProfile = (defined('PHPFOX_IS_USER_PROFILE') ? true : false);
		$sView = $this->request()->get('view');
		if ($bIsUserProfile)
		{
			$aUser = $this->getParam('aUser');
		}
		
		$aRequests = $this->request()->getRequests();		
		$sCategoryUrl = '';	
		foreach ($aRequests as $sKey => $sValue)
		{			
			if (!preg_match("/req[0-9]/", $sKey))
			{
				continue;
			}
			
			$iRequestCount++;
			
			$aCacheCategories[] = $sValue;
			
			$this->url()->setParam($sKey, $sValue);
			
			if ($bIsUserProfile)
			{
				if ($iRequestCount > 2)
				{
					$sCategory = $sValue;
					$sCategoryUrl .= '.' . $sValue;
				}				
			}
			else 
			{
				if ($sKey != 'req1')
				{
					$sCategory = $sValue;
					$sCategoryUrl .= '.' . $sValue;
				}
			}
		}
		$sCategoryUrl = ltrim($sCategoryUrl, '.');		
		if (empty($sCategoryUrl))
		{
			$sCategoryUrl = null;
		}
				
		$this->setParam('sCategory', $sCategoryUrl);
		
		$aPages = array(12, 15, 18, 21);
		$aDisplays = array();
		foreach ($aPages as $iPageCnt)
		{
			$aDisplays[$iPageCnt] = Phpfox::getPhrase('core.per_page', array('total' => $iPageCnt));
		}		
	
		$aFilters = array(
			'display' => array(
				'type' => 'select',
				'options' => $aDisplays,
				'default' => '12'
			),
			'country' => array(
				'type' => 'select',
				'options' => Phpfox::getService('core.country')->get(),
				'search' => 'AND m.country_iso = \'[VALUE]\'',
				'style' => 'width:90%;',
				'id' => 'country_iso',
				'add_any' => true
			),
			'country_child_id' => array(
				'type' => 'select',
				'search' => 'AND m.country_child_id = \'[VALUE]\'',
				'clone' => true
			),
			'sort' => array(
				'type' => 'select',
				'options' => array(
					'time_stamp' => Phpfox::getPhrase('marketplace.date_added'),
					'title' => Phpfox::getPhrase('marketplace.name')
				),
				'default' => 'time_stamp',
				'alias' => 'm'
			),
			'sort_by' => array(
				'type' => 'select',
				'options' => array(
					'DESC' => Phpfox::getPhrase('core.descending'),
					'ASC' => Phpfox::getPhrase('core.ascending')
				),
				'default' => 'DESC'
			),
			'keyword' => array(
				'type' => 'input:text',
				'size' => 20,
				'search' => 'AND m.title LIKE \'%[VALUE]%\''
			),
			'city' => array(
				'type' => 'input:text',
				'size' => 20,
				'search' => 'AND m.city LIKE \'%[VALUE]%\''
			),
			'zip' => array(
				'type' => 'input:text',
				'size' => 10,
				'search' => 'AND m.postal_code = \'[VALUE]\''
			)			
		);
		
		(($sPlugin = Phpfox_Plugin::get('marketplace.component_controller_index_process_search')) ? eval($sPlugin) : false);
		
		$oFilter = Phpfox::getLib('search')
			->set(array(
				'type' => 'browse',
				'filters' => $aFilters,
				'search' => 'keyword',
				'prepare' => false
			)
		);		
		
		if (!Phpfox::getUserParam('marketplace.can_approve_listings') && $sView != 'my')
		{
			$oFilter->setCondition('AND m.view_id = 0');
		}		

		switch ($sView)
		{
			case 'sold':
				Phpfox::isUser(true);				
				$oFilter->setCondition('AND m.user_id = ' . Phpfox::getUserId());				
				$oFilter->setCondition('AND m.is_sell = 1');
				
				break;
			case 'featured':
				$oFilter->setCondition('AND m.is_featured = 1');
				break;
			case 'my':
				Phpfox::isUser(true);				
				$oFilter->setCondition('AND m.user_id = ' . Phpfox::getUserId());
				break;
			case 'pending':
				if (Phpfox::getUserParam('marketplace.can_approve_listings'))
				{
					$oFilter->setCondition('AND m.view_id = 1');
				}
				break;
			case 'invitation':
				Phpfox::isUser(true);
				$oServiceMarketplaceBrowse->seen();				
				break;
			default:
				
				break;
		}
		
		if ($bIsUserProfile && isset($aUser['user_id']))
		{
			$oFilter->setCondition('AND m.user_id = ' . $aUser['user_id']);	
		}

		// if its a user trying to buy sponsor space he should get only his own listings
		if ($this->request()->get('sponsor') == 'help')
		{
		    $oFilter->setCondition('AND m.user_id = ' . Phpfox::getUserId() . ' AND is_sponsor != 1');
		}
		
		(($sPlugin = Phpfox_Plugin::get('marketplace.component_controller_index_process_filter')) ? eval($sPlugin) : false);

		$oServiceMarketplaceBrowse->condition($oFilter->getConditions())
			->category($sCategoryUrl)
			->order($oFilter->getSort())
			->page($iPage)
			->size($oFilter->getDisplay())
			->execute();			
		
		Phpfox::getLib('pager')->set(array('page' => $iPage, 'size' => $oFilter->getDisplay(), 'count' => $oFilter->getSearchTotal($oServiceMarketplaceBrowse->getCount())));
		
		$iFilterCount = 0;
		$aFilterMenuCache = array();
		if (!defined('PHPFOX_IS_USER_PROFILE'))
		{
			$aFilterMenu = array(
				Phpfox::getPhrase('marketplace.recent_listings') => '',
				Phpfox::getPhrase('marketplace.my_listings') => 'my',
				Phpfox::getPhrase('marketplace.sold') => 'sold',
				Phpfox::getPhrase('marketplace.purchased') => 'purchased',
				Phpfox::getPhrase('marketplace.featured') => 'featured',
				Phpfox::getPhrase('marketplace.invitations') => 'invitation'
			);		
			
			if (Phpfox::getUserParam('marketplace.can_approve_listings'))
			{
				$aFilterMenu[Phpfox::getPhrase('marketplace.pending')] = 'pending';
			}			
			
			foreach ($aFilterMenu as $sMenuName => $sMenuLink)
			{
				$iFilterCount++;
				$aFilterMenuCache[] = array(
					'name' => $sMenuName,
					'link' => $this->url()->makeUrl('marketplace' . (empty($sCategoryUrl) ? '' : '.' . $sCategoryUrl), array('view' => $sMenuLink)),
					'active' => ($sView == $sMenuLink ? true : false),
					'last' => (count($aFilterMenu) === $iFilterCount ? true : false)
				);	
				
				if ($sView == $sMenuLink)
				{
					$this->template()->setTitle($sMenuName)->setBreadcrumb($sMenuName, null, true);
				}
			}	
			
			if (empty($sView))
			{				
				$this->template()->setTitle(Phpfox::getPhrase('marketplace.recent_listings'))->setBreadcrumb(Phpfox::getPhrase('marketplace.recent_listings'), null, true);
			}
		}

		$this->template()->setTitle(Phpfox::getPhrase('marketplace.marketplace'))
			->setBreadcrumb(Phpfox::getPhrase('marketplace.marketplace'), ($bIsUserProfile ? $this->url()->makeUrl($aUser['user_name'], 'marketplace') : $this->url()->makeUrl('marketplace')))
			->setHeader('cache', array(
					'pager.css' => 'style_css',
					'country.js' => 'module_core'
				)
			)
			->assign(array(
					'aListings' => $oServiceMarketplaceBrowse->get(),
					'aForms' => $aForms,
					'sCategoryUrl' => $sCategoryUrl,
					'aFilterMenus' => $aFilterMenuCache,
					'iListingApproveCnt' => (Phpfox::getUserParam('marketplace.can_approve_listings') ? Phpfox::getService('marketplace')->getPendingTotal() : 0),
					'sListingView' => $sView
				)
			);
			
		(($sPlugin = Phpfox_Plugin::get('marketplace.component_controller_process_end')) ? eval($sPlugin) : false);
			
		if ($sCategory !== null)
		{
			$aCategories = Phpfox::getService('marketplace.category')->getParentBreadcrumb($sCategoryUrl);			
			$iCnt = 0;
			foreach ($aCategories as $aCategory)
			{
				$iCnt++;
				
				$this->template()->setTitle($aCategory[0]);				
				
				if ($bIsUserProfile)
				{
					$aCategory[1] = str_replace('/marketplace/', '/' . $aUser['user_name'] . '/marketplace/', $aCategory[1]);
				}
				
				$this->template()->setBreadcrumb($aCategory[0], $aCategory[1], ($iCnt === count($aCategories) ? true : false));
			}			
		}
	}
	
	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('marketplace.component_controller_index_clean')) ? eval($sPlugin) : false);
	}
}

?>