<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package 		Phpfox_Service
 * @version 		$Id: browse.class.php 2040 2010-11-02 14:21:12Z Raymond_Benc $
 */
class Marketplace_Service_Browse extends Phpfox_Service 
{
	private $_aConditions = array();
	
	private $_iCnt = 0;
	
	private $_iPage = 0;
	
	private $_iPageSize = 25;
	
	private $_sOrder = 'm.is_featured DESC, m.time_stamp DESC';
	
	private $_aListings = array();
	
	private $_sCategory = null;
	
	private $_bIsSeen = false;
	
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('marketplace');
	}
	
	public function condition($aConditions)
	{
		$this->_aConditions = $aConditions;
		
		return $this;
	}
	
	public function page($iPage)
	{
		$this->_iPage = $iPage;
		
		return $this;
	}
	
	public function seen()
	{
		$this->_bIsSeen = true;
		
		return $this;
	}
	
	public function size($iPageSize)
	{
		$this->_iPageSize = $iPageSize;
		
		return $this;
	}
	
	public function category($sCategory)
	{
		$this->_sCategory = $sCategory;
		
		return $this;
	}
	
	public function order($sOrder)
	{
		if ($sOrder != 'm.time_stamp DESC')
		{		
			$this->_sOrder = $sOrder;
		}
		
		return $this;
	}	
	
	public function execute()
	{
		if ($this->_sCategory !== null)
		{
			$sCategories = Phpfox::getService('marketplace.category')->getAllCategories($this->_sCategory);
		
			$this->database()->innerJoin(Phpfox::getT('marketplace_category_data'), 'mcd', 'mcd.listing_id = m.listing_id');
			
			$this->_aConditions[] = ' AND mcd.category_id IN(' . $sCategories . ')';
		}
		
		if ($this->_bIsSeen !== false)
		{
			$this->database()->join(Phpfox::getT('marketplace_invite'), 'mi', 'mi.listing_id = m.listing_id AND mi.visited_id = 0 AND mi.invited_user_id = ' . Phpfox::getUserId());
		}
		
		if (Phpfox::getLib('request')->get('view') == 'purchased')
		{
			$this->database()->join(Phpfox::getT('marketplace_invoice'), 'minvoice', 'minvoice.listing_id = m.listing_id AND minvoice.user_id = ' . Phpfox::getUserId() . ' AND minvoice.status = \'completed\'');
		}
		
		if (Phpfox::getLib('request')->get('view') == 'sold')
		{
			$this->database()->join(Phpfox::getT('marketplace_invoice'), 'minvoice', 'minvoice.listing_id = m.listing_id AND minvoice.status = \'completed\'');			
		}
		
		(($sPlugin = Phpfox_Plugin::get('marketplace.service_browse_execute_query')) ? eval($sPlugin) : false);
		
		$this->_iCnt = $this->database()->select((($this->_sCategory !== null || (Phpfox::getLib('request')->get('view') == 'sold' || Phpfox::getLib('request')->get('view') == 'purchased')) ? 'COUNT(DISTINCT m.listing_id)' : 'COUNT(*)'))
			->from($this->_sTable, 'm')
			->where($this->_aConditions)
			->execute('getSlaveField');
			
		if ($this->_iCnt)
		{
			if ($this->_sCategory !== null)
			{			
				$this->database()->innerJoin(Phpfox::getT('marketplace_category_data'), 'mcd', 'mcd.listing_id = m.listing_id')->group('m.listing_id');
			}
			
			if ($this->_bIsSeen !== false)
			{
				$this->database()->join(Phpfox::getT('marketplace_invite'), 'mi', 'mi.listing_id = m.listing_id AND mi.visited_id = 0 AND mi.invited_user_id = ' . Phpfox::getUserId());
			}			
			
			if (Phpfox::getLib('request')->get('view') == 'purchased')
			{
				$this->database()->join(Phpfox::getT('marketplace_invoice'), 'minvoice', 'minvoice.listing_id = m.listing_id AND minvoice.user_id = ' . Phpfox::getUserId() . ' AND minvoice.status = \'completed\'');	
			}			
			
			if (Phpfox::getLib('request')->get('view') == 'sold')
			{
				$this->database()->join(Phpfox::getT('marketplace_invoice'), 'minvoice', 'minvoice.listing_id = m.listing_id AND minvoice.status = \'completed\'')->group('m.listing_id');			
			}			
			
			(($sPlugin = Phpfox_Plugin::get('marketplace.service_browse_execute')) ? eval($sPlugin) : false);
			
			$this->_aListings = $this->database()->select('m.*, ' . Phpfox::getUserField())
				->from($this->_sTable, 'm')
				->join(Phpfox::getT('user'), 'u', 'u.user_id = m.user_id')
				->where($this->_aConditions)
				->order($this->_sOrder)
				->limit($this->_iPage, $this->_iPageSize, $this->_iCnt)
				->execute('getSlaveRows');
				
			if (Phpfox::getLib('request')->get('view') == 'sold')
			{
				foreach ($this->_aListings as $iKey => $aListing)
				{
					list($iSoldCount, $aSoldItems) = Phpfox::getService('marketplace')->getInvoices('mi.listing_id = ' . $aListing['listing_id'] . ' AND mi.status = \'completed\'', true);
					
					$this->_aListings[$iKey]['invoices'] = $aSoldItems;
				}				
			}
		}
	}
	
	public function get()
	{
		return $this->_aListings;
	}

	public function getCount()
	{
		return $this->_iCnt;
	}	
	
	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('marketplace.service_browse__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}	
}

?>