<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package 		Phpfox_Component
 * @version 		$Id: song.class.php 1549 2010-04-14 10:42:27Z Miguel_Espinoza $
 */
class Music_Component_Controller_Browse_Song extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{		
		Phpfox::getUserParam('music.can_access_music', true);
		
		$oServiceSongBrowse = Phpfox::getService('music.song.browse');
		$sCategory = '';
		$sCategoryUrl = '';
		$iPage = $this->request()->get('page');
		$sGenre = $this->request()->get('req4', null);
		$sView = $this->request()->get('view');
		
		if (($sRedirect = $this->request()->getInt('redirect')) && ($aSong = Phpfox::getService('music')->getSong(Phpfox::getUserId(), $sRedirect, true)))
		{
			$this->url()->send($aSong['user_name'], array('music', ($aSong['album_id'] ? $aSong['album_url'] : 'view'), $aSong['title_url']));
		}
		
		$aPages = array(30, 60, 90);
		$aDisplays = array();
		foreach ($aPages as $iPageCnt)
		{
			$aDisplays[$iPageCnt] = Phpfox::getPhrase('core.per_page', array('total' => $iPageCnt));
		}		
	
		$aFilters = array(
			'display' => array(
				'type' => 'select',
				'options' => $aDisplays,
				'default' => '12'
			),
			'sort' => array(
				'type' => 'select',
				'options' => array(
					'time_stamp' => Phpfox::getPhrase('music.date_added'),
					'title' => Phpfox::getPhrase('music.name'),
					'total_score' => Phpfox::getPhrase('music.popular')
				),
				'default' => 'time_stamp',
				'alias' => 'm'
			),
			'sort_by' => array(
				'type' => 'select',
				'options' => array(
					'DESC' => Phpfox::getPhrase('core.descending'),
					'ASC' => Phpfox::getPhrase('core.ascending')
				),
				'default' => 'DESC'
			),
			'keyword' => array(
				'type' => 'input:text',
				'size' => 20,
				'search' => 'AND m.title LIKE \'%[VALUE]%\''
			)			
		);
		
		$oFilter = Phpfox::getLib('search')
			->set(array(
				'type' => 'browse',
				'filters' => $aFilters,
				'search' => 'keyword',
				'prepare' => false
			)
		);
		
		if ($sView == 'my')
		{
			$oFilter->setCondition('AND m.user_id = ' . Phpfox::getUserId());
		}
		else 
		{
			switch ($sView)
			{
				case 'featured':
					$oFilter->setCondition('AND m.is_featured = 1');	
					break;
				case 'popular':
					$oFilter->setSort('total_score');					
					break;
				case 'pending':
					if (Phpfox::getUserParam('music.can_approve_songs'))
					{
						$oFilter->setCondition('AND m.view_id = 1');	
					}
					break;
				default:
					
					break;
			}
			
			if (!Phpfox::getUserParam('music.can_approve_songs'))
			{
				$oFilter->setCondition('AND m.view_id = 0');
			}
		}
		if ($this->request()->getInt('sponsor') == 1)
		{
		    Phpfox::addMessage(Phpfox::getPhrase('music.sponsor_help_song'));
		    $oFilter->setCondition('AND m.is_sponsor != 1');
		}
		$oServiceSongBrowse->condition($oFilter->getConditions())
			->genre($sGenre)
			->category($sCategory)
			->order($oFilter->getSort())
			->page($iPage)
			->size($oFilter->getDisplay())
			->execute();						
			
		Phpfox::getLib('pager')->set(array('page' => $iPage, 'size' => $oFilter->getDisplay(), 'count' => $oFilter->getSearchTotal($oServiceSongBrowse->getCount())));		
		
		$iFilterCount = 0;
		$aFilterMenuCache = array();
		if (!defined('PHPFOX_IS_USER_PROFILE'))
		{
			$aFilterMenu = array(
				Phpfox::getPhrase('music.recent_songs') => '',
				Phpfox::getPhrase('music.featured') => 'featured',
				Phpfox::getPhrase('music.popular') => 'popular'
			);		
			
			if (Phpfox::getUserParam('music.can_approve_songs'))
			{
				$aFilterMenu[Phpfox::getPhrase('music.pending')] = 'pending';
			}			
			
			foreach ($aFilterMenu as $sMenuName => $sMenuLink)
			{
				$iFilterCount++;
				$aFilterMenuCache[] = array(
					'name' => $sMenuName,
					'link' => $this->url()->makeUrl('music.browse.song' . (empty($sGenre) ? '' : $sGenre), array('view' => $sMenuLink)),
					'active' => ($sView == $sMenuLink ? true : false),
					'last' => (count($aFilterMenu) === $iFilterCount ? true : false)
				);	
				
				if ($sView == $sMenuLink)
				{
					$this->template()->setTitle($sMenuName)->setBreadcrumb($sMenuName, null, true);
				}
			}	
			
			if (empty($sView))
			{				
				$this->template()->setTitle(Phpfox::getPhrase('music.recent_songs'))->setBreadcrumb(Phpfox::getPhrase('music.recent_songs'), null, true);
			}		
		}
		
		if (Phpfox::getParam('music.music_index_controller') == 'song' && $this->request()->get('req3') != 'song')
		{
			$this->template()->setTitle(Phpfox::getPhrase('music.music'))
				->setBreadcrumb(Phpfox::getPhrase('music.music'), $this->url()->makeUrl('music'));				
		}
		else 
		{
			$this->template()->setTitle(Phpfox::getPhrase('music.music_songs'))
				->setBreadcrumb(Phpfox::getPhrase('music.music'), $this->url()->makeUrl('music'))
				->setBreadcrumb(Phpfox::getPhrase('music.songs'), null, true);
		}
		
		$this->template()
			->setHeader('cache', array(
					'pager.css' => 'style_css',
					'player/' . Phpfox::getParam('core.default_music_player') . '/phpfox.js' => 'static_script'										
				)
			)
			->setHeader(array(
					'<script type="text/javascript">$(function() { Phpfox.player.load({id: \'js_music_player\', type: \'music\'}); });</script>'			
				)
			)			
			->assign(array(
				'aSongs' => $oServiceSongBrowse->get(),
				'aFilterMenus' => $aFilterMenuCache,
				'sCategoryUrl' => $sGenre,
				'sParentLink' => '.browse.song',
				'iSongApproveCnt' => (Phpfox::getUserParam('music.can_approve_songs') ? Phpfox::getService('music')->getPendingTotal() : 0)
			)
		);
	}
	
	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('music.component_controller_browse_song_clean')) ? eval($sPlugin) : false);
	}
}

?>