<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package 		Phpfox_Service
 * @version 		$Id: album.class.php 1496 2010-03-05 17:15:05Z Raymond_Benc $
 */
class Music_Service_Album_Album extends Phpfox_Service 
{
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('music_album');
	}
	
	/**
	 * @todo Add perms.
	 *
	 * @param unknown_type $iId
	 * @return unknown
	 */
	public function getForEdit($iId)
	{
		$aAlbum = $this->database()->select('ma.*, mat.text, u.user_name')
			->from($this->_sTable, 'ma')			
			->join(Phpfox::getT('music_album_text'), 'mat', 'mat.album_id = ma.album_id')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = ma.user_id')
			->where('ma.album_id = ' . (int) $iId)
			->execute('getRow');
			
		if (!isset($aAlbum['album_id']))
		{
			return Phpfox_Error::display(Phpfox::getPhrase('music.unable_to_find_the_album_you_want_to_edit'));
		}
		
		if (($aAlbum['user_id'] == Phpfox::getUserId() && Phpfox::getUserParam('music.can_edit_own_albums')) || Phpfox::getUserParam('music.can_edit_other_music_albums'))
		{
			return $aAlbum;	
		}
		
		return Phpfox_Error::set(Phpfox::getPhrase('music.unable_to_edit_this_album'));
	}
	
	public function getTracks($iUserId, $iId, $bCanViewAll = false)
	{				
		static $aSongs = null;
		
		if ($aSongs === null)
		{
			$aSongs = Phpfox::getService('music')->getSongs($iUserId, $iId, null, $bCanViewAll);
		}
		
		return $aSongs;
	}
	
	public function getForUpload()
	{
		return $this->database()->select('ma.album_id, ma.name')
			->from($this->_sTable, 'ma')
			->where('ma.view_id = 0 AND ma.user_id = ' . Phpfox::getUserId())
			->order('ma.name ASC')
			->execute('getSlaveRows');		
	}
	
	public function getForProfile($iUserId, $iLimit = 4)
	{
		return $this->database()->select('ma.name, ma.name_url, ma.year, ma.image_path, ma.server_id, ma.total_track, ma.total_play, ma.time_stamp')
			->from($this->_sTable, 'ma')
			->where('ma.view_id = 0 AND ma.user_id = ' . (int) $iUserId)
			->order('ma.time_stamp DESC')
			->limit($iLimit)
			->execute('getSlaveRows');
	}
	
	public function getAlbum($iUserId, $sAlbum)
	{
		$aAlbum = $this->database()->select('ma.*, ' . (Phpfox::getParam('core.allow_html') ? 'mat.text_parsed' : 'mat.text') . ' AS text, u.user_name, vr.rate_id AS has_rated')
			->from($this->_sTable, 'ma')
			->join(Phpfox::getT('music_album_text'), 'mat', 'mat.album_id = ma.album_id')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = ma.user_id')
			->leftJoin(Phpfox::getT('music_album_rating'), 'vr', 'vr.item_id = ma.album_id AND vr.user_id = ' . Phpfox::getUserId())
			->where('ma.view_id = 0 AND ma.user_id = ' . (int) $iUserId . ' AND ma.name_url = \'' . $this->database()->escape($sAlbum) . '\'')
			->execute('getSlaveRow');
			
		$aAlbum['bookmark'] = Phpfox::getLib('url')->makeUrl($aAlbum['user_name'], array('music', $aAlbum['name_url']));
			
		return $aAlbum;
	}
	
	public function getForPlayer($iId)
	{
		return $this->database()->select('ma.*, ' . (Phpfox::getParam('core.allow_html') ? 'mat.text_parsed' : 'mat.text') . ' AS text')
			->from($this->_sTable, 'ma')
			->join(Phpfox::getT('music_album_text'), 'mat', 'mat.album_id = ma.album_id')
			->where('ma.album_id = ' . (int) $iId . ' AND ma.view_id = 0')
			->execute('getSlaveRow');		
	}
	
	public function getNextSong($iAlbumId, $iLastSongId)
	{
		$aSongs = $this->database()->select('ms.song_id, ms.song_path')
			->from(Phpfox::getT('music_song'), 'ms')
			->where('ms.album_id = ' . (int) $iAlbumId)
			->order('ms.ordering ASC, ms.time_stamp DESC')
			->execute('getSlaveRows');
			
		$iNextSong = 0;
		foreach ($aSongs as $iKey => $aSong)
		{
			if ($aSong['song_id'] == $iLastSongId)
			{
				$iNextSong = ($iKey + 1);	
			}
		}
				
		return (isset($aSongs[$iNextSong]) ? $aSongs[$iNextSong] : false);
	}
	
	public function getLatestAlbums()
	{
		$aAlbums = $this->database()->select('ma.*, ' . Phpfox::getUserField())
			->from($this->_sTable, 'ma')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = ma.user_id')
			->where('ma.view_id = 0')
			->limit(10)
			->execute('getSlaveRows');
			
		return $aAlbums;
	}
	
	public function getFeaturedAlbums()
	{
		$aAlbums = $this->database()->select('ma.*, ' . Phpfox::getUserField())
			->from($this->_sTable, 'ma')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = ma.user_id')
			->where('ma.view_id = 0 AND ma.is_featured = 1')
			->limit(3)
			->execute('getSlaveRows');
			
		return $aAlbums;
	}	
	
	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('music.service_album_album__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}	
}

?>