<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package 		Phpfox_Service
 * @version 		$Id: browse.class.php 1496 2010-03-05 17:15:05Z Raymond_Benc $
 */
class Music_Service_Album_Browse extends Phpfox_Service 
{
	private $_aConditions = array();
	
	private $_iCnt = 0;
	
	private $_iPage = 0;
	
	private $_iPageSize = 25;
	
	private $_sOrder = 'm.is_featured DESC, m.time_stamp DESC';
	
	private $_aListings = array();
	
	private $_sCategory = null;
	
	private $_sGenre = null;	
	
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('music_album');
	}
	
	public function condition($aConditions)
	{
		$this->_aConditions = $aConditions;
		
		return $this;
	}
	
	public function page($iPage)
	{
		$this->_iPage = $iPage;
		
		return $this;
	}
	
	public function size($iPageSize)
	{
		$this->_iPageSize = $iPageSize;
		
		return $this;
	}
	
	public function category($sCategory)
	{
		$this->_sCategory = $sCategory;
		
		return $this;
	}
	
	public function order($sOrder)
	{
		if ($sOrder != 'm.time_stamp DESC')
		{		
			$this->_sOrder = $sOrder;
		}
		
		return $this;
	}	
	
	public function genre($sGenre)
	{
		$this->_sGenre = $sGenre;
		
		return $this;
	}	
	
	public function execute()
	{		
		if ($this->_sGenre !== null)
		{		
			$this->database()				
				->join(Phpfox::getT('music_genre'), 'mg', 'mg.name_url = \'' . $this->database()->escape($this->_sGenre) . '\'')
				->join(Phpfox::getT('music_genre_user'), 'mgu', 'mgu.user_id = m.user_id AND mgu.genre_id = mg.genre_id')
				->group('m.album_id');
		}		
		
		$this->_iCnt = $this->database()->select('COUNT(*)')
			->from($this->_sTable, 'm')
			->where($this->_aConditions)
			->execute('getSlaveField');
			
		if ($this->_iCnt)
		{			
			if ($this->_sGenre !== null)
			{			
				$this->database()
					->select('mg.name AS genre_name, ')		
					->join(Phpfox::getT('music_genre'), 'mg', 'mg.name_url = \'' . $this->database()->escape($this->_sGenre) . '\'')
					->join(Phpfox::getT('music_genre_user'), 'mgu', 'mgu.user_id = m.user_id AND mgu.genre_id = mg.genre_id')
					->group('m.album_id');
			}					
			
			$this->_aListings = $this->database()->select('m.*, vr.rate_id AS has_rated, ' . Phpfox::getUserField())
				->from($this->_sTable, 'm')
				->join(Phpfox::getT('user'), 'u', 'u.user_id = m.user_id')
				->leftJoin(Phpfox::getT('music_album_rating'), 'vr', 'vr.item_id = m.album_id AND vr.user_id = ' . Phpfox::getUserId())				
				->where($this->_aConditions)
				->order($this->_sOrder)
				->limit($this->_iPage, $this->_iPageSize, $this->_iCnt)
				->execute('getSlaveRows');					
		}
	}
	
	public function get()
	{
		return $this->_aListings;
	}

	public function getCount()
	{
		return $this->_iCnt;
	}	
	
	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('marketplace.service_browse__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}	
}

?>