<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Music
 * @version 		$Id: music.class.php 2373 2011-03-14 15:07:25Z Miguel_Espinoza $
 */
class Music_Service_Music extends Phpfox_Service 
{
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('music_song');
	}
	
	public function getSongs($iUserId, $iAlbumId = null, $iLimit = null, $bCanViewAll = false)
	{
		$aSongs = $this->database()->select('ms.song_id, ms.is_sponsor, ms.user_id, ms.album_id, ms.title, ms.title_url, ms.song_path, ms.is_featured, ms.view_id, ms.server_id, ms.explicit, ms.duration, ms.time_stamp, ma.name_url AS album_url, u.user_name, mp.play_id AS is_on_profile, mp.user_id AS profile_user_id, ' . Phpfox::getUserField())
			->from($this->_sTable, 'ms')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = ms.user_id')
			->leftJoin(Phpfox::getT('music_album'), 'ma', 'ma.album_id = ms.album_id')
			->leftJoin(Phpfox::getT('music_profile'), 'mp', 'mp.song_id = ms.song_id AND mp.user_id = ' . Phpfox::getUserId())
			->where(($bCanViewAll === false ? 'ms.view_id = 0 AND' : '') . ($iAlbumId === null ? '' : ' ms.album_id = ' . (int) $iAlbumId . ' AND') . ' ms.user_id = ' . (int) $iUserId)
			->order('ms.ordering ASC, ms.time_stamp DESC')
			->limit($iLimit)
			->execute('getSlaveRows');
			
		foreach ($aSongs as $iKey => $aSong)
		{
			$aSongs[$iKey]['song_path'] = $this->getSongPath($aSong['song_path'], $aSong['server_id']);
		}
		
		return $aSongs;
	}
	
	public function getForProfile($iUserId, $iLimit = null)
	{
		$aSongs = $this->database()->select('ms.song_id, ms.user_id, ms.album_id, ms.title, ms.title_url, ms.song_path, ms.is_featured, ms.view_id, ms.server_id, ms.explicit, ms.duration, ms.time_stamp, ma.name_url AS album_url, u.user_name, mp.play_id AS is_on_profile, mp.user_id AS profile_user_id, ' . Phpfox::getUserField())
			->from(Phpfox::getT('music_profile'), 'mp')
			->join($this->_sTable, 'ms', 'ms.song_id = mp.song_id')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = ms.user_id')
			->leftJoin(Phpfox::getT('music_album'), 'ma', 'ma.album_id = ms.album_id')
			->where('mp.user_id = ' . (int) $iUserId)
			->order('ms.time_stamp DESC')
			->limit($iLimit)
			->execute('getSlaveRows');

		foreach ($aSongs as $iKey => $aSong)
		{
			$aSongs[$iKey]['song_path'] = $this->getSongPath($aSong['song_path'], $aSong['server_id']);
		}		
		
		return $aSongs;		
	}
	
	public function getSong($iUserId, $sSongId, $bUseId = false)
	{
		$aSong = $this->database()->select('ms.*, ms.total_comment as song_total_comment, ms.total_play as song_total_play, ms.time_stamp as song_time_stamp, ms.is_sponsor AS song_is_sponsor, ma.name_url AS album_url, ma.*, mp.play_id AS is_on_profile, mp.user_id AS profile_user_id, vr.rate_id AS has_rated, ' . Phpfox::getUserField())
			->from($this->_sTable, 'ms')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = ms.user_id')
			->leftJoin(Phpfox::getT('music_album'), 'ma', 'ma.album_id = ms.album_id')
			->leftJoin(Phpfox::getT('music_profile'), 'mp', 'mp.song_id = ms.song_id AND mp.user_id = ' . Phpfox::getUserId())
			->leftJoin(Phpfox::getT('music_song_rating'), 'vr', 'vr.item_id = ms.song_id AND vr.user_id = ' . Phpfox::getUserId())
			->where('ms.user_id = ' . (int) $iUserId . ' AND ' . ($bUseId ? 'ms.song_id' : 'ms.title_url') . ' = \'' . $this->database()->escape($sSongId) . '\'')
			->execute('getSlaveRow');		
		
		if (!isset($aSong['song_id']))
		{
			return false;
		}
		
		if ($aSong['view_id'] == '1')
		{
			if ($aSong['user_id'] == Phpfox::getUserId() || Phpfox::getUserParam('music.can_approve_songs'))
			{
				
			}
			else 
			{
				return false;
			}
		}
			
		$aSong['song_path'] = $this->getSongPath($aSong['song_path'], $aSong['server_id']);
		$aSong['bookmark'] = Phpfox::getLib('url')->makeUrl($aSong['user_name'], array('music', ($aSong['album_id'] ? $aSong['album_url'] : 'view'), $aSong['title_url']));
		if (!isset($aSong['song_total_comment']))
		{
		    $aSong['song_total_comment'] = 0;
		}
		return $aSong;	
	}

	public function getSongPath($sSong, $iServerId = null)
	{
		if (preg_match("/\{file\/music_folder\/(.*)\.mp3\}/i", $sSong, $aMatches))
		{
			return Phpfox::getParam('core.path') . str_replace(array('{', '}'), '', $aMatches[0]);
		}
		$sSong = Phpfox::getParam('music.url') . sprintf($sSong, '');	
		
		if (Phpfox::getParam('core.allow_cdn') && !empty($iServerId))
		{
			//$sSong = Phpfox::getLib('cdn')->getUrl($sSong);
			$sTempSong = Phpfox::getLib('cdn')->getUrl($sSong);
			if (!empty($sTempSong))
			{
				$sSong = $sTempSong;
			}
		}
		
		return $sSong;
	}
	
	public function getLatestSongs()
	{
		$aSongs = $this->database()->select('ms.song_id, ms.user_id, ms.album_id, ms.title, ms.title_url, ms.song_path, ms.server_id, ms.explicit, ms.duration, ms.time_stamp, ma.name_url AS album_url, u.user_name, mp.play_id AS is_on_profile, mp.user_id AS profile_user_id, ' . Phpfox::getUserField())
			->from($this->_sTable, 'ms')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = ms.user_id')
			->leftJoin(Phpfox::getT('music_album'), 'ma', 'ma.album_id = ms.album_id')
			->leftJoin(Phpfox::getT('music_profile'), 'mp', 'mp.song_id = ms.song_id AND mp.user_id = ' . Phpfox::getUserId())
			->where('ms.view_id = 0')
			->order('ms.time_stamp DESC')
			->limit(10)
			->execute('getSlaveRows');
			
		foreach ($aSongs as $iKey => $aSong)
		{
			$aSongs[$iKey]['song_path'] = $this->getSongPath($aSong['song_path'], $aSong['server_id']);
		}		
		
		return $aSongs;
	}
	
	public function getFeaturedSongs()
	{		
		$sCacheId = $this->cache()->set('music_song_featured');
		
		if (!($aSongs = $this->cache()->get($sCacheId)))
		{		
			$aSongs = $this->database()->select('ms.song_id, ms.user_id, ms.album_id, ms.title, ms.title_url, ms.song_path, ms.server_id, ms.explicit, ms.duration, ms.time_stamp, ma.name_url AS album_url, u.user_name, ' . Phpfox::getUserField())
				->from($this->_sTable, 'ms')
				->join(Phpfox::getT('user'), 'u', 'u.user_id = ms.user_id')
				->leftJoin(Phpfox::getT('music_album'), 'ma', 'ma.album_id = ms.album_id')
				->where('ms.view_id = 0 AND ms.is_featured = 1')
				->order('ms.time_stamp DESC')
				->limit(3)
				->execute('getSlaveRows');
				
			foreach ($aSongs as $iKey => $aSong)
			{
				$aSongs[$iKey]['url'] = Phpfox::getLib('url')->makeUrl($aSong['user_name'], array('music', (!empty($aSong['album_url']) ? $aSong['album_url'] : 'view'), $aSong['title_url']));
			}
			
			$this->cache()->save($sCacheId, $aSongs);
		}
		
		return $aSongs;
	}

	public function getRandomSponsoredSongs()
	{
	    $sCacheId = $this->cache()->set('music_song_sponsored');
	    if (!($aSongs = $this->cache()->get($sCacheId)))
	    {
		$aSongs = $this->database()->select('ms.*, ma.*, u.user_name, s.*')
			->from($this->_sTable, 'ms')
			->leftjoin(Phpfox::getT('music_album'), 'ma', 'ma.album_id = ms.album_id')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = ms.user_id')
			->join(Phpfox::getT('ad_sponsor'), 's', 's.item_id = ms.song_id')
			->where('ms.view_id = 0 AND ms.is_sponsor = 1 AND s.module_id = "music-song"')
			->execute('getSlaveRows');

		$this->cache()->save($sCacheId, $aSongs);
	    }
	    if (!isset($aSongs[0]) || empty($aSongs[0]))
	    {
		return array();
	    }
	    $aOut = array();
	    shuffle($aSongs);
	    for ($i = 0; ($i < Phpfox::getParam('music.sponsored_songs_to_show')) && !empty($aSongs); ++$i)
	    {
		$aOut[] = array_pop($aSongs);
	    }
	    return $aOut;
	}

	public function getRandomSponsoredAlbum()
	{
	    $sCacheId = $this->cache()->set('music_album_sponsored');
	    if (!($aAlbums = $this->cache()->get($sCacheId)))
	    {
		$aAlbums = $this->database()->select('s.sponsor_id, m.name, m.year, m.total_track, m.server_id, m.image_path, m.name_url, m.user_id,' . Phpfox::getUserField())
			->from(Phpfox::getT('music_album'), 'm')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = m.user_id')
			->join(Phpfox::getT('ad_sponsor'), 's', 's.item_id = m.album_id')
			->where('m.view_id = 0 AND m.is_sponsor = 1 AND s.module_id = "music-album"')
			->execute('getSlaveRows');
			
		$this->cache()->save($sCacheId, $aAlbums);
	    }
	    
	    if (empty($aAlbums) || !is_array($aAlbums))
	    {
		return array();
	    }

	    shuffle($aAlbums);
	    return array_pop($aAlbums);
	}

	public function getPendingTotal()
	{
		return $this->database()->select('COUNT(*)')
			->from($this->_sTable)
			->where('view_id = 1')
			->execute('getSlaveField');
	}	
	
	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('music.service_music__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}	
}

?>