<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * Class controls all AJAX requests related to the photo module.
 *
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Photo
 * @version 		$Id: ajax.class.php 2437 2011-03-24 12:27:58Z Raymond_Benc $
 */
class Photo_Component_Ajax_Ajax extends Phpfox_Ajax
{
    /**
     * Displays the form that adds a new photo album.
     *
     */
    public function newAlbum()
    {
	// Only users can view this form.
	Phpfox::isUser(true);
	// Only users with this specific user group perm. can view this form.
	Phpfox::getUserParam('photo.can_create_photo_album', true);
	// Display the block form
	Phpfox::getBlock('photo.album');
    }

    /**
     * Add a new album into the database
     *
     * @return boolean Return false only to exit the call earlier.
     */
    public function addAlbum()
    {
		// Only users can view this form.
		Phpfox::isUser(true);
		// Only users with this specific user group perm. can view this form.
		Phpfox::getUserParam('photo.can_create_photo_album', true);
		// Get the total number of albums this user has
		$iTotalAlbums = Phpfox::getService('photo.album')->getAlbumCount(Phpfox::getUserId());
		// Check if they are allowed to create new albums
		$bAllowedAlbums = (Phpfox::getUserParam('photo.max_number_of_albums') == 'null' ? true : (!Phpfox::getUserParam('photo.max_number_of_albums') ? false : (Phpfox::getUserParam('photo.max_number_of_albums') <= $iTotalAlbums ? false : true)));

		// Are they allowed to create new albums?
		if (!$bAllowedAlbums)
		{
			// They have reached their limit
			$this->alert(Phpfox::getPhrase('photo.you_have_reached_your_limit_you_are_currently_unable_to_create_new_photo_albums'));

			return false;
		}

		// Assigned the post vals
		$aVals = $this->get('val');

		// Add the photo album
		if ($iId = Phpfox::getService('photo.album.process')->add($aVals))
		{
			$this->alert(Phpfox::getPhrase('photo.album_successfully_created'));
			$this->call('setTimeout(tb_remove, 1000);');
			
			// All went well, add the new album to our form and close the AJAX popup.
			$this->show('#js_photo_albums')
				->append('#js_photo_album_select', '<option value="' . $iId. '" selected="selected">' . Phpfox::getLib('parse.output')->clean(Phpfox::getLib('parse.input')->clean($aVals['name'])) . '</option>')
				->call('$(\'#js_album_form\').hide();$(\'#js_upload_form\').show();					$(\'#js_create_new_album\')[0].reset();					$(\'.js_cached_friend_name\').remove();					$(\'#js_allow_list_input\').hide();					if (swfu != undefined){swfu.addPostParam(\'album_id\', '.$iId.');}');
		}
    }

    /**
     * Displays the photo index page using the pagination.
     *
     */
    public function browse()
    {
	Phpfox::getLib('module')->getComponent('photo.index', $this->getAll(), 'controller');

	$this->call('$(\'#site_content\').html(\'' . $this->getContent() . '\'); $.scrollTo(\'#site_content\', 340); Behavior.hoverAction(); Behavior.imageHoverHolder();');
    }

    /**
     * Browse a users album
     *
     */
    public function browseUserAlbum()
    {
	Phpfox::getLib('module')->getComponent('photo.profile', $this->getAll(), 'controller');

	$this->call('$(\'#js_user_photo_albums\').html(\'' . $this->getContent() . '\'); $.scrollTo(\'#js_user_photo_albums_outer\', 340);');
    }

    /**
     * Browse a users album
     *
     */
    public function browseAlbum()
    {
	Phpfox::getLib('module')->getComponent('photo.album', $this->getAll(), 'controller');

	$this->call('$(\'#js_album_content\').html(\'' . $this->getContent() . '\'); $.scrollTo(\'#js_album_content\', 340);');
    }

    /**
     * Browser a set of photos by a user
     *
     */
    public function browseUserPhotos()
    {
	Phpfox::getLib('module')->getComponent('photo.profile', $this->getAll(), 'controller');

	$this->call('$(\'#js_user_photos\').html(\'' . $this->getContent() . '\'); $.scrollTo(\'#js_user_photos_outer\', 340); Behavior.hoverAction(); Behavior.imageHoverHolder();');
    }

    /**
     * Refresh the featured image and reset the refresh time.
     *
     */
    public function refreshFeaturedImage()
    {
	Phpfox::getBlock('photo.featured');

	$this->html('#js_block_content_featured_photo', $this->getContent(false))->call('setTimeout("$.ajaxCall(\'photo.refreshFeaturedImage\');", ' + Phpfox::getService('photo')->getFeaturedRefreshTime() + ');');
    }

    public function updateAlbumTitle()
    {
	Phpfox::isUser(true);

	if (Phpfox::getLib('parse.format')->isEmpty($this->get('quick_edit_input')))
	{
	    $this->alert('Add a title.');

	    return false;
	}

	if (Phpfox::getService('user.auth')->hasAccess('photo_album', 'album_id', $this->get('album_id'), 'photo.can_edit_own_photo_album', 'photo.can_edit_other_photo_albums') && Phpfox::getService('photo.album.process')->updateTitle($this->get('album_id'), $this->get('quick_edit_input')))
	{
	    $this->html('#' . $this->get('id'), '<a href="' . Phpfox::getLib('url')->makeUrl($this->get('user_name'), array('photo', $this->get('old_title'))) . '" id="js_ge_edit_inner_title' . $this->get('album_id') . '">' . Phpfox::getLib('parse.output')->clean(Phpfox::getLib('parse.input')->clean($this->get('quick_edit_input'))) . '</a>', '.highlightFade()');
	}
    }

    public function updateAlbum()
    {
	Phpfox::isUser(true);

	$aVals = $this->get('val');

	if (Phpfox::getService('user.auth')->hasAccess('photo_album', 'album_id', $aVals['album_id'], 'photo.can_edit_own_photo_album', 'photo.can_edit_other_photo_albums') && Phpfox::getService('photo.album.process')->update($aVals['album_id'], $aVals))
	{
	    $oParseInput = Phpfox::getLib('parse.input');
	    $oParseOutput = Phpfox::getLib('parse.output');

	    if (isset($aVals['inline']))
	    {
		$sTitle = $oParseOutput->clean($oParseInput->clean($aVals['name']));

		$this->hide('#js_album_edit_form')
			->call('$(\'#js_album_inner_title_link_' . $aVals['album_id'] . '\').attr(\'title\', \'' . $sTitle . '\');')
			->html('#js_album_inner_title_' . $aVals['album_id'], $sTitle)
			->show('#js_user_photo_albums')
			->html('#js_updating_album', ' - <a href="#" onclick="$(\'#js_album_edit_form\').hide(); $(\'#js_user_photo_albums\').show(); return false;">' . Phpfox::getPhrase('photo.cancel') . '</a>');
	    }
	    else
	    {
		$this->html('#js_ge_edit_inner_title' . $aVals['album_id'], $oParseOutput->clean($oParseInput->clean($aVals['name'])))
			->html('#js_album_description', $oParseOutput->clean($oParseInput->clean($aVals['description'])))
			->html('#js_updating_album', ' - <a href="#" id="js_album_cancel_edit">' . Phpfox::getPhrase('photo.cancel') . '</a>');
	    }
	}
    }

    public function updatePhoto()
    {
		$aVals = $this->get('val');
	
		if (($iUserId = Phpfox::getService('user.auth')->hasAccess('photo', 'photo_id', $aVals['photo_id'], 'photo.can_edit_own_photo', 'photo.can_edit_other_photo')) && Phpfox::getService('photo.process')->update($iUserId, $aVals['photo_id'], $aVals))
		{
		    $oParseInput = Phpfox::getLib('parse.input');
		    $oParseOutput = Phpfox::getLib('parse.output');
	
		    if (isset($aVals['full_edit']))
		    {
				$aPhoto = Phpfox::getService('photo')->getForEdit($aVals['photo_id']);
	
				if ($aPhoto['group_id'] > 0 && Phpfox::isModule('group'))
				{
				    $aGroup = Phpfox::getService('group')->getForEdit($aPhoto['group_id']);
				    if ($aGroup !== false)
				    {
					$this->call('window.location.href = "' . Phpfox::getLib('url')->makeUrl('group', array($aGroup['title_url'], 'photo', ($aPhoto['album_id'] ? $aPhoto['album_url'] : 'view'), $aPhoto['title_url'])) . '";');
				    }
				}
				else
				{
				    $this->call('window.location.href = "' . Phpfox::getLib('url')->makeUrl($aPhoto['user_name'], array('photo', ($aPhoto['album_id'] ? $aPhoto['album_url'] : 'view'), $aPhoto['title_url'])) . '";');
				}
		    }
		    else
		    {
				$this->html('#js_photo_title_' . $aVals['photo_id'], $oParseOutput->clean($oParseInput->clean($aVals['title'])))->html('#js_photo_description_' . $aVals['photo_id'], $oParseOutput->clean($oParseInput->clean($aVals['description'])));
		    }
		}
    }

    /**
     * Set an album cover
     *
     */
    public function setAlbumCover()
    {
	if (Phpfox::getService('user.auth')->hasAccess('photo_album', 'album_id', $this->get('album_id'), 'photo.can_edit_own_photo_album', 'photo.can_edit_other_photo_albums') && Phpfox::getService('photo.album.process')->setCover($this->get('album_id'), $this->get('photo_id')))
	{

	}
    }

    /**
     * After uploading a photo we give an option that allows users the ability
     * to delete their photos on the spot. This method does that job for us.
     *
     */
    public function deleteNewPhoto()
    {
	// Only users can view this form.
	Phpfox::isUser(true);

	// Delete the photo.
	if (Phpfox::getService('photo.process')->delete($this->get('id')))
	{

	}
    }

    public function deletePhoto()
    {
	Phpfox::isUser(true);

	if (Phpfox::getService('photo.process')->delete($this->get('photo_id')))
	{
	    $this->remove('#js_photo_id_' . $this->get('photo_id'))
		    ->call('$(\'#js_pager_to\').html((parseInt($(\'#js_pager_to\').html()) - 1));')
		    ->call('$(\'#js_pager_total\').html((parseInt($(\'#js_pager_total\').html()) - 1));');
	}
    }

    public function editPhoto()
    {
	Phpfox::isUser(true);

	if (Phpfox::getService('user.auth')->hasAccess('photo', 'photo_id', $this->get('photo_id'), 'photo.can_edit_own_photo', 'photo.can_edit_other_photo'))
	{
	    $aPhoto = Phpfox::getService('photo')->getForEdit($this->get('photo_id'));

	    echo '<div><input type="hidden" name="val[photo_id]" value="' . $aPhoto['photo_id'] . '" /></div>';
	    $this->template()->assign(array(
		    'aForms' => $aPhoto
		    )
		    )
		    ->getTemplate('photo.block.form');

	    $this->html('#js_photo_edit_form', $this->getContent(false))
		    ->show('#js_photo_edit_form_outer')
		    ->hide('#js_album_edit_form')
		    ->hide('#js_album_outer_content')
		    ->call('$(\'#js_photo_id_' . $this->get('photo_id') . '\').find(\'.hover_action_div\').hide();')
		    ->call('Phpfox.loadInit();');
	}
    }

    public function warning()
    {		
    	Phpfox::getBlock('photo.warning');
    }

    public function getPhotosForRating()
    {
	Phpfox::isUser(true);
	Phpfox::getUserParam('photo.can_rate_on_photos', true);

	(($sPlugin = Phpfox_Plugin::get('photo.component_ajax_getphotosforrating_start')) ? eval($sPlugin) : false);

	$aPhotos = $this->get('photo_id');

	if (is_array($aPhotos) && Phpfox::getService('photo.rate.process')->add($this->get('photo_id')))
	{

	}

	$sCategory = null;
	$aRequests = Phpfox::getLib('request')->getRequests();
	foreach ($aRequests as $sKey => $sValue)
	{
	    if (!preg_match("/req[0-9]/", $sKey))
	    {
		continue;
	    }

	    if ($sKey != 'req1' && $sKey != 'req2')
	    {
		$sCategory = $sValue;
	    }
	}

	$sPhotos = Phpfox::getService('photo.rate')->getJavaScript($sCategory);

	if ($sPhotos === false)
	{
	    $this->html('#site_content', '<div class="extra_info">' . Phpfox::getPhrase('photo.you_have_rated_all_the_available_images', array('phpfox_squote' => true)) . '</a>');
	}
	else
	{
	    $this->call('Phpfox.PhotoRate.populate({' . $sPhotos . '}});');
	}

	(($sPlugin = Phpfox_Plugin::get('photo.component_ajax_getphotosforrating_end')) ? eval($sPlugin) : false);
    }

    public function battle()
    {
	$aPhotos = $this->get('photo_id');

	if (is_array($aPhotos) && Phpfox::getService('photo.battle.process')->add($aPhotos))
	{

	}

	$sCategory = $this->get('category');
	if (empty($sCategory))
	{
	    $sCategory = null;
	}

	$sJavaScript = Phpfox::getService('photo.battle')->getJavaScript($sCategory);

	$this->call('Phpfox.photoBattle.populate(' . $sJavaScript . ');');
    }

    public function getCategoryForEdit()
    {
	Phpfox::isUser(true);
	Phpfox::getUserParam('photo.can_edit_photo_categories', true);

	$aCategory = Phpfox::getService('photo.category')->getCategory($this->get('id'));

	$this->call('$(\'#js_photo_category_' . $aCategory['parent_id'] . '\').attr(\'selected\', true);');

	$this->html('#js_photo_table_header', Phpfox::getPhrase('photo.editing_category') . ': ' . $aCategory['name'])
		->html('#js_photo_hidden', '<input type="hidden" name="val[edit_id]" value="' . $aCategory['category_id'] . '" />')
		->html('#js_photo_extra_button', ' <input type="button" name="" value="' . Phpfox::getPhrase('photo.cancel') . '" class="button" onclick="$(\'#js_photo_category_' . $aCategory['parent_id'] . '\').attr(\'selected\', false); $(\'#js_category_holder\').show(); $(\'#js_photo_table_header\').html(\'Add a Photo Category\'); $(\'#js_photo_extra_button\').html(\'\'); $(\'#js_photo_hidden\').html(\'\'); $(\'#name\').val(\'\');" /> <input type="submit" value="Delete" onclick="return confirm(\'' . Phpfox::getPhrase('photo.are_you_sure') . '\');" class="button" name="val[delete]" />')
		->val('#name', $aCategory['name']);
    }

    public function approvePhoto()
    {
	Phpfox::isUser(true);
	Phpfox::getUserParam('photo.can_approve_photos', true);

	if (Phpfox::getService('photo.process')->approve($this->get('photo_id')))
	{
	    $this->removeClass('#js_photo_id_' . $this->get('photo_id'), 'row_moderate')->remove('#js_photo_approve_' . $this->get('photo_id'));
	}
    }

    public function getNew()
    {
	Phpfox::getBlock('photo.new');

	$this->html('#' . $this->get('id'), $this->getContent(false));
	$this->call('$(\'#' . $this->get('id') . '\').parents(\'.block:first\').find(\'.bottom li a\').attr(\'href\', \'' . Phpfox::getLib('url')->makeUrl('photo') . '\');');
    }

    public function feature()
    {
	Phpfox::isUser(true);
	Phpfox::getUserParam('photo.can_feature_photo', true);

	if (Phpfox::getService('photo.process')->feature($this->get('photo_id'), $this->get('type')))
	{
	    if ($this->get('type') == '1')
	    {
		$sHtml = '<a href="#" title="' . Phpfox::getPhrase('photo.un_feature_this_photo') . '" onclick="$.ajaxCall(\'photo.feature\', \'photo_id=' . $this->get('photo_id') . '&amp;type=0\'); return false;"><img src="' . $this->template()->getStyle('image', 'misc/photo_unfeature.png') . '" alt="" width="16" height="16" /></a>';
	    }
	    else
	    {
		$sHtml = '<a href="#" title="' . Phpfox::getPhrase('photo.feature_this_photo') . '" onclick="$.ajaxCall(\'photo.feature\', \'photo_id=' . $this->get('photo_id') . '&amp;type=1\'); return false;"><img src="' . $this->template()->getStyle('image', 'misc/photo_feature.png') . '" alt="" width="16" height="16" /></a>';
	    }

	    $this->html('#js_photo_feature_' . $this->get('photo_id'), $sHtml)->alert(($this->get('type') == '1' ? Phpfox::getPhrase('photo.photo_successfully_featured') : Phpfox::getPhrase('photo.photo_successfully_un_featured')));
	    if ($this->get('type') == '1')
	    {
		$this->addClass('#js_photo_id_' . $this->get('photo_id'), 'row_featured');
	    }
	    else
	    {
		$this->removeClass('#js_photo_id_' . $this->get('photo_id'), 'row_featured');
	    }
	}
    }

    public function sponsor()
    {
	Phpfox::getUserParam('photo.can_sponsor_photo', true);
	// 0 = remove sponsor; 1 = add sponsor
	if (Phpfox::getService('photo.process')->sponsor($this->get('photo_id'), $this->get('type')))
	{
	    if ($this->get('type') == '1')
	    {
		Phpfox::getService('ad.process')->addSponsor(array('module' => 'photo', 'item_id' => $this->get('photo_id')));
		// image was sponsored
		$sHtml = '<a href="#" title="' . Phpfox::getPhrase('photo.unsponsor_this_photo') . '" onclick="$.ajaxCall(\'photo.sponsor\', \'photo_id=' . $this->get('photo_id') . '&amp;type=0\'); return false;"><img src="' . $this->template()->getStyle('image', 'misc/medal_gold_delete.png') . '" alt="'.Phpfox::getPhrase('photo.unsponsor_this_photo').'" width="16" height="16" /></a>';

	    }
	    else
	    {
		Phpfox::getService('ad.process')->deleteAdminSponsor('photo', $this->get('photo_id'));
		$sHtml = '<a href="#" title="' . Phpfox::getPhrase('photo.unsponsor_this_photo') . '" onclick="$.ajaxCall(\'photo.sponsor\', \'photo_id=' . $this->get('photo_id') . '&amp;type=1\'); return false;"><img src="' . $this->template()->getStyle('image', 'misc/medal_gold_add.png') . '" alt="'.Phpfox::getPhrase('photo.sponsor_this_photo').'" width="16" height="16" /></a>';
	    }
	    $this->html('#js_photo_sponsor_' . $this->get('photo_id'), $sHtml)->alert($this->get('type') == '1' ? Phpfox::getPhrase('photo.photo_successfully_sponsored') : Phpfox::getPhrase('photo.photo_successfully_un_sponsored'));
	    if($this->get('type') == '1')
	    {
		$this->addClass('#js_photo_id_' . $this->get('photo_id'), 'row_sponsored');
	    }
	    else
	    {
		$this->removeClass('#js_photo_id_' . $this->get('photo_id'), 'row_sponsored');
	    }
	}
    }
    public function rotate()
    {
	Phpfox::isUser(true);
	if ($aPhoto = Phpfox::getService('photo.process')->rotate($this->get('photo_id'), $this->get('photo_cmd')))
	{
	    Phpfox::getService('photo.tag.process')->deleteAll($this->get('photo_id'));

	    $this->call('window.location.href = $(\'#js_current_photo_url\').html();');
	}
    }

    public function addPhotoTag()
    {
	$aVals = $this->get('val');
	$this->val('#js_tag_user_id', '0')->val('#NoteNote', '');
	if (($sReturn = Phpfox::getService('photo.tag.process')->add($aVals['tag'])))
	{
	    $this->append('#js_photo_in_this_photo', ', ' . $sReturn)->call('$(\'#js_photo_in_this_photo\').parent().show();');
	    $this->call('$(\'#js_photo_in_this_photo\').html(ltrim($(\'#js_photo_in_this_photo\').html(), \', \'));');
	    $this->call('Phpfox.photo_tag.init({' . Phpfox::getService('photo.tag')->getJs($aVals['tag']['item_id']) . '});');
	}
    }

    public function removePhotoTag()
    {
	if ($iPhoto = Phpfox::getService('photo.tag.process')->delete($this->get('tag_id')))
	{
	    $this->call('$(\'.note\').remove(); Phpfox.photo_tag.init({' . Phpfox::getService('photo.tag')->getJs($iPhoto) . '});');
	}
    }

    public function process()
    {
		$aImagesArray = array();
		$aImages = array();
		$bMassUploader = Phpfox::getParam('photo.enable_mass_uploader') && ($this->get('sMethod', false) != 'simple');
		if ($bMassUploader)
		{
			$aImagesArray = $this->get('photos');
			if (!is_array($aImagesArray))
			{
				$aImagesArray = unserialize(base64_decode($aImagesArray));
				if (!is_array($aImagesArray))
				{
					$aImagesArray = base64_decode(unserialize($aImagesArray));
				}
				foreach ($aImagesArray as $iKey => $aTemp)
				{
					if (!isset($aTemp['completed']) && isset($aTemp[0]['completed']))
					{
						$aImages[] = $aTemp[0];
					}
					else
					{
						$aImages[] = $aTemp;
					}
				}
			}
			else
			{
				foreach ($aImagesArray as $iKey => $sJsoned)
				{
					$aTemp = unserialize(base64_decode(urldecode($sJsoned)));
					if (!isset($aTemp['completed']) && isset($aTemp[0]['completed']))
					{
						$aImages[] = $aTemp[0];
					}
					else
					{
						$aImages[] = $aTemp;
					}
				}
			}
		}
		else
		{
			$aImages = $this->get('photos');
			if (!is_array($aImages))
			{
				$aImages = unserialize(base64_decode(urldecode($this->get('photos'))));
			}
			if (!is_array($aImages[0]))
			{
				$aTemp = array();
				foreach ($aImages as $aImage)
				{
					$aTemp[] = unserialize(base64_decode(urldecode($aImage)));
				}
				$aImages = $aTemp;
			}
		}
		$aFailed = $this->get('aFailed');
		if (!empty($aFailed))
		{
			$sFailedDueToSpace = '';
			foreach ($aFailed as $iCode => $aFiles)
			{
				if ($iCode == '-110')
				{
					$sFailedDueToSpace .= implode(', ', $aFiles);
				}
			}

			if ($sFailedDueToSpace != '')
			{
				Phpfox::addMessage(Phpfox::getPhrase('photo.the_following_files_were_not_uploaded_because_their_size_exceeds_the_limit_of_ilimit_sfiles',
					array('iLimit' => Phpfox::getUserParam('photo.photo_max_upload_size').' KB', 'sFiles' => $sFailedDueToSpace)));
			}
		}
		
		$oImage = Phpfox::getLib('image');
		$iFileSizes = 0;
		$iGroupId = 0;
		$bProcess = false;
		
		foreach ($aImages as $iKey => $aImage)
		{
			if ($aImage['completed'] == 'false')
			{
				$aPhoto = Phpfox::getService('photo')->getForProcess($aImage['photo_id']);
				if (isset($aPhoto['photo_id']))
				{
					if ($aPhoto['group_id'] > 0)
					{
						$iGroupId = $aPhoto['group_id'];
					}

					$sFileName = $aPhoto['destination'];

					//$this->call('p(\'Processing photo: ' . $aPhoto['photo_id'] . '\');');

					foreach (Phpfox::getParam('photo.photo_pic_sizes') as $iSize)
					{
						// Create the thumbnail
						if ($oImage->createThumbnail(Phpfox::getParam('photo.dir_photo') . sprintf($sFileName, ''), Phpfox::getParam('photo.dir_photo') . sprintf($sFileName, '_' . $iSize), $iSize, $iSize, true, ((Phpfox::getParam('photo.enabled_watermark_on_photos') && Phpfox::getParam('core.watermark_option') != 'none') ? (Phpfox::getParam('core.watermark_option') == 'image' ? 'force_skip' : true) : false)) === false)
						{
							$this->call('p(\'Thumbnail failed: ' . $aPhoto['photo_id'] . ' (' . $iSize . ')\');');

							continue;
						}

						//$this->call('p(\'Created thumbnail: ' . $aPhoto['photo_id'] . ' (' . $iSize . ')\');');

						if (Phpfox::getParam('photo.enabled_watermark_on_photos'))
						{
							$oImage->addMark(Phpfox::getParam('photo.dir_photo') . sprintf($sFileName, '_' . $iSize));
						}

						// Add the new file size to the total file size variable
						$iFileSizes += filesize(Phpfox::getParam('photo.dir_photo') . sprintf($sFileName, '_' . $iSize));
					}

					if (Phpfox::getParam('photo.enabled_watermark_on_photos'))
					{
						$oImage->addMark(Phpfox::getParam('photo.dir_photo') . sprintf($sFileName, ''));
					}

					$aImages[$iKey]['completed'] = 'true';

					break;
				}
			}
		}

		// Update the user space usage
		Phpfox::getService('user.space')->update(Phpfox::getUserId(), 'photo', $iFileSizes);

		$iNotCompleted = 0;
		foreach ($aImages as $iKey => $aImage)
		{
			if ($aImage['completed'] == 'false')
			{
				$iNotCompleted++;
			}
		}
		if ($iNotCompleted === 0)
		{
			//$this->call('p(\'Photo process completed.\');');
			
			// Only display the photo block if the user plans to upload more pictures
			if ($this->get('action') == 'view_photo')
			{
				Phpfox::addMessage((count($aImages) == 1 ? Phpfox::getPhrase('photo.photo_successfully_uploaded') : Phpfox::getPhrase('photo.photos_successfully_uploaded')));

				if ($iGroupId > 0)
				{
					$aGroup = Phpfox::getService('group')->getGroup($iGroupId, true);

					$this->call('window.parent.location.href = \'' . Phpfox::getLib('url')->makeUrl('group', array($aGroup['title_url'], 'photo')) . '\';');
				}
				else
				{
					$this->call('window.parent.location.href = \'' . Phpfox::getLib('url')->makeUrl(Phpfox::getUserBy('user_name'), 'photo') . '\';');
				}
			}
			elseif ($this->get('action') == 'view_album' && isset($aImages[0]['album']))
			{
				Phpfox::addMessage((count($aImages) == 1 ? Phpfox::getPhrase('photo.photo_successfully_uploaded') : Phpfox::getPhrase('photo.photos_successfully_uploaded')));

				$this->call('window.location.href = \'' . Phpfox::getLib('url')->makeUrl(Phpfox::getUserBy('user_name'), array('photo', $aImages[0]['album']['name_url'])) . '\';');
			}
			else
			{
				$this->template()->assign(array(
					'aNewImages' => $aImages
						)
				)->getTemplate('photo.block.new-image');


				$this->append('#js_uploaded_images_data', $this->getContent(false));

				if ($this->get('action') == 'upload')
				{
					$this->show('#js_uploaded_images')
							->hide('#js_progress_cache_holder')
							->show('#js_upload_inner_form');
				}
				else
				{
					$this->show('#js_uploaded_images');
				}
				$this->call('window.aImagesUrl = [];');
				
			}
			/*if (!empty($this->get('failed')))
			{
				$sFailed = implode(',', $this->get('failed'));
				Phpfox::addMessage('The following files failed to be uploaded: ' . $sFailed);
			}*/
			if ($bMassUploader)
			{
				$this->call('completeProgress();');
			}
		}
		else
		{
			$sToSend = '';
			foreach ($aImages as $aImage)
			{
				$sToSend .= 'photos[]=' . urlencode(base64_encode(serialize($aImage))) . '&';
			}
			$sToSend = rtrim($sToSend, '&');
			$this->call('$(\'#js_progress_cache_holder\').html(\'\' + $.ajaxProcess(\'' . Phpfox::getPhrase('photo.processing_image_current_total', array('phpfox_squote' => true, 'current' => (count($aImages) - $iNotCompleted), 'total' => count($aImages))) . '\', \'large\') + \'\');');
			$this->call('$.ajaxCall(\'photo.process\', \'&action=' . $this->get('action') . '&js_disable_ajax_restart=true&' . ($sToSend) . '\');');
		}
	}

    public function editAlbum()
    {
	$aAlbum = Phpfox::getService('photo.album')->getForEdit($this->get('id'));

	if (isset($aAlbum['album_id']))
	{
	    $this->template()->assign(array(
		    'aForms' => $aAlbum
		    )
	    );

	    $this->template()->getTemplate('photo.block.form-album');

	    $this->html('#js_album_edit_form_template', $this->getContent(false));
	    $this->val('#js_album_edit_form_id', $aAlbum['album_id']);
	    $this->show('#js_album_edit_form');
	    $this->hide('#js_user_photo_albums');
	}
    }
}

?>