<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * Controller used to view photo albums on a users profile.
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Photo
 * @version 		$Id: album.class.php 2436 2011-03-24 12:12:57Z Raymond_Benc $
 */
class Photo_Component_Controller_Album extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{
		Phpfox::getUserParam('photo.can_view_photo_albums', true);
		Phpfox::getUserParam('photo.can_view_photos', true);
		
		// Get the user details (person we are viewing)
		$aUser = $this->getParam('aUser');		
		
		if ($iDeleteId = $this->request()->getInt('delete'))
		{
			if (Phpfox::getService('photo.album.process')->delete($iDeleteId))
			{
				$this->url()->send($aUser['user_name'], array('photo'), Phpfox::getPhrase('photo.photo_album_successfully_deleted'));
			}
		}		
		
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_album_process_start')) ? eval($sPlugin) : false);
		
		// Check if this is an AJAX request and that the user information is null (reconfirmation that its an AJAX call)
		if (PHPFOX_IS_AJAX && $aUser === null)
		{
			$aUser = Phpfox::getService('user')->get($this->request()->get('req1'), false);
			$this->template()->assign(array(
					'aUser' => $aUser
				)
			);				
		}
		
		// Get the current album we are trying to view
		$aAlbum = Phpfox::getService('photo.album')->getAlbum($aUser['user_id'], $this->request()->get('req3'));
		
		// Make sure this is a valid album
		if (empty($aAlbum))
		{
			return Phpfox_Error::display(Phpfox::getPhrase('photo.invalid_photo_album'));
		}		
		
		if ($aAlbum['user_id'] == Phpfox::getUserId())
		{
			Phpfox::getService('notification.process')->delete('photo_album_notifyLike', $aAlbum['album_id'], Phpfox::getUserId());
		}		
		
		// Check if this is a password protected album
		if (!empty($aAlbum['password']))
		{
			// If we have a session set lets verify it
			if (Phpfox::getLib('session')->get('photo_password_' . $aAlbum['album_id']) && !Phpfox::getLib('hash')->getRandomHash($aAlbum['password'], Phpfox::getLib('session')->get('photo_password_' . $aAlbum['album_id'])))
			{
				Phpfox::getLib('session')->remove('photo_password_' . $aAlbum['album_id']);
			}
			
			// If we posted a password lets check to make sure it is valid
			if (($sAlbumPassword = $this->request()->get('album_password')) && !empty($sAlbumPassword))
			{
				// Password is valid
				if ($aAlbum['password'] == $sAlbumPassword)
				{
					Phpfox::getLib('session')->set('photo_password_' . $aAlbum['album_id'], Phpfox::getLib('hash')->setRandomHash($aAlbum['password']));
					
					$this->url()->send($aUser['user_name'], array('photo', $aAlbum['name_url']));	
				}
				else 
				{
					// Password is not valid
					Phpfox_Error::set(Phpfox::getPhrase('photo.password_is_not_correct_please_try_again'));
				}
			}		
		}
		
		// Get all requets and reset the params so we can use them in AJAX requests
		$aRequests = $this->request()->getRequests();			
		foreach ($aRequests as $sKey => $sValue)
		{			
			if (!preg_match("/req[0-9]/", $sKey))
			{
				continue;
			}
			
			$this->url()->setParam($sKey, $sValue);			
		}
		
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_album_process_album')) ? eval($sPlugin) : false);
		
		// Store the album details so we can use it in a block later on
		$this->setParam('aAlbum', $aAlbum);

		// Setup the page data
		$iPage = $this->request()->getInt('page');
		$iPageSize = Phpfox::getUserParam('photo.total_photo_display_profile');		

		// Create the SQL condition array
		$aConditions = array();
		
		$sPhotoView = 'p.view_id = 0';
		if ($aUser['user_id'] == Phpfox::getUserId() || Phpfox::getUserParam('photo.can_approve_photos'))
		{
			$sPhotoView = 'p.view_id IN(0,1)';
		}	
		
		// User can view this item because they are allowed to view all hidden items
		if (Phpfox::getUserParam('photo.can_view_hidden_photos'))
		{
			$aConditions[] = 'p.album_id = ' . $aAlbum['album_id'] . ' AND ' . $sPhotoView . ' AND p.group_id = 0 AND p.privacy IN(0,1,2,3) AND p.user_id = ' . $aUser['user_id'] . '';
		}
		// Viewer can view this item since it belongs to them
		elseif (Phpfox::getUserId() && Phpfox::getUserId() == $aAlbum['user_id'])
		{
			$aConditions[] = 'p.album_id = ' . $aAlbum['album_id'] . ' AND ' . $sPhotoView . ' AND p.group_id = 0 AND p.privacy IN(0,1,2,3) AND p.user_id = ' . $aUser['user_id'] . '';
		}
		else 
		{
			// If the album is only for friends lets make sure the user is friends with the album owner
			if ($aAlbum['privacy'] == 2 && Phpfox::getService('friend')->isFriend(Phpfox::getUserId(), $aAlbum['user_id'], true))
			{
				$aConditions[] = 'p.album_id = ' . $aAlbum['album_id'] . ' AND ' . $sPhotoView . ' AND p.group_id = 0 AND p.privacy IN(0,1,2) AND p.user_id = ' . $aUser['user_id'] . '';				
			}
			// If the album is only allowed to be viewed by certain users make sure they are in the "white" list
			elseif ($aAlbum['privacy'] == 3 && Phpfox::getService('privacy')->verify('photo_album', $aAlbum['album_id'], $aUser['user_id'], true))
			{				
				$aConditions[] = 'p.album_id = ' . $aAlbum['album_id'] . ' AND ' . $sPhotoView . ' AND p.group_id = 0 AND p.privacy IN(0,1,2,3) AND p.user_id = ' . $aUser['user_id'] . '';
			}
			// Public album for everyone to view
			else 
			{
				$aConditions[] = 'p.album_id = ' . $aAlbum['album_id'] . ' AND ' . $sPhotoView . ' AND p.group_id = 0 AND p.privacy IN(0,1) AND p.user_id = ' . $aUser['user_id'] . '';
			}
		}
		
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_album_process_conditions')) ? eval($sPlugin) : false);
		
		// Get the photos based on the conditions
		list($iCnt, $aPhotos) = Phpfox::getService('photo')->get($aConditions, 'p.time_stamp DESC', $iPage, $iPageSize);
		
		// Set the pager for the photos
		Phpfox::getLib('pager')->set(array('page' => $iPage, 'size' => $iPageSize, 'count' => $iCnt));		

		foreach ($aPhotos as $aPhoto)
		{
			$this->template()->setMeta('keywords', $this->template()->getKeywords($aPhoto['title']));
		}		
		
		// Assign the template vars
		$this->template()->setTitle($aAlbum['name'])
				->setBreadcrumb(Phpfox::getPhrase('photo.full_name_s_photos', array('full_name' => $aUser['full_name'])), $this->url()->makeUrl($aUser['user_name'], 'photo'))
				->setBreadcrumb($aAlbum['name'], null, true)
				->setMeta('description', Phpfox::getPhrase('photo.full_name_s_photo_album_from_time_stamp', array('full_name' => $aUser['full_name'], 'time_stamp' => Phpfox::getTime(Phpfox::getParam('core.description_time_stamp'), $aAlbum['time_stamp']))) . ': ' . (empty($aAlbum['description']) ? $aAlbum['name'] : $aAlbum['description']) . '.')		
				->setMeta('keywords', $this->template()->getKeywords($aAlbum['name']))
				->setMeta('keywords', Phpfox::getParam('photo.photo_meta_keywords'))
				->setMeta('description', Phpfox::getParam('photo.photo_meta_description'))				
				->setPhrase(array(
						'photo.updating_album',
						'photo.none_of_your_files_were_uploaded_please_make_sure_you_upload_either_a_jpg_gif_or_png_file'
					)
				)
				->setHeader('cache', array(
					'pager.css' => 'style_css',
					'jquery/plugin/jquery.scrollTo.js' => 'static_script',
					'album.js' => 'module_photo',
					'photo.js' => 'module_photo',
					'quick_edit.js' => 'static_script',
					'jquery/plugin/jquery.highlightFade.js' => 'static_script',
					'switch_legend.js' => 'static_script',
					'switch_menu.js' => 'static_script'
				)
			)
			->assign(array(
				'aPhotos' => $aPhotos,
				'aForms' => $aAlbum,
				'aCallback' => null
			)
		);		
		
		$this->template()->setTitle(Phpfox::getPhrase('photo.full_name_s_albums', array('full_name' => $aUser['full_name'])));
		
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_album_process_end')) ? eval($sPlugin) : false);
	}
	
	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_album_clean')) ? eval($sPlugin) : false);
	}
}

?>