<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Photo
 * @version 		$Id: index.class.php 2415 2011-03-23 14:39:38Z Miguel_Espinoza $
 */
class Photo_Component_Controller_Index extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{		
		Phpfox::getUserParam('photo.can_view_photos', true);
		
		if (($iRedirectId = $this->request()->getInt('redirect')) && ($aPhoto = Phpfox::getService('photo')->getForEdit($iRedirectId)))
		{
			if ($aPhoto['group_id'])
			{
				$aGroup = Phpfox::getService('group')->getGroup($aPhoto['group_id'], true);
				
				$this->url()->send('group', array($aGroup['title_url'], 'photo', 'view', $aPhoto['title_url']));
			}
			else 
			{
				$this->url()->send($aPhoto['user_name'], array('photo', ($aPhoto['album_id'] ? $aPhoto['album_url'] : 'view'), $aPhoto['title_url']));
			}
		}
		
		if (($iRedirectAlbumId = $this->request()->getInt('aredirect')) && ($aAlbum = Phpfox::getService('photo.album')->getForEdit($iRedirectAlbumId)))
		{
			$this->url()->send($aAlbum['user_name'], array('photo', $aAlbum['name_url']));	
		}
		
		if (($iUnFeature = $this->request()->getInt('unfeature')) && Phpfox::getUserParam('photo.can_feature_photo'))
		{
			if (Phpfox::getService('photo.process')->feature($iUnFeature, 0))
			{
				$this->url()->send('photo', null, Phpfox::getPhrase('photo.photo_successfully_unfeatured'));
			}
		}
		
		$aCallback = $this->getParam('aCallback', null);
		if (PHPFOX_IS_AJAX)
		{
			if ($this->request()->get('req1') == 'group')
			{
				$aGroup = Phpfox::getService('group')->getGroup($this->request()->get('req2'));
				if (isset($aGroup['group_id']))
				{
					$aCallback = array(
						'group_id' => $aGroup['group_id'],
						'url_home' => 'group.' . $aGroup['title_url'] . '.photo',
						'url_home_array' => array(
							'group',
							array(
								$aGroup['title_url']							
							)
						)						
					);
				}
			}
		}		
		
		$sCategory = null;	
		$aSearch = $this->request()->getArray('search');
		$bIsTagSearch = false;
		$sPhotoUrl = ($aCallback === null ? $this->url()->makeUrl('photo') : $this->url()->makeUrl($aCallback['url_home']));		
		$this->setParam('sTagType', 'photo');
		$sView = $this->request()->get('view', false);
		
		if ($iDeleteId = $this->request()->get('delete'))
		{
			if (Phpfox::getService('photo.process')->delete($iDeleteId))
			{
				$this->url()->send(($aCallback === null ? 'photo' : $aCallback['url_home']), null, Phpfox::getPhrase('photo.photo_successfully_deleted'));
			}
		}	
		
		$aRequests = $this->request()->getRequests();			
		$iCount = 0;
		foreach ($aRequests as $sKey => $sValue)
		{			
			if (!preg_match("/req[0-9]/", $sKey))
			{
				continue;
			}
			
			$iCount++;
			
			$this->url()->setParam($sKey, $sValue);
			
			if ($aCallback === null)
			{
				if ($sKey != 'req1')
				{
					$sCategory = $sValue;
				}
			}
			else 
			{
				if ($iCount > 3)
				{
					$sCategory = $sValue;
				}
			}
		}
		
		$aDisplays = array();
		$aPhotoDisplays = Phpfox::getUserParam('photo.total_photos_displays');		
		foreach ($aPhotoDisplays as $iPageCnt)
		{
			$aDisplays[$iPageCnt] = Phpfox::getPhrase('core.per_page', array('total' => $iPageCnt));	
		}
		
		$aSorts = array(
			'time_stamp' => Phpfox::getPhrase('photo.time'),
			'total_view' => Phpfox::getPhrase('photo.most_viewed'),
			'total_comment' => Phpfox::getPhrase('photo.most_talked_about'),
			'total_rating' => Phpfox::getPhrase('photo.top_rated'),
			'total_battle' => Phpfox::getPhrase('photo.top_battle')
		);			
		
		$aFilters = array(
			'display' => array(
				'type' => 'select',
				'options' => $aDisplays,
				'default' => Phpfox::getUserParam('photo.default_photo_display_limit')
			),
			'sort' => array(
				'type' => 'select',
				'options' => $aSorts,
				'default' => 'time_stamp',
				'alias' => 'p'
			),
			'sort_by' => array(
				'type' => 'select',
				'options' => array(
					'DESC' => Phpfox::getPhrase('core.descending'),
					'ASC' => Phpfox::getPhrase('core.ascending')
				),
				'default' => 'DESC'
			),
			'search' => array(
				'type' => 'input:text',
				'search' => "AND p.title LIKE '%[VALUE]%'"
			)			
		);
		
		$oFilter = Phpfox::getLib('search')->set(array(
				'type' => 'photo',
				'filters' => $aFilters,
				'search' => 'search'
			)
		);	
				
		if ($this->request()->get('view') && $this->request()->get('view') == 'approval' && Phpfox::getUserParam('photo.can_approve_photos'))
		{
			$oFilter->setCondition('AND p.view_id = 1');
		}
		else 
		{
			
			$oFilter->setCondition((Phpfox::getUserParam('photo.can_view_private_photos') ? 'AND p.view_id >= 0' : (Phpfox::getUserParam('photo.can_approve_photos') ? 'AND p.view_id IN(0,1)' : 'AND p.view_id = 0')));
			$oFilter->setCondition('AND p.group_id = ' . ($aCallback === null ? '0' : (int) $aCallback['group_id']) . ' AND p.privacy ' . (Phpfox::getUserParam('photo.can_view_private_photos') ? '>= 0' : '= 0'));

			switch ($sView)
			{
				case 'featured':
					$oFilter->setCondition('AND p.is_featured = 1');
					$oFilter->setCondition('AND p.album_id = 0');
					break;
				case 'most-viewed':
					$oFilter->setSort('total_view');
					$oFilter->setCondition('AND p.album_id = 0');
					break;
				case 'top-rated':
					$oFilter->setSort('total_rating');
					$oFilter->setCondition('AND p.total_vote > 0');
					$oFilter->setCondition('AND p.album_id = 0');
					break;				
				case 'top-battle':
					$oFilter->setSort('total_battle');
					$oFilter->setCondition('AND p.total_battle > 0');
					break;	
				default:
					
					break;
			}
		}			
		
		if ($this->request()->get('req2') == 'tag')
		{
			$sCategory = null;
			$oFilter->setCondition("AND tag.tag_url = '" . Phpfox::getLib('database')->escape($this->request()->get('req3')) . "'");
			$bIsTagSearch = true;
			$this->setParam('bIsTagSearch', true);
		}		
		
		list($iCnt, $aPhotos) = ($sCategory === null ? Phpfox::getService('photo')->isTagSearch($bIsTagSearch)->get($oFilter->getConditions(), $oFilter->getSort(), $oFilter->getPage(), $oFilter->getDisplay(), $aCallback) : Phpfox::getService('photo.category')->getPhotos($sCategory, $oFilter->getConditions(), $oFilter->getSort(), $oFilter->getPage(), $oFilter->getDisplay(), $aCallback));
		
		$iCnt = $oFilter->getSearchTotal($iCnt);
		
		Phpfox::getLib('pager')->set(array('page' => $oFilter->getPage(), 'size' => $oFilter->getDisplay(), 'count' => $iCnt));
		
		if (!PHPFOX_IS_AJAX && Phpfox::getUserParam('photo.can_approve_photos') && ($iPhotoApproveCnt = Phpfox::getService('photo')->getApprovalPhotosCount()) && $iPhotoApproveCnt > 0)
		{
			$this->template()->assign('iPhotoApproveCnt', $iPhotoApproveCnt);
		}
		
		foreach ($aPhotos as $aPhoto)
		{
			$this->template()->setMeta('keywords', $this->template()->getKeywords($aPhoto['title']));
		}		
		
		$aFilterMenuCache = array();
		$aFilterMenu = array();
		if ($aCallback === null && !defined('PHPFOX_IS_USER_PROFILE'))
		{
			$aFilterMenu = array(
				Phpfox::getPhrase('photo.recent_photos') => '',
				Phpfox::getPhrase('photo.featured') => 'featured',
				Phpfox::getPhrase('photo.most_viewed') => 'most-viewed',
				Phpfox::getPhrase('photo.top_rated') => 'top-rated',
				Phpfox::getPhrase('photo.top_battle') => 'top-battle'
			);			
				
			if (Phpfox::getUserParam('photo.can_approve_photos') && $aCallback === null)
			{
				$aFilterMenu[Phpfox::getPhrase('photo.pending')] = 'approval';
			}
		}
				
		$this->template()->setTitle(Phpfox::getPhrase('photo.photos'))
			->setBreadcrumb(Phpfox::getPhrase('photo.photos'), $sPhotoUrl)
			->setMeta('keywords', Phpfox::getParam('photo.photo_meta_keywords'))
			->setMeta('description', Phpfox::getParam('photo.photo_meta_description'))
			->setMeta('description', Phpfox::getPhrase('photo.site_title_has_a_total_of_total_photo_s', array('site_title' => Phpfox::getParam('core.site_title'), 'total' => $iCnt)))	
			->setPhrase(array(
					'photo.loading'
				)
			)
			->setHeader('cache', array(
					'browse.js' => 'module_photo',
					'pager.css' => 'style_css',
					'jquery/plugin/jquery.scrollTo.js' => 'static_script'
				)
			)
			->assign(array(
					'aPhotos' => $aPhotos,
					'bIsAjax' => PHPFOX_IS_AJAX,
					'sPhotoUrl' => $sPhotoUrl,
					'aCallback' => $aCallback,					
					'sView' => $sView
				)
			);	
			
		$iFilterCount = 0;
		foreach ($aFilterMenu as $sMenuName => $sMenuLink)
		{
			$iFilterCount++;
			$aFilterMenuCache[] = array(
				'name' => $sMenuName,
				'link' => $this->url()->makeUrl(($aCallback !== null ? $aCallback['url_home_array'][0] . '.' . implode('.', array_merge($aCallback['url_home_array'][1], array('photo'))) : 'photo' ) . (empty($sCategoryUrl) ? '' : $sCategoryUrl), array('view' => $sMenuLink)),
				'active' => ($sView == $sMenuLink ? true : false),
				'last' => (count($aFilterMenu) === $iFilterCount ? true : false)
			);
			
			if (!empty($sView) && $sView == $sMenuLink)
			{
				$this->template()->setTitle($sMenuName);
				$this->template()->setBreadcrumb($sMenuName, null, true);
			}
		}	

		if (empty($sView))
		{				
			$this->template()->setTitle(Phpfox::getPhrase('photo.recent_photos'))->setBreadcrumb(Phpfox::getPhrase('photo.recent_photos'), $this->url()->makeUrl('photo',array('view' => '')), true);
		}
		
		$this->template()->assign(array(
				'aFilterMenus' => $aFilterMenuCache
			)
		);
			
		if ($bIsTagSearch)
		{
			$this->template()->setTitle(Phpfox::getPhrase('photo.tags'))
				->setTitle($this->request()->get('req3'))
				->setBreadcrumb(Phpfox::getPhrase('photo.tags'), $this->url()->makeUrl('photo.tag'))
				->setBreadcrumb($this->request()->get('req3'), $this->url()->makeUrl('photo.tag', $this->request()->get('req3')), true);
		}			
		
		if (!empty($sCategory))
		{
			$aCategories = Phpfox::getService('photo.category')->getParentBreadcrumb($sCategory);
			$iCnt = 0;
			foreach ($aCategories as $aCategory)
			{
				$iCnt++;
				
				$this->template()->setTitle($aCategory[0]);
				
				if (is_array($aCallback) && !empty($aCallback))
				{
					$sHomeUrl = '/' . Phpfox::getLib('url')->doRewrite($aCallback['url_home_array'][0]) . '/' . implode('/', $aCallback['url_home_array'][1]) . '/' . Phpfox::getLib('url')->doRewrite('photo') . '/';	
					$aCategory[1] = preg_replace('/^http:\/\/(.*?)\/' . Phpfox::getLib('url')->doRewrite('photo') . '\/(.*?)$/i', 'http://\\1' . $sHomeUrl . '\\2', $aCategory[1]);						
				}				
				
				$this->template()->setBreadcrumb($aCategory[0], $aCategory[1], ($iCnt === count($aCategories) ? true : false));
			}				
		}

		$this->setParam('sCurrentCategory', $sCategory);
	}
	
	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_index_clean')) ? eval($sPlugin) : false);
	}
}

?>