<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * Displays a users photo and album gallery on their profile.
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Photo
 * @version 		$Id: profile.class.php 1594 2010-05-22 22:49:41Z Raymond_Benc $
 */
class Photo_Component_Controller_Profile extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{
		// Get the user details (person we are viewing)
		$aUser = $this->getParam('aUser');	
		if (PHPFOX_IS_AJAX)
		{
			$aUser = Phpfox::getService('user')->getByUserName($this->request()->get('req1'));	
			if (!isset($aUser['user_id']))
			{
				return false;
			}
		}
		
		if (!Phpfox::isPublicView() && !Phpfox::getService('user.privacy')->hasAccess($aUser['user_id'], 'photo.display_on_profile'))
		{
			return Phpfox_Error::display(Phpfox::getPhrase('photo.section_is_private'));
		}			
		
		Phpfox::getUserParam('photo.can_view_photos', true);
		
		// Define that this is a profile
		$this->setParam('bIsProfile', true);	
		
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_profile_process_start')) ? eval($sPlugin) : false);
		
		// Check if we are trying to view an image and if we are change the controller
		if ($this->request()->get('req3') && $this->request()->get('req4'))
		{			
			return Phpfox::getLib('module')->setController('photo.view');
		}
		
		// Check if we are trying to view an album and if we are chaneg the controller
		if ($this->request()->get('req3'))
		{
			return Phpfox::getLib('module')->setController('photo.album');
		}		

		if (!Phpfox::getService('user.privacy')->hasAccess($aUser['user_id'], 'photo.display_on_profile'))
		{
			return Phpfox_Error::display(Phpfox::getPhrase('photo.section_is_private'));
		}			

		// certain conditions need to apply to sponsor a listing
		if ($this->request()->getInt('sponsor') == 1) // all we need to get is anything actually
		{
		    // check if the user can sponsor items
		    if (!Phpfox::getUserParam('photo.can_purchase_sponsor') && !Phpfox::getUserParam('photo.can_sponsor_photo'))
		    {
				$this->url()->forward($this->url()->makeUrl('photo'), Phpfox::getPhrase('subscribe.the_feature_or_section_you_are_attempting_to_use_is_not_permitted_with_your_membership_level'));
		    }
		    else
		    {
				Phpfox::addMessage(Phpfox::getPhrase('photo.sponsor_help'));
		    }
		} 
		// Check if this is an AJAX request and that the user information is null (reconfirmation that its an AJAX call)
		if (PHPFOX_IS_AJAX && $aUser === null)
		{
			$aUser = Phpfox::getService('user')->get($this->request()->get('req1'), false);
			$this->template()->assign(array(
					'aUser' => $aUser
				)
			);				
		}
		
		// Assign the template headers, I don't like adding this in AJAX calls however bots need to pick this up on each page since they can't do AJAX
		$this->template()->setHeader('cache', array(
				'pager.css' => 'style_css',
				'jquery/plugin/jquery.scrollTo.js' => 'static_script',
				'profile.js' => 'module_photo'
			)
		);		
		
		// Get all requets and reset the params so we can use them in AJAX requests
		$aRequests = $this->request()->getRequests();			
		foreach ($aRequests as $sKey => $sValue)
		{			
			if (!preg_match("/req[0-9]/", $sKey))
			{
				continue;
			}
			
			$this->url()->setParam($sKey, $sValue);			
		}		
		
		$aAlbumConditions = array();
		
		$aAlbumConditions[] = 'pa.view_id = 0 AND pa.group_id = 0 AND pa.user_id = ' . $aUser['user_id'] . '';
		
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_profile_process_album_conditions')) ? eval($sPlugin) : false);
		
		$this->template()->assign(array(
				'bIsFriends' => (((Phpfox::getUserId() && Phpfox::isModule('friend') && Phpfox::getService('friend')->isFriend($aUser['user_id'], Phpfox::getUserId())) || (Phpfox::getUserId() == $aUser['user_id'])) ? true : false)
			)
		);
	
		// Check if we are just trying to browse the photo album
		if ($this->request()->get('view') == 'album')
		{
			$iAlbumPage = $this->request()->getInt('page');
			$iAlbumPageSize = 6;		
			
			(($sPlugin = Phpfox_Plugin::get('photo.component_controller_profile_process_album_viewer')) ? eval($sPlugin) : false);
			
			// Get photo album
			list($iAlbumCnt, $aAlbums) = Phpfox::getService('photo.album')->get($aAlbumConditions, 'pa.time_stamp DESC', $iAlbumPage, $iAlbumPageSize);
			
			// Set the pager for the album
			Phpfox::getLib('pager')->set(array('page' => $iAlbumPage, 'size' => $iAlbumPageSize, 'count' => $iAlbumCnt, 'ajax' => 'photo.browseUserAlbum'));
			
			// Assign the album data to the template
			$this->template()->assign(array(
					'aAlbums' => $aAlbums,
					'iAlbumCnt' => $iAlbumCnt				
				)
			);				
		}
		else 
		{
			// Make sure we set the view param to only view photos since the album uses a special AJAX request
			$this->url()->setParam('view', 'photo');
			
			$iPage = $this->request()->getInt('page');
			$iPageSize = 9;			
			
			(($sPlugin = Phpfox_Plugin::get('photo.component_controller_profile_process_photo_album_viewer')) ? eval($sPlugin) : false);
			
			$sView = 'p.view_id = 0';
			$sPrivacy = 'p.privacy = 0';
			if ($aUser['user_id'] == Phpfox::getUserId())
			{
				$sView = 'p.view_id IN(0,1)';
				$sPrivacy = 'p.privacy IN(0,1,2,3,4)';
			}
			elseif (Phpfox::getService('friend')->isFriend(Phpfox::getUserId(), $aUser['user_id']))
			{
				$sPrivacy = 'p.privacy IN(0,4)';
			}			
			
			if (Phpfox::getUserParam('photo.can_view_private_photos'))
			{
				$sView = 'p.view_id >= 0';	
				$sPrivacy = 'p.privacy >= 0';	
			}
			
			// Get the photos
			if ($this->request()->getInt('sponsor') == 1)
			{
			    list($iPhotoCnt, $aPhotos) = Phpfox::getService('photo')->get('p.album_id = 0 AND ' . $sView . ' AND p.group_id = 0 AND ' . $sPrivacy . ' AND p.user_id = ' . $aUser['user_id'] . ' AND p.is_sponsor != 1', 'p.time_stamp DESC', $iPage, $iPageSize);
			}
			else
			{
			    list($iPhotoCnt, $aPhotos) = Phpfox::getService('photo')->get('p.album_id = 0 AND ' . $sView . ' AND p.group_id = 0 AND ' . $sPrivacy . ' AND p.user_id = ' . $aUser['user_id'] . '', 'p.time_stamp DESC', $iPage, $iPageSize);
			}
			
			// Set the pager for the photos
			Phpfox::getLib('pager')->set(array('page' => $iPage, 'size' => $iPageSize, 'count' => $iPhotoCnt, 'aParams' => array(
						'view' => 'photo'
					)
				)
			);			
	
			// If we are viewing a list of both photos and albums
			// if ($this->request()->get('view') != 'photo')
			{
				// Get the photo album
				list($iAlbumCnt, $aAlbums) = Phpfox::getService('photo.album')->get($aAlbumConditions, 'pa.time_stamp DESC', 0, 6);			
				$this->template()->assign(array(
						'aAlbums' => $aAlbums,
						'iAlbumCnt' => $iAlbumCnt
					)
				);
			}
			
			if (!PHPFOX_IS_AJAX)
			{
				$this->template()->setTitle(Phpfox::getPhrase('photo.full_name_s_photos', array('full_name' => $aUser['full_name'])))
					->setBreadcrumb(Phpfox::getPhrase('photo.full_name_s_photos', array('full_name' => $aUser['full_name'])), $this->url()->makeUrl($aUser['user_name'], 'photo'))
					->setMeta('description', Phpfox::getPhrase('photo.full_name_s_photos_on_site_title_full_name_has_total_photo_photo_s_and_total_album_photo', array(					
								'full_name' => $aUser['full_name'],
								'site_title' => Phpfox::getParam('core.site_title'),
								'full_name' => $aUser['full_name'],
								'total_photo' => $iPhotoCnt,
								'total_album' => $iAlbumCnt
							)
						)
					)
					->setMeta('keywords', Phpfox::getParam('photo.photo_meta_keywords'))
					->setMeta('description', Phpfox::getParam('photo.photo_meta_description'));
			}
				
			$this->template()
				->assign(array(					
					'aPhotos' => $aPhotos,
					'iPhotoCnt' => $iPhotoCnt,
					'aCallback' => null
				)
			);		
			
			foreach ($aPhotos as $aPhoto)
			{
				$this->template()->setMeta('keywords', $aPhoto['title']);
			}
			
			(($sPlugin = Phpfox_Plugin::get('photo.component_controller_profile_process_end')) ? eval($sPlugin) : false);
		}
	}
	
	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_profile_clean')) ? eval($sPlugin) : false);
	}
}

?>