<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * Photo controller where we upload new images and includes
 * a photo progress bar.
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Photo
 * @version 		$Id: upload.class.php 2291 2011-02-03 10:02:46Z Miguel_Espinoza $
 */
class Photo_Component_Controller_Upload extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{
		// Make sure the user is allowed to upload an image
		Phpfox::isUser(true);
		Phpfox::getUserParam('photo.can_upload_photos', true);		
		//Phpfox::getService('core.process')->trackUpload();

		$aCallback = null;
		if (($sModule = $this->request()->get('module')) 
			&& Phpfox::isModule($sModule) 
			&& ($iItemId = $this->request()->getInt('item'))
			&& Phpfox::hasCallback($sModule, 'addPhoto')
		)
		{
			$aCallback = Phpfox::callback($sModule . '.addPhoto', $iItemId);			
			
			$this->template()->setBreadcrumb(Phpfox::getPhrase('photo.groups'), $this->url()->makeUrl('group'));
			$sUrlHome = $this->url()->makeUrl($aCallback['url_home']);
			$this->template()->setBreadcrumb($aCallback['title'], $sUrlHome);
			$this->template()->removeUrl('photo.upload', 'photo.battle');
			$this->template()->removeUrl('photo.upload', 'photo.rate');
			$this->template()->removeUrl('photo.upload', 'profile.photo');
			$this->template()->rebuildMenu('photo.upload', array(
						'group',
						array(
							$aCallback['title_url']							
						)
					)
				);			
		}		
		
		// Set the main breadcrumb &amp; title
		$this->template()->setTitle(Phpfox::getPhrase('photo.upload_photos'))->setBreadcrumb(Phpfox::getPhrase('photo.photos'), $this->url()->makeUrl('photo'));
			
		
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_upload_start')) ? eval($sPlugin) : false);

		// Updating photos using the global settings
		if (($aVals = $this->request()->getArray('val')) && $this->request()->get('save_global'))
		{
			// Create the photo storate array
			$aPhotos = array();
			
			// Do we have any saved photos we planned on processing?
			if (isset($aVals['photo_id']))
			{
				// Look thru them and get their ID#
				foreach ($aVals['photo_id'] as $iPhoto)
				{
					$aPhotos[$iPhoto] = $iPhoto;	
				}
			}			
			
			// Lets look thru all the post data and find our photos only
			foreach ($aVals as $iId => $aVal)
			{
				// Since we post other data we only want to allow those that contain our photos
				if (!is_numeric($iId))
				{
					continue;
				}
				
				$aPhotos[$iId] = $iId;
			}
			
			// Lets look thru all our final photos
			foreach ($aPhotos as $iPhotoId)
			{
				// Update the photos
				Phpfox::getService('photo.process')->update(Phpfox::getUserId(), $iPhotoId, $aVals, true);	
			}		
			
			(($sPlugin = Phpfox_Plugin::get('photo.component_controller_upload_process_global')) ? eval($sPlugin) : false);
			
			$this->url()->send(Phpfox::getUserBy('user_name'), 'photo', 'Photos successfully uploaded.');
		}
		
		// Updating photos with specific settings for each photo
		if (($aVals = $this->request()->getArray('val')) && $this->request()->get('save'))
		{
			$aCachePhotos = array();
			foreach ($aVals as $iId => $aVal)
			{
				// Since we post other data we only want to allow those that contain our photos
				if (!is_numeric($iId))
				{
					continue;
				}				

				// Update the photos
				$aCachePhotos[] = Phpfox::getService('photo.process')->update(Phpfox::getUserId(), $iId, $aVal, true);
			}			
			
			if (count($aCachePhotos))
			{
				Phpfox::getService('photo.process')->updateNewsFeed($aCachePhotos);
			}
			
			(($sPlugin = Phpfox_Plugin::get('photo.component_controller_upload_process_photos')) ? eval($sPlugin) : false);
			
			switch ($aVals['action'])
			{
				case 'view_album':
					$aAlbum = Phpfox::getService('photo.album')->getAlbum(Phpfox::getUserId(), $aVals['album_id'], true);				
					
					$this->url()->send(Phpfox::getUserBy('user_name'), array('photo', $aAlbum['name_url']), Phpfox::getPhrase('photo.photos_successfully_uploaded'));
					break;
				case 'view_photo':
					$this->url()->send(($aCallback === null ? Phpfox::getUserBy('user_name') : $aCallback['url_home']), 'photo', Phpfox::getPhrase('photo.photos_successfully_updated'));
					break;
				case 'upload':
					$this->url()->send('photo.upload', ($aCallback === null ? null : array('module' => 'group', 'item' => $aCallback['group_id'])), Phpfox::getPhrase('photo.photo_s_successfully_updated'));
					break;				
			}			
		}
		
		// Processing the images
		if ($this->request()->get('req3') // Check if we need to process the images.
			&& ($aVals = $this->request()->getArray('val')) // Make sure we actually posted some data.
			&& isset($aVals['photo_id'])
			&& ($aImages = Phpfox::getService('photo')->getNewImages(Phpfox::getUserId(), $aVals['photo_id'])) // Verify and get the new images.
			&& is_array($aImages) // Make sure its an array before we display the images.
		)
		{			
			// Get storage arrays
			$aDisplay = array();
			$aNextImages = array();
			
			// Loop thru all the images
			foreach ($aImages as $iKey => $aImage)
			{
				// Only display a certain amount
				if ($iKey > 2)
				{
					// Cache the next images we need to process
					$aNextImages[] = $aImage['photo_id'];
					
					// Skip this image in the current process
					continue;
				}
				
				// Cache all the images we plan to process in this round
				$aDisplay[] = $aImage;
			}
			
			// Clear the original image array from memory
			unset($aImages);
			
			(($sPlugin = Phpfox_Plugin::get('photo.component_controller_upload_process_display_batch')) ? eval($sPlugin) : false);			
			$aFailed = $this->request()->getArray('aFailed');
			if (!empty($aFailed))
			{
				$this->template()->assign(array('aFailed' => $aFailed));
			}
			// Assign all the needed vars to the template
			$this->template()->setTitle(Phpfox::getPhrase('photo.process_photos'))
				->setBreadcrumb(Phpfox::getPhrase('photo.upload'), $this->url()->makeUrl('photo.upload'))
				->setBreadcrumb(Phpfox::getPhrase('photo.process_photos'), null, true)
				->setPhrase(array(
						'photo.none_of_your_files_were_uploaded_please_make_sure_you_upload_either_a_jpg_gif_or_png_file'
					)
				)					
				->setHeader('cache', array(						
						'photo.js' => 'module_photo'
					)
				)				
				->assign(array(
					'bProcess' => true,
					'aImages' => $aDisplay,					
					'aNextImages' => $aNextImages,
					'iTotalNextBatch' => count($aNextImages),
					'sSkipLink' => ($aCallback === null ? $this->url()->makeUrl(Phpfox::getUserBy('user_name'), 'photo') : $this->url()->makeUrl($aCallback['url_home'], 'photo')),
					'aCallback' => $aCallback
				)
			);
		}
		else 
		{			
			$aValidation = array(
				'name' => Phpfox::getPhrase('photo.provide_a_name_for_your_album'),
				'privacy' => Phpfox::getPhrase('photo.select_a_privacy_setting_for_your_album')
			);				
	
			// Assign validation.
			$oValid = Phpfox::getLib('validator')->set(array(
					'sFormName' => 'js_create_new_album', 
					'aParams' => $aValidation
				)
			);	
			
			$bCantUploadMore = (Phpfox::getParam('photo.total_photo_input_bars') > Phpfox::getUserParam('photo.max_images_per_upload'));
			$iMaxFileSize = (Phpfox::getUserParam('photo.photo_max_upload_size') === 0 ? null : ((Phpfox::getUserParam('photo.photo_max_upload_size') / 1024) * 1048576));
			$sMethod = Phpfox::getParam('photo.enable_mass_uploader') && $this->request()->get('method','') != 'simple' ? 'massuploader' : 'simple';
			$sMethodUrl = str_replace(array('method_simple/','method_massuploader/'), '',$this->url()->getFullUrl()) . 'method_' . ($sMethod == 'simple' ? 'massuploader' : 'simple') . '/';
			if ($sMethod == 'massuploader')
			{
				$this->template()->setPhrase(array(							
							'photo.you_can_upload_a_jpg_gif_or_png_file',
							'core.name',
							'core.status',
							'core.in_queue',
							'core.upload_failed_your_file_size_is_larger_then_our_limit_file_size'
						)
					)
						->setHeader('cache', array(
							'massuploader/swfupload.js' => 'static_script',						
							'<script type="text/javascript">
							function setSWFUSettings()
							{								
								swfu.setButtonDimensions('.(strlen(Phpfox::getPhrase('photo.click_here_to_upload_photos'))*5).',20);
								swfu.setUploadURL("'.$this->url()->makeUrl('photo.frame').'");
								swfu.setFileSizeLimit("'.$iMaxFileSize .' B");
								swfu.setFileUploadLimit('.Phpfox::getUserParam('photo.max_images_per_upload').');
								swfu.customSettings.progress_target = "js_progress_bar";
								swfu.customSettings.flash_user_id = '.Phpfox::getUserId().';
								
								swfu.customSettings.sHash = "'.  Phpfox::getService('core')->getHashForUpload() .'";
								swfu.customSettings.action = $("#js_photo_action").val();
								swfu.atFileQueue = function()
								{
									$("#album_table").hide();
									this.addPostParam("album_id", '. ($this->request()->getInt('album') > 0 ? $this->request()->getInt('album') : '$("#js_photo_album_select").val()') .');
									'. ($sModule == 'group' ? 'this.addPostParam("val[group_id]", '.$iItemId.');this.addPostParam("val[group_title_url]", "'.$aCallback['title_url'].'");' : '') .'
								}
								oParams["sViewPhotoUrl"] = "'.$this->url()->makeUrl('profile.photo').'";
							}
							</script>',
							'massuploader/upload.js' => 'static_script',
							'swfu.js' => 'style_script' 
						))
						//->assign(array('bMassUploader' => true))
					;				
			}
			else{
				$this->template()->setHeader(array(
							'<script type="text/javascript">var oProgressBar = {holder: \'#js_upload_inner_form\', progress_id: \'#js_progress_bar\', uploader: \'#js_progress_uploader\', add_more: ' . ($bCantUploadMore ? 'false' : 'true') . ', max_upload: ' . Phpfox::getUserParam('photo.max_images_per_upload') . ', total: 1, frame_id: \'js_upload_frame\', file_id: \'image[]\', valid_file_ext: new Array(\'gif\', \'png\', \'jpg\', \'jpeg\')};</script>'
						)
					);				
			}
			// Assign template vars.
			$this->template()->setBreadcrumb(Phpfox::getPhrase('photo.upload'), null, true)								
					->setHeader('cache', array(
						'progress.js' => 'static_script',
						'photo.js' => 'module_photo',										
						'pager.css' => 'style_css',
						'upload.css' => 'module_photo'						
					)
				)
					->setHeader(array('<script type="text/javascript">oParams["sMethod"] = "'.$sMethod .'";</script>'))
					->setPhrase(array(
							'photo.none_of_your_files_were_uploaded_please_make_sure_you_upload_either_a_jpg_gif_or_png_file',
							'photo.view_this_album',
							'core.select_a_file_to_upload',
							'core.not_a_valid_file_extension_we_only_allow_ext'
					))
				->assign(array(
						'bProcess' => false,
						'aCallback' => $aCallback,
						'aAlbums' => Phpfox::getService('photo.album')->getAll(Phpfox::getUserId()), // Get all the photo albums for this specific user
						'iUploadId' => uniqid(),
						'sCreateJs' => $oValid->createJS(),
						'sGetJsForm' => $oValid->getJsForm(false),
						'iAlbumId' => $this->request()->getInt('album'),
						'iMaxFileSize' => $iMaxFileSize,
						'sMethod' => $sMethod,
						'sMethodUrl' => $sMethodUrl
					)
				);
				
			(($sPlugin = Phpfox_Plugin::get('photo.component_controller_upload_end')) ? eval($sPlugin) : false);
		}
	}
	
	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_upload_clean')) ? eval($sPlugin) : false);
	}
}

?>