<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * Controller to view images on a users profile.
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Photo
 * @version 		$Id: view.class.php 2012 2010-11-01 12:48:12Z Miguel_Espinoza $
 */
class Photo_Component_Controller_View extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{		
		Phpfox::getUserParam('photo.can_view_photos', true);
		define('PHPFOX_SHOW_TAGS', true); 
		$aCallback = $this->getParam('aCallback', null);
		$sId = $this->request()->get(($aCallback === null ? 'req4' : 'req5'));
		$sAction = $this->request()->get(($aCallback === null ? 'req5' : 'req6'));		
		$aUser = $this->getParam('aUser');
		$this->setParam('sTagType','photo'); // fixes http://forums.phpfox.com/project.php?issueid=5274
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_view_process_start')) ? eval($sPlugin) : false);
		
		// Get the photo
		$aPhoto = Phpfox::getService('photo')->getPhoto($sId, $aUser['user_id'], ($aCallback === null ? null : $aCallback));
		
		// No photo founds lets get out of here
		if (!isset($aPhoto['photo_id']))
		{
			return Phpfox_Error::display(Phpfox::getPhrase('photo.sorry_the_photo_you_are_looking_for_no_longer_exists', array('link' => $this->url()->makeUrl('photo'))));
		}		
		
		// User can view this item because they are allowed to view all hidden items
		if (Phpfox::getUserParam('photo.can_view_hidden_photos'))
		{
			
		}
		// Viewer can view this item since it belongs to them
		elseif (Phpfox::getUserId() && Phpfox::getUserId() == $aPhoto['user_id'])
		{
			
		}
		else 
		{			
			// If the album is only for friends lets make sure the user is friends with the album owner					
			if ($aPhoto['privacy'] == 2 && Phpfox::getService('friend')->isFriend(Phpfox::getUserId(), $aPhoto['user_id'], true))
			{
				
			}
			// If the album is only allowed to be viewed by certain users make sure they are in the "white" list
			elseif ($aPhoto['privacy'] == 3 && Phpfox::getService('privacy')->verify('photo_album', $aPhoto['album_id'], $aPhoto['user_id'], true))
			{				
				
			}
			elseif ($aPhoto['privacy'] == 4 && $aPhoto['user_id'] != Phpfox::getUserId())
			{
				return Phpfox_Error::display(Phpfox::getPhrase('photo.invalid_photo'));	
			}
			// Public album for everyone to view
			else 
			{
				
			}
		}			
		
		// Check if this is a password protected album
		if (!empty($aPhoto['album_password']) && $aPhoto['user_id'] != Phpfox::getUserId() && !Phpfox::getUserParam('photo.can_view_private_photos'))
		{
			// If we have a session set lets verify it
			if ((!Phpfox::getLib('session')->get('photo_password_' . $aPhoto['album_id'])) || (Phpfox::getLib('session')->get('photo_password_' . $aPhoto['album_id']) && !Phpfox::getLib('hash')->getRandomHash($aPhoto['album_password'], Phpfox::getLib('session')->get('photo_password_' . $aPhoto['album_id']))))
			{
				$this->url()->send($aUser['user_name'], array('photo', $aPhoto['album_url']));
			}
		}
		
		if ($aPhoto['mature'] != 0)
		{
			if (Phpfox::getUserId())
			{				
				if ($aPhoto['mature'] == 1 && Phpfox::getUserParam(array(
						'photo.photo_mature_age_limit' => array(
								'>', 
								Phpfox::getUserBy('age')
							)
						)
					)
				)
				{
					// warning check cookie
				}
				elseif ($aPhoto['mature'] == 2 && Phpfox::getUserParam(array(
						'photo.photo_mature_age_limit' => array(
								'>', 
								Phpfox::getUserBy('age')
							)
						)
					)				
				)
				{
					return Phpfox_Error::display(Phpfox::getPhrase('photo.sorry_this_photo_can_only_be_viewed_by_those_older_then_the_age_of_limit', array('limit' => Phpfox::getUserParam('photo.photo_mature_age_limit'))));	
				}
			}
			else 
			{
				Phpfox::isUser(true);
			}
		}
		
		$this->setParam('bIsValidImage', true);
		
		/* 
			Don't like that this is here, but if added in the service class it would require an extra JOIN to the user table and its such a waste of a query when we could
			just get the users details vis the cached user array.		
		*/
		$aPhoto['bookmark_url'] = ($aCallback === null ? Phpfox::getLib('url')->makeUrl($aUser['user_name'], array('photo', ($aPhoto['album_id'] ? $aPhoto['album_url'] : 'view'), $aPhoto['title_url'])) : Phpfox::getLib('url')->makeUrl($aCallback['url_home'], array('view', $aPhoto['title_url'])));
		
		// Increment the total view
		$aPhoto['total_view'] = ((int) $aPhoto['total_view'] + 1);
		
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_view_process_photo')) ? eval($sPlugin) : false);
		
		// Assign the photo array so other blocks can use this information
		$this->setParam('aPhoto', $aPhoto);	
		define('TAG_ITEM_ID', $aPhoto['photo_id']); // to be used with the cloud block
		// Check if we should set another controller
		if (!empty($sAction))
		{
			switch ($sAction)
			{
				case 'all':
					return Phpfox::getLib('module')->setController('photo.size');
					break;
				case 'download':
					return Phpfox::getLib('module')->setController('photo.download');
					break;
				default:
					(($sPlugin = Phpfox_Plugin::get('photo.component_controller_view_process_controller')) ? eval($sPlugin) : false);
					break;
			}			
		}
		
		// Increment the view counter
		if (Phpfox::isModule('track') && Phpfox::isUser() && Phpfox::getUserId() != $aPhoto['user_id'] && !$aPhoto['is_viewed'])
		{
			Phpfox::getService('track.process')->add('photo', $aPhoto['photo_id']);
			Phpfox::getService('photo.process')->updateCounter($aPhoto['photo_id'], 'total_view');
		}
		
		// Add photo tags to meta keywords
		if (!empty($aPhoto['tag_list']) && $aPhoto['tag_list'] && Phpfox::isModule('tag'))
		{
			$this->template()->setMeta('keywords', Phpfox::getService('tag')->getKeywords($aPhoto['tag_list']));
		}
		
		// Add photo categories to meta keywords
		if (!empty($aPhoto['categories']))
		{
			$sCategory = strip_tags(str_replace('<br />', ',', $aPhoto['categories']));
			
			$this->template()->setMeta('keywords', $sCategory);
		}
		
		if ($aPhoto['user_id'] == Phpfox::getUserId() && Phpfox::isModule('notification'))
		{
			Phpfox::getService('notification.process')->delete('comment_photo', $aPhoto['photo_id'], Phpfox::getUserId());
			Phpfox::getService('notification.process')->delete('photo_notifyLike', $aPhoto['photo_id'], Phpfox::getUserId());
		}		


		$this->template()->setTitle($aPhoto['title']);
		
		if (Phpfox::getParam('photo.how_many_categories_to_show_in_title') > 0)
		{
		    $aCategories = explode('<br />',$aPhoto['categories']);
		    $sCategories = '';
		    foreach ($aCategories as $iCount => $sCategory)
		    {
			if ($iCount >= Phpfox::getParam('photo.how_many_categories_to_show_in_title'))
			{
			    break;
			}// clean the categories
			$sCategories .= strip_tags($sCategory) . ' - ';
		    }
		    $this->template()->setTitle(rtrim($sCategories, ' - '));
		}
		$this->template()
				->setBreadcrumb(Phpfox::getPhrase('photo.photos'), ($aCallback === null ? (Phpfox::getParam('core.item_view_area') == 'profile' ? $this->url()->makeUrl($aUser['user_name'], 'photo') : $this->url()->makeUrl('photo')) : $this->url()->makeUrl($aCallback['url_home'])))
				->setBreadcrumb($aPhoto['title'], null, true)
				->setMeta('description',  Phpfox::getPhrase('photo.full_name_s_photo_from_time_stamp', array('full_name' => $aUser['full_name'], 'time_stamp' => Phpfox::getTime(Phpfox::getParam('core.description_time_stamp'), $aPhoto['time_stamp']))) . ': ' . (empty($aPhoto['description']) ? $aPhoto['title'] : $aPhoto['title'] . '.' . $aPhoto['description']))
				->setMeta('keywords', $this->template()->getKeywords($aPhoto['title']))
				->setMeta('keywords', Phpfox::getParam('photo.photo_meta_keywords'))
				->setMeta('description', Phpfox::getParam('photo.photo_meta_description'))								
				->setPhrase(array(
						'photo.none_of_your_files_were_uploaded_please_make_sure_you_upload_either_a_jpg_gif_or_png_file',
						'photo.updating_photo',
						'photo.save',
						'photo.cancel',
						'photo.click_here_to_tag_as_yourself'
					)
				)				
				->setHeader('cache', array(
						'jquery/plugin/jquery.highlightFade.js' => 'static_script',	
						'jquery/plugin/jquery.scrollTo.js' => 'static_script',
						'jquery/plugin/imgnotes/jquery.tag.js' => 'static_script',						
						'quick_edit.js' => 'static_script',
						'comment.css' => 'style_css',
						'pager.css' => 'style_css',
						'view.js' => 'module_photo',
						'photo.js' => 'module_photo',
						'switch_legend.js' => 'static_script',
						'switch_menu.js' => 'static_script',
						'stream.css' => 'module_photo'
					)
				)
				->setHeader(array(
						'<script type="text/javascript">Phpfox.photo_tag.init({' . Phpfox::getService('photo.tag')->getJs($aPhoto['photo_id']) . '});</script>'
					)
				)
				->setEditor(array(
						'load' => 'simple'					
					)
				)->assign(array(
					'aForms' => $aPhoto,
					'aCallback' => $aCallback
				)
			);		
			
		if (!empty($aPhoto['album_title']))
		{
			$this->template()->setTitle($aPhoto['album_title']);
			$this->template()->setMeta('description', '' . Phpfox::getPhrase('photo.part_of_the_photo_album') . ': ' . $aPhoto['album_title']);
		}
		
		$this->template()->setTitle($aUser['full_name']);
			
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_view_process_end')) ? eval($sPlugin) : false);
	}
	
	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('photo.component_controller_view_clean')) ? eval($sPlugin) : false);	
	}
}

?>