<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * Controls photo albums.
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Photo
 * @version 		$Id: album.class.php 1793 2010-09-06 07:56:03Z Raymond_Benc $
 */
class Photo_Service_Album_Album extends Phpfox_Service 
{
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('photo_album');	
	}
	
	/**
	 * Get all albums based on filters we passed via the params.
	 *
	 * @param array $mConditions SQL Conditions
	 * @param string $sOrder SQL Ordering
	 * @param int $iPage Current page we are on
	 * @param int $iPageSize Define how many photos we can display at one time
	 * 
	 * @return array Return an array of the total album count and the albums
	 */
	public function get($mConditions = array(), $sOrder = 'pa.time_stamp DESC', $iPage = '', $iPageSize = '')
	{		
		$aAlbums = array();
		
		(($sPlugin = Phpfox_Plugin::get('photo.service_album_album_get_count')) ? eval($sPlugin) : false);
		
		$iCnt = $this->database()->select('COUNT(DISTINCT pa.album_id)')
			->from($this->_sTable, 'pa')
			->leftJoin(Phpfox::getT('photo'), 'p', 'p.album_id = pa.album_id')
			->where($mConditions)
			->execute('getSlaveField');
		
		if ($iCnt)
		{
			if (Phpfox::isModule('privacy'))
			{
				$this->database()->select('p2.item_id AS privacy_pass, ')->leftJoin(Phpfox::getT('privacy'), 'p2', "p2.item_id = pa.album_id AND p2.category_id = 'photo_album' AND p2.user_id = " . Phpfox::getUserId());
			}			
			
			(($sPlugin = Phpfox_Plugin::get('photo.service_album_album_get_query')) ? eval($sPlugin) : false);
			
			$aAlbums = $this->database()->select('pa.*, p.destination, p.server_id, p.mature, ' . Phpfox::getUserField())
				->from($this->_sTable, 'pa')
				->leftJoin(Phpfox::getT('photo'), 'p', 'p.album_id = pa.album_id AND pa.view_id = 0 AND p.is_cover = 1')
				->join(Phpfox::getT('user'), 'u', 'u.user_id = pa.user_id')
				->where($mConditions)
				->order($sOrder)
				->limit($iPage, $iPageSize, $iCnt)
				->execute('getSlaveRows');	
		}		

		return array($iCnt, $aAlbums);
	}	
	
	/**
	 * Get all the albums for a specific user.
	 *
	 * @param int $iUserId User ID.
	 * 
	 * @return array Return the array of albums.
	 */
	public function getAll($iUserId)
	{
		(($sPlugin = Phpfox_Plugin::get('photo.service_album_album_getall')) ? eval($sPlugin) : false);
		
		return $this->database()->select('album_id, name')
			->from($this->_sTable)
			->where('user_id = ' . (int) $iUserId)
			->execute('getSlaveRows');
	}
	
	/**
	 * Get the total count of albums for a specific user.
	 *
	 * @param int $iUserId User ID.
	 * 
	 * @return int Return the total number of albums.
	 */
	public function getAlbumCount($iUserId)
	{
		(($sPlugin = Phpfox_Plugin::get('photo.service_album_album_getalbumcount')) ? eval($sPlugin) : false);
		
		return $this->database()->select('COUNT(*)')
			->from($this->_sTable)
			->where('user_id = ' . (int) $iUserId)
			->execute('getField');		
	}
	
	/**
	 * Get a specific album based on the user ID and album ID or album title.
	 *
	 * @param int $iUserId User ID this album belongs to
	 * @param mixed $mId Album ID or Album title
	 * @param boolean $bUseId True to use an album ID call or else it is an album title
	 *
	 * @return array Array of the album
	 */
	public function getAlbum($iUserId, $mId, $bUseId = false)
	{
		(($sPlugin = Phpfox_Plugin::get('photo.service_album_album_getalbum')) ? eval($sPlugin) : false);
		
		return $this->database()->select('pa.*, pai.*')
			->from($this->_sTable, 'pa')
			->join(Phpfox::getT('photo_album_info'), 'pai', 'pai.album_id = pa.album_id')
			->where('pa.user_id = ' . (int) $iUserId . ' AND ' . ($bUseId === true ? 'pa.album_id = ' . (int) $mId : 'pa.name_url = \'' . $this->database()->escape($mId) . '\''))
			->execute('getSlaveRow');
	}
	
	public function getForEdit($iId)
	{
		(($sPlugin = Phpfox_Plugin::get('photo.service_album_album_getforedit')) ? eval($sPlugin) : false);
		
		return $this->database()->select('pa.*, pai.*, ' . Phpfox::getUserField())
			->from($this->_sTable, 'pa')
			->join(Phpfox::getT('photo_album_info'), 'pai', 'pai.album_id = pa.album_id')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = pa.user_id')
			->where('pa.album_id = ' . (int) $iId)
			->execute('getSlaveRow');
	}	
	
	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('photo.service_album__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}	
}

?>