<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * Photo process class. Used to INSERT, UPDATE & DELETE photos.
 *
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Photo
 * @version 		$Id: process.class.php 2419 2011-03-23 15:36:55Z Raymond_Benc $
 */
class Photo_Service_Process extends Phpfox_Service
{
    /**
     * Class constructor
     */
    public function __construct()
    {
		$this->_sTable = Phpfox::getT('photo');
    }

    public function updateNewsFeed($aImages)
    {
	if (!Phpfox::isModule('feed'))
	{
	    return;
	}

	$sIds = '';
	foreach ($aImages as $iId)
	{
	    if (!is_numeric($iId))
	    {
		continue;
	    }
	    $sIds .= $iId . ',';
	}
	$sIds = rtrim($sIds, ',');

	if (!empty($sIds))
	{
	    $aPhotos = $this->database()->select('p.photo_id, p.group_id, p.view_id, p.server_id, p.destination, p.mature, p.title_url, p.album_id, u.user_name, pa.name AS album_name, pa.name_url AS album_url, pa.privacy, pa.password')
		    ->from($this->_sTable, 'p')
		    ->join(Phpfox::getT('user'), 'u', 'u.user_id = p.user_id')
		    ->leftJoin(Phpfox::getT('photo_album'), 'pa', 'pa.album_id = p.album_id')
		    ->where('p.photo_id IN(' . $sIds . ')')
		    ->execute('getRows');

	    if (count($aPhotos))
	    {
		$aFeed = array();
		$iCnt = 0;

		if (!empty($aPhotos[0]['album_id']))
		{
		    Phpfox::getService('feed.process')->delete('photo_album', $aPhotos[0]['album_id']);
		}

		foreach ($aPhotos as $aPhoto)
		{
		    if ((int) $aPhoto['view_id'] > 0)
		    {
			continue;
		    }

		    if (empty($aPhoto['album_id']))
		    {
			Phpfox::getService('feed.process')->delete('photo', $aPhoto['photo_id']);
		    }
		    else
		    {
			if ($aPhoto['privacy'] > 0 || !empty($aPhoto['password']))
			{
			    continue;
			}
		    }

		    $aCallback = ($aPhoto['group_id'] ? Phpfox::callback('group.addPhoto', $aPhoto['group_id']) : null);

		    if (defined('PHPFOX_SKIP_FEED_ENTRY'))
		    {
			continue;
		    }

		    $iCnt++;
		    if ($iCnt < 4)
		    {
			$aFeed[] = array(
				'server_id' => $aPhoto['server_id'],
				'destination' => $aPhoto['destination'],
				'link' => ((isset($aPhoto['group_id']) && (int) $aPhoto['group_id'] > 0) ? array($aCallback['url_home'], 'photo', 'view', $aPhoto['title_url']) : array($aPhoto['user_name'], 'photo', (!empty($aPhoto['album_id']) ? $aPhoto['album_url'] : 'view'), $aPhoto['title_url'])),
				'mature' => $aPhoto['mature']
			);
		    }
		}

		if (count($aFeed))
		{
		    if (!empty($aPhotos[0]['album_id']))
		    {
			Phpfox::getService('feed.process')->add('photo_album', $aPhotos[0]['album_id'], serialize(array('name' => $aPhotos[0]['album_name'], 'images' => $aFeed)));
		    }
		    else
		    {
			Phpfox::getService('feed.process')->add('photo', $aPhotos[0]['photo_id'], serialize($aFeed));
		    }
		}
	    }
	}

	return true;
    }

    /**
     * Adding a new photo.
     *
     * @param int $iUserId User ID of the user that the photo belongs to.
     * @param array $aVals Array of the post data being passed to insert.
     * @param boolean $bIsUpdate True if we plan to update the entry or false to insert a new entry in the database.
     * @param boolean $bAllowTitleUrl Set to true to allow the editing of the SEO url.
     *
     * @return int ID of the newly added photo or the ID of the current photo we are editing.
     */
    public function add($iUserId, $aVals, $bIsUpdate = false, $bAllowTitleUrl = false)
    {
		$oParseInput = Phpfox::getLib('parse.input');
		// Create the fields to insert.
		$aFields = array();
	
		// Make sure we are updating the album ID
		(!empty($aVals['album_id']) ? $aFields['album_id'] = 'int' : null);
	
		// Is this an update?
		if ($bIsUpdate)
		{
		    // Make sure we only update the fields that the user is allowed to
		    (Phpfox::getUserParam('photo.can_add_mature_images') ? $aFields['mature'] = 'int' : null);
		    (Phpfox::getUserParam('photo.can_control_comments_on_photos') ? $aFields['allow_comment'] = 'int' : null);
		    ((Phpfox::getUserParam('photo.can_add_to_rating_module') && Phpfox::getParam('photo.can_rate_on_photos')) ? $aFields['allow_rate'] = 'int' : null);
		    (!empty($aVals['destination']) ? $aFields[] = 'destination' : null);
		    $aFields['allow_download'] = 'int';
		    $aFields['server_id'] = 'int';
	
		    // Check if we are allowed to update the SEO title and if there is anything to update
		    if ($bAllowTitleUrl === true && !empty($aVals['title']))
		    {
				$aFields[] = 'title_url';
		
				$aVals['title_url'] = $oParseInput->prepareTitle('photo', $aVals['title'], 'title_url', $iUserId, Phpfox::getT('photo'), null, false, false);
		
				if (Phpfox::getParam('photo.rename_uploaded_photo_names'))
				{
				    $aFields[] = 'destination';
		
				    $aPhoto = $this->database()->select('destination')
					    ->from($this->_sTable)
					    ->where('photo_id = ' . $aVals['photo_id'])
					    ->execute('getRow');
		
				    $sNewName = preg_replace("/^(.*?)-(.*?)%(.*?)$/", "$1-" . str_replace('%', '', $aVals['title_url']) . "%$3", $aPhoto['destination']);
		
				    $aVals['destination'] = $sNewName;
		
				    Phpfox::getLib('file')->rename(Phpfox::getParam('photo.dir_photo') . sprintf($aPhoto['destination'], ''), Phpfox::getParam('photo.dir_photo') . sprintf($sNewName, ''));
		
				    // Create thumbnails with different sizes depending on the global param.
				    foreach(Phpfox::getParam('photo.photo_pic_sizes') as $iSize)
				    {
						Phpfox::getLib('file')->rename(Phpfox::getParam('photo.dir_photo') . sprintf($aPhoto['destination'], '_' . $iSize), Phpfox::getParam('photo.dir_photo') . sprintf($sNewName, '_' . $iSize));
				    }
				}
		    }
			$sCheck = '' . (isset($aVals['title']) ? $aVals['title'] : '') . ' ' . (isset($aVals['description']) ? $aVals['description'] : '');
			Phpfox::getService('ban')->checkAutomaticBan($sCheck);
		    // Check if we really need to update the title
		    if (!empty($aVals['title']))
		    {
			$aFields[] = 'title';

			// Clean the title for any sneaky attacks
			$aVals['title'] = $oParseInput->clean($aVals['title'], 255);
		    }
	
		    // Update the data into the database.
		    $this->database()->process($aFields, $aVals)->update($this->_sTable, 'photo_id = ' . (int) $aVals['photo_id']);
		    // Check if we need to update the description of the photo
		    if (!empty($aVals['description']))
		    {
				$aFieldsInfo = array(
					'description'
				);
		
				// Clean the data before we add it into the database
				$aVals['description'] = $oParseInput->clean($aVals['description'], 255);
		    }
		    else 
		    {
				$aFieldsInfo = array(
					'description'
				);
		
				// Clean the data before we add it into the database
				$aVals['description'] = null;
		    }
	
		    (!empty($aVals['width']) ? $aFieldsInfo[] = 'width' : 0);
		    (!empty($aVals['height']) ? $aFieldsInfo[] = 'height' : 0);
	
		    // Check if we have anything to add into the photo_info table
		    if (isset($aFieldsInfo))
		    {
			$this->database()->process($aFieldsInfo, $aVals)->update(Phpfox::getT('photo_info'), 'photo_id = ' . (int) $aVals['photo_id']);
		    }
		    // Add tags for the photo
		    if (Phpfox::isModule('tag') && isset($aVals['tag_list']) && !empty($aVals['tag_list']) && Phpfox::getUserParam('photo.can_add_tags_on_photos'))
		    {
				Phpfox::getService('tag.process')->update('photo', $aVals['photo_id'], $iUserId, $aVals['tag_list']);
		    }
	
		    // Make sure if we plan to add categories for this image that there is something to add
		    if (isset($aVals['category_id']) && count($aVals['category_id']))
		    {
			// Loop thru all the categories
			foreach ($aVals['category_id'] as $iCategory)
			{
			    // Add each of the categories
			    Phpfox::getService('photo.category.process')->updateForItem($aVals['photo_id'], $iCategory);
			}
		    }
	
		    if (PHPFOX_IS_AJAX && Phpfox::isModule('feed'))
		    {
			$aPhoto = $this->database()->select('p.photo_id, p.server_id, p.destination, p.title_url, p.mature, p.album_id, u.user_name, pa.name AS album_name, pa.name_url AS album_url')
				->from($this->_sTable, 'p')
				->join(Phpfox::getT('user'), 'u', 'u.user_id = p.user_id')
				->leftJoin(Phpfox::getT('photo_album'), 'pa', 'pa.album_id = p.album_id')
				->where('p.photo_id = ' . $aVals['photo_id'])
				->execute('getRow');

			Phpfox::getService('feed.process')->update('photo', $aPhoto['photo_id'], serialize(array(
				array(
					'server_id' => $aPhoto['server_id'],
					'destination' => $aPhoto['destination'],
					'link' => array($aPhoto['user_name'], 'photo', (!empty($aPhoto['album_id']) ? $aPhoto['album_url'] : 'view'), $aPhoto['title_url']),
					'mature' => $aPhoto['mature']
				)
				)
				)
			);
		    }
	
		    $iId = $aVals['photo_id'];
		}
		else
		{
		    // Define all the fields we need to enter into the database
		    $aFields['user_id'] = 'int';
		    $aFields['time_stamp'] = 'int';
		    $aFields['server_id'] = 'int';
		    $aFields['view_id'] = 'int';
		    $aFields['group_id'] = 'int';
		    $aFields[] = 'title';
		    $aFields[] = 'title_url';
		    // Define all the fields we need to enter into the photo_info table
		    $aFieldsInfo = array(
			    'photo_id' => 'int',
			    'file_name',
			    'mime_type',
			    'extension',
			    'file_size' => 'int'
		    );
	
		    // Clean and prepare the title and SEO title
		    $aVals['title'] = $oParseInput->clean(rtrim(preg_replace("/^(.*?)\.(jpg|jpeg|gif|png)$/i", "$1", $aVals['name'])), 255);
		    $aVals['title_url'] = $oParseInput->prepareTitle('photo', $aVals['name'], 'title_url', $iUserId, Phpfox::getT('photo'), null, false, false);
		    $aVals['title_url'] = preg_replace("/^(.*?)\.(jpg|jpeg|gif|png)$/i", "$1", $aVals['title_url']);
		    // Add the user_id
		    $aVals['user_id'] = $iUserId;
	
		    // Add the original server ID for LB.
		    $aVals['server_id'] = Phpfox::getLib('request')->getServer('PHPFOX_SERVER_ID');
	
		    // Add the time stamp.
		    $aVals['time_stamp'] = PHPFOX_TIME;
	
		    $aVals['view_id'] = (((!isset($aVals['group_id']) || !$aVals['group_id']) && Phpfox::getUserParam('photo.photo_must_be_approved')) ? '1' : '0');
	
		    // Insert the data into the database.
		    $iId = $this->database()->process($aFields, $aVals)->insert($this->_sTable);
	
		    // Prepare the data to enter into the photo_info table
		    $aInfo = array(
			    'photo_id' => $iId,
			    'file_name' => $aVals['name'],
			    'extension' => strtolower($aVals['ext']),
			    'file_size' => $aVals['size'],
			    'mime_type' => $aVals['type']
		    );
	
		    // Insert the data into the photo_info table
		    $this->database()->process($aFieldsInfo, $aInfo)->insert(Phpfox::getT('photo_info'));
		    if (((!isset($aVals['group_id']) || !$aVals['group_id']) && !Phpfox::getUserParam('photo.photo_must_be_approved') || ($aVals['group_id'])))
		    {
			// Update user activity
			Phpfox::getService('user.activity')->update($iUserId, 'photo');
		    }
		}
	
		// Plugin call
		if ($sPlugin = Phpfox_Plugin::get('photo.service_process_add__end'))
		{
		    eval($sPlugin);
		}
	
		// Return the photo ID#
		return $iId;
    }

    /**
     * Updating a new photo. We piggy back on the add() method so we don't have to do the same code twice.
     *
     * @param int $iUserId User ID of the user that the photo belongs to.
     * @param array $aVals Array of the post data being passed to insert.
     * @param boolean $bAllowTitleUrl Set to true to allow the editing of the SEO url.
     *
     * @return int ID of the newly added photo or the ID of the current photo we are editing.
     */
    public function update($iUserId, $iId, $aVals, $bAllowTitleUrl = false)
    {
		$aVals['photo_id'] = $iId;
	
		return $this->add($iUserId, $aVals, true, $bAllowTitleUrl);
    }

    /**
     * Used to delete a photo.
     *
     * @param int $iId ID of the photo we want to delete.
     *
     * @return boolean We return true since if nothing fails we were able to delete the image.
     */
    public function delete($iId, $bPass = false)
    {
		// Get the image ID and full path to the image.
		$aPhoto = $this->database()->select('user_id, is_sponsor, album_id, photo_id, destination')
			->from($this->_sTable)
			->where('photo_id = ' . (int) $iId)
			->execute('getRow');
	
		if (!isset($aPhoto['user_id']))
		{
		    return false;
		}
	
		if ($bPass === false && !Phpfox::getService('user.auth')->hasAccess('photo', 'photo_id', $iId, 'photo.can_delete_own_photo', 'photo.can_delete_other_photos', $aPhoto['user_id']))
		{
		    return false;
		}
	
		// Create the total file size var for all the images
		$iFileSizes = 0;
		// Make sure the original image exists
		if (file_exists(Phpfox::getParam('photo.dir_photo') . sprintf($aPhoto['destination'], '')))
		{
		    // Add to the file size var
		    $iFileSizes += filesize(Phpfox::getParam('photo.dir_photo') . sprintf($aPhoto['destination'], ''));
	
		    // Remove the image
		    unlink(Phpfox::getParam('photo.dir_photo') . sprintf($aPhoto['destination'], ''));
		}
	
		// Loop thru all the other smaller images
		foreach(Phpfox::getParam('photo.photo_pic_sizes') as $iSize)
		{
		    // Make sure the image exists
		    if (file_exists(Phpfox::getParam('photo.dir_photo') . sprintf($aPhoto['destination'], '_' . $iSize)))
		    {
				// Add to the file size var
				$iFileSizes += filesize(Phpfox::getParam('photo.dir_photo') . sprintf($aPhoto['destination'], '_' . $iSize));
		
				// Remove the image
				unlink(Phpfox::getParam('photo.dir_photo') . sprintf($aPhoto['destination'], '_' . $iSize));
		    }
		}
	
		// Delete this entry from the database
		$this->database()->delete($this->_sTable, 'photo_id = ' . $aPhoto['photo_id']);
		$this->database()->delete(Phpfox::getT('photo_info'), 'photo_id = ' . $aPhoto['photo_id']);
		// delete the ratings for this photo
		$this->database()->delete(Phpfox::getT('photo_rating'), 'photo_id = ' . $aPhoto['photo_id']);
		// delete the photo tags
		$this->database()->delete(Phpfox::getT('photo_tag'), 'photo_id = ' . $aPhoto['photo_id']);
		// delete the category_data
		$this->database()->delete(Phpfox::getT('photo_category_data'), 'photo_id = ' . $aPhoto['photo_id']);
		// delete the battles
		$this->database()->delete(Phpfox::getT('photo_battle'), 'photo_1 = ' . $aPhoto['photo_id'] . ' OR photo_2 = ' . $aPhoto['photo_id']);
	
		(Phpfox::isModule('feed') ? Phpfox::getService('feed.process')->delete('photo', $iId) : null);
		(Phpfox::isModule('feed') ? Phpfox::getService('feed.process')->delete('comment_photo', $iId) : null);
		(Phpfox::isModule('tag') ? Phpfox::getService('tag.process')->deleteForItem($aPhoto['user_id'], $iId, 'photo') : null);
		
		$this->database()->delete(Phpfox::getT('comment'), 'type_id = \'photo\' AND item_id = ' . (int) $iId);
	
		// Update user space usage
		if ($iFileSizes > 0)
		{
		    Phpfox::getService('user.space')->update($aPhoto['user_id'], 'photo', $iFileSizes, '-');
		}
	
		// Update user activity
		Phpfox::getService('user.activity')->update($aPhoto['user_id'], 'photo', '-');
	
		if ($aPhoto['album_id'] > 0)
		{
		    Phpfox::getService('photo.album.process')->updateCounter($aPhoto['album_id'], 'total_photo', true);
		}

		if ($aPhoto['is_sponsor'] == 1)
		{
			$this->cache()->remove('photo_sponsored');
		}
		return true;
    }

    /**
     * Update the photo counters.
     *
     * @param int $iId ID# of the photo
     * @param string $sCounter Field we plan to update
     * @param boolean $bMinus True increases to the count and false decreases the count
     */
    public function updateCounter($iId, $sCounter, $bMinus = false)
    {
	$this->database()->update($this->_sTable, array(
		$sCounter => array('= ' . $sCounter . ' ' . ($bMinus ? '-' : '+'), 1)
		), 'photo_id = ' . (int) $iId
	);
    }

    public function approve($iId)
    {
	$aPhoto = $this->database()->select('p.*, ' . Phpfox::getUserField() . ', pa.name_url AS album_url, pa.privacy')
		->from($this->_sTable, 'p')
		->join(Phpfox::getT('user'), 'u', 'u.user_id = p.user_id')
		->leftJoin(Phpfox::getT('photo_album'), 'pa', 'pa.album_id = p.album_id')
		->where('p.photo_id = ' . (int) $iId)
		->execute('getSlaveRow');

	if (!isset($aPhoto['photo_id']))
	{
	    return false;
	}

	$this->database()->update($this->_sTable, array('view_id' => 0, 'time_stamp' => PHPFOX_TIME), 'photo_id = ' . $aPhoto['photo_id']);

	Phpfox::getService('user.activity')->update($aPhoto['user_id'], 'photo');

	if ($aPhoto['album_id'] > 0)
	{
	    Phpfox::getService('photo.album.process')->updateCounter($aPhoto['album_id'], 'total_photo');
	}

	if (Phpfox::isModule('feed'))
	{
	    $bUpdate = ((isset($aPhoto['privacy']) && $aPhoto['privacy'] > 0) ? false : true);

	    if ($bUpdate === true)
	    {
		Phpfox::getService('feed.process')->add('photo', $aPhoto['photo_id'], serialize(array(
			array(
				'server_id' => $aPhoto['server_id'],
				'destination' => $aPhoto['destination'],
				'link' => array($aPhoto['user_name'], 'photo', (!empty($aPhoto['album_id']) ? $aPhoto['album_url'] : 'view'), $aPhoto['title_url']),
				'mature' => $aPhoto['mature']
			)
			)
			), $aPhoto['user_id']
		);
	    }
	}

	return true;
    }

    public function feature($iId, $sType)
    {
	$this->database()->update($this->_sTable, array('is_featured' => ($sType == '1' ? 1 : 0)), 'photo_id = ' . (int) $iId);

	$this->cache()->remove('photo_featured');

	return true;
    }

    public function sponsor($iId, $sType)
    {	    
	    if (!Phpfox::getUserParam('photo.can_sponsor_photo') && !Phpfox::getUserParam('photo.can_purchase_sponsor') && !defined('PHPFOX_API_CALLBACK'))
	    {
		    return Phpfox_Error::set('Hack attempt?');
	    }

	    $iType = (int)$sType;
	    if ($iType != 0 && $iType != 1)
	    {
		    return false;
	    }
	    // if it was featured it cannot be both and sponsored overrides featured. If it was sponsored it couldnt had been featured
	    $this->database()->update($this->_sTable, array('is_featured' => 0, 'is_sponsor' => $iType), 'photo_id = ' . (int)$iId);
	    $this->cache()->remove('photo_sponsored');
	    if ($sPlugin = Phpfox_Plugin::get('photo.service_process_sponsor__end'))
	    {
		    eval($sPlugin);
	    }
	    return true;
    }

    public function rotate($iId, $sCmd)
    {
		$aPhoto = $this->database()->select('user_id, photo_id, destination, server_id')
			->from($this->_sTable)
			->where('photo_id = ' . (int) $iId)
			->execute('getSlaveRow');
	
		if (!isset($aPhoto['photo_id']))
		{
		    return Phpfox_Error::set(Phpfox::getPhrase('photo.unable_to_find_the_photo_you_plan_to_edit'));
		}
	
		if (($aPhoto['user_id'] == Phpfox::getUserId() && Phpfox::getUserParam('photo.can_edit_own_photo')) || Phpfox::getUserParam('photo.can_edit_other_photo'))
		{
		    foreach(array_merge(array(''), Phpfox::getParam('photo.photo_pic_sizes')) as $iSize)
		    {
				$sFile = Phpfox::getParam('photo.dir_photo') . sprintf($aPhoto['destination'], (empty($iSize) ? '' : '_') . $iSize);
				if (file_exists($sFile))
				{
				    Phpfox::getLib('image')->rotate($sFile, $sCmd);
				}
		    }
	
		    return $aPhoto;
		}
	
		return false;
    }

    /**
     * If a call is made to an unknown method attempt to connect
     * it to a specific plug-in with the same name thus allowing
     * plug-in developers the ability to extend classes.
     *
     * @param string $sMethod is the name of the method
     * @param array $aArguments is the array of arguments of being passed
     */
    public function __call($sMethod, $aArguments)
    {
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('photo.service_process__call'))
		{
		    return eval($sPlugin);
		}
	
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
    }
}

?>