<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * Handles the rating of photos.
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package 		Phpfox_Service
 * @version 		$Id: rate.class.php 1496 2010-03-05 17:15:05Z Raymond_Benc $
 */
class Photo_Service_Rate_Rate extends Phpfox_Service 
{
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('photo');	
	}
	
	public function getJavaScript($sCategory = null, $iPhotoId = null)
	{		
		$aConds = array();
		$aConds[] = 'p.privacy = 0 AND p.allow_rate = 1 AND ' . $this->database()->isNull('pr.rating_id');
		
		if ($sCategory !== null)
		{
			$sCategoryIds = Phpfox::getService('photo.category')->getAllCategories($sCategory);
			
			if (!empty($sCategoryIds))
			{
				$aConds[] = ' AND pcd.category_id IN (' . $sCategoryIds . ')';
				
				$this->database()->innerJoin(Phpfox::getT('photo_category_data'), 'pcd', 'pcd.photo_id = p.photo_id');
			}
		}
		
		if ($iPhotoId !== null)
		{
			$aConds[] = ' AND p.photo_id = ' . (int) $iPhotoId;
		}
		
		$aPhotos = $this->database()->select('p.photo_id, p.server_id, p.destination, p.total_rating, p.total_vote, p.time_stamp, pr.rating_id, ' . Phpfox::getUserField())
			->from($this->_sTable, 'p')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = p.user_id')
			->leftJoin(Phpfox::getT('photo_rating'), 'pr', 'pr.photo_id = p.photo_id AND pr.user_id = ' . Phpfox::getUserId())
			->where($aConds)
			->limit(Phpfox::getParam('photo.rating_total_photos_cache'))
			->order('RAND()')
			->execute('getRows');
			
		if (!count($aPhotos))
		{
			return false;
		}
			
		$iCnt = 0;
		$sJs = "";
		foreach ($aPhotos as $iKey => $aPhoto)
		{
			$iCnt++;
			if ($iCnt != 1)
			{
				$sJs .= "},";
			}				
			$sJs .= "{$iKey}: {";
			foreach ($aPhoto as $sKey => $sValue)
			{
				if ($sKey == 'destination')
				{
					$sValue = Phpfox::getLib('image.helper')->display(array(
							'server_id' => $aPhoto['server_id'],
							'path' => 'photo.url_photo',
							'file' => $aPhoto['destination'],
							'suffix' => '_500',
							'max_width' => 500,
							'max_height' => 500							
						)
					);					
				}
				elseif ($sKey == 'full_name')
				{
					$sValue = '<a href="' . Phpfox::getLib('url')->makeUrl($aPhoto['user_name']) . '">' . $aPhoto['full_name'] . '</a>';
				}				
				elseif ($sKey == 'time_stamp')
				{
					$sValue = Phpfox::getTime(Phpfox::getParam('photo.photo_image_details_time_stamp'), $aPhoto['time_stamp']);
				}
				
				$sJs .= $sKey . ': \'' . str_replace("'", "\'", $sValue) . '\',';
			}						
			$sJs = rtrim($sJs, ',');
					
		}
		$sJs = rtrim($sJs, ',');
		
		return $sJs;	
	}
	
	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('photo.service_rate__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}	
}

?>