<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 *
 *
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Poll
 * @version 		$Id: view.class.php 2103 2010-11-09 16:02:21Z Raymond_Benc $
 */
class Poll_Component_Controller_View extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{
		Phpfox::getUserParam('poll.can_access_polls', true);	
	
		(($sPlugin = Phpfox_Plugin::get('poll.component_controller_view_process_start')) ? eval($sPlugin) : false);

		// there are times when this controller is actually called
		// in the Poll_Component_Controller_Profile like when the poll
		// is in the profile
		$sSuffix = '_' . Phpfox::getParam('poll.poll_max_image_pic_size');

		$iPage = $this->request()->getInt('page', 0);
		$iPageSize = 10;

		// we need to make sure we're getting the
		if (!($sPoll = $this->request()->get('req3')))
		{
			$this->url()->send('poll');
		}

		// we need to load one poll
		$aPoll = Phpfox::getService('poll')->getPollByUrl($sPoll, $iPage, $iPageSize);
		Phpfox::getLib('pager')->set(array('ajax'=> 'poll.pageVotes', 'page' => 0, 'size' => Phpfox::getParam('poll.show_x_users_who_took_poll'), 'count' => $aPoll['total_votes']));
		
		if ($aPoll === false)
		{
			return Phpfox_Error::display('Not a valid poll.');
		}
		// set if we can show the poll results
			// is guest the owner of the poll
			$bIsOwner = $aPoll['user_id'] == Phpfox::getUserId();
			$bShowResults = false;
			if ($bIsOwner && Phpfox::getUserParam('poll.can_view_user_poll_results_own_poll') ||
				(!$bIsOwner && Phpfox::getUserParam('poll.can_view_user_poll_results_other_poll'))
			)
			{
				$bShowResults = true;
			}
			$this->template()->assign(array('bShowResults' => $bShowResults));
			
		$aUser = $this->getParam('aUser');

		if ($aUser['user_id'] != $aPoll['user_id'])
		{
			return Phpfox_Error::display('Not a valid poll.');
		}

		if ($aPoll['view_id'] == 1)
		{
			if ((!Phpfox::getUserParam('poll.poll_can_moderate_polls') && $aPoll['user_id'] != Phpfox::getUserId()))
			{
				return Phpfox_Error::display(Phpfox::getPhrase('poll.unable_to_view_this_poll'));
			}

			if ($sModerate = $this->request()->get('moderate'))
			{
				Phpfox::getUserParam('poll.poll_can_moderate_polls', true);
				switch ($sModerate)
				{
					case 'approve':
						if (Phpfox::getService('poll.process')->moderatePoll($aPoll['poll_id'], 0))
						{
							$this->url()->send($aUser['user_name'], array('poll', $aPoll['question_url']), Phpfox::getPhrase('poll.poll_successfully_approved'));
						}
						break;
					default:
						break;
				}
			}
		}

		// check if user has permission to view this item
		if ($aPoll['privacy'] == 4)
		{
			Phpfox::getService('privacy')->verify('poll', $aPoll['poll_id'], Phpfox::getUserId(), true);
		}

		if ($aPoll['privacy'] == 3 && $aPoll['user_id'] != Phpfox::getUserId() && !Phpfox::getService('friend')->isfriend((int) $aPoll['user_id'], Phpfox::getUserId()))
		{
			Phpfox::getLib('url')->send('friend.request', array('id' => $aPoll['user_id']));
		}

		// Track users
		if (Phpfox::isModule('track') && Phpfox::isUser() && (Phpfox::getUserId() != $aPoll['user_id']) && !$aPoll['poll_is_viewed'] && !Phpfox::getUserBy('is_invisible'))
		{
			Phpfox::getService('track.process')->add('poll', $aPoll['poll_id']);
			Phpfox::getService('poll.process')->updateView($aPoll['poll_id']);
		}
	
		if (Phpfox::isUser() && Phpfox::isModule('track') && Phpfox::getUserId() != $aPoll['user_id'] && $aPoll['poll_is_viewed'] && !Phpfox::getUserBy('is_invisible'))
		{
			Phpfox::getService('track.process')->update('poll_track', $aPoll['poll_id']);	
		}	
		
		// check editing permissions		
		$aPoll['bCanEdit'] = Phpfox::getService('poll')->bCanEdit($aPoll['user_id']);
		
		if (Phpfox::isModule('notification') && $aPoll['user_id'] == Phpfox::getUserId())
		{
			Phpfox::getService('notification.process')->delete('poll_notifyLike', $aPoll['poll_id'], Phpfox::getUserId());
		}				
		
		// Define params for "review views" block tracker
		$this->setParam(array(
				'sTrackType' => 'poll',
				'iTrackId' => $aPoll['poll_id'],
				'iTrackUserId' => $aPoll['user_id'],
				'aPoll' => $aPoll
			)
		);		

		$this->template()->setTitle($aPoll['question'])
			->setTitle(Phpfox::getPhrase('poll.polls'))
			->setBreadcrumb(Phpfox::getPhrase('poll.polls'), $this->url()->makeUrl('poll'))
			->setBreadcrumb($aPoll['question'], null, true)
			->setMeta('keywords', $this->template()->getKeywords($aPoll['question']))
			->setMeta('description',  Phpfox::getPhrase('poll.full_name_s_poll_from_time_stamp_question', array(
						'full_name' => $aUser['full_name'],
						'time_stamp' => Phpfox::getTime(Phpfox::getParam('core.description_time_stamp'), $aPoll['time_stamp']),
						'question' => $aPoll['question']
					)
				)
			)
			->setMeta('description', Phpfox::getParam('poll.poll_meta_description'))
			->setMeta('keywords', Phpfox::getParam('poll.poll_meta_keywords'))		
			->setHeader('cache', array(
					'jquery/plugin/jquery.highlightFade.js' => 'static_script',
					'jquery/plugin/jquery.scrollTo.js' => 'static_script',
					'quick_edit.js' => 'static_script',
					'comment.css' => 'style_css',
					'pager.css' => 'style_css',
					'poll.css' => 'module_poll'
					
			)
		)->setEditor(array(
				'load' => 'simple'
			)
		)->assign(array(
					'bIsViewingPoll' => true,
					'aPoll' => $aPoll,
					'sSuffix' => $sSuffix
			)
		);
		
		if (isset($aPoll['answer']) && is_array($aPoll['answer']))
		{
			foreach ($aPoll['answer'] as $aAnswer)
			{
				$this->template()->setMeta('keywords', $this->template()->getKeywords($aAnswer['answer']));
			}
		}

		(($sPlugin = Phpfox_Plugin::get('poll.component_controller_view_process_end')) ? eval($sPlugin) : false);
	}

	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('poll.component_controller_view_clean')) ? eval($sPlugin) : false);
	}
}

?>