<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Privacy
 * @version 		$Id: privacy.class.php 1496 2010-03-05 17:15:05Z Raymond_Benc $
 */
class Privacy_Service_Privacy extends Phpfox_Service 
{
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('privacy');
	}
	
	public function get($sCategory, $iItemId)
	{
		(($sPlugin = Phpfox_Plugin::get('privacy.service_privacy_get')) ? eval($sPlugin) : false);
		
		$aRows = $this->database()->select(Phpfox::getUserField())
			->from($this->_sTable, 'privacy')
			->join(Phpfox::getT('user'), 'u', 'u.user_id = privacy.user_id')
			->where("item_id = " . (int) $iItemId . " AND category_id = '" . $this->database()->escape($sCategory) . "'")
			->execute('getSlaveRows');		
		
		return $aRows;
	}
	
	/**
	 * Verify if a user is allowed to view a private item (eg. blog, photo etc...)
	 *
	 * @param string $sCategory Is the module name
	 * @param int $iItemId Is the item unique ID#
	 * @param int $iUserId Is the items users ID#
	 * @param bool $bRedirect Option to redirect on failure
	 * @return bool Return true if user can view the item, or false on failure
	 */
	public function verify($sCategory, $iItemId, $iUserId, $bRedirect = true)
	{
		$iCnt = 0;
		if (Phpfox::getUserParam('core.can_view_private_items'))
		{
			$iCnt = 1;
		}		
		
		if (!Phpfox::getUserId())
		{
			$iCnt = 0;
		}		

		if ($iCnt === 0)
		{
			$iCnt = $this->database()->select('COUNT(*)')
				->from($this->_sTable)
				->where("item_id = " . (int) $iItemId . " AND category_id = '" . $this->database()->escape($sCategory) . "' AND user_id = " . Phpfox::getUserId() . "")
				->execute('getSlaveField');
		}		
		
		if ((int) $iCnt === 0)
		{			
			if ($bRedirect)
			{				
				Phpfox::getLib('url')->send('privacy.invalid');
			}
			
			return false;
		}
		
		return true;
	}

	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('privacy.service_privacy__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}
}

?>