<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Quiz
 * @version 		$Id: index.class.php 1599 2010-05-28 04:31:26Z Raymond_Benc $
 */
class Quiz_Component_Controller_Index extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{
		Phpfox::getUserParam('quiz.can_access_quiz', true);
		
		if (($iRedirect = $this->request()->getInt('redirect')) && ($sUrl = Phpfox::getService('quiz.callback')->getFeedRedirect($iRedirect)))
		{
			$this->url()->forward($sUrl);
		}
		
		/*
		 * This controller handles viewing quizzes in a profile and in the main quiz section
		 * So we have 2 conditions, if its a profile then filter out according to the privacy
		 * settings. If its the main section just show every public quiz.
		 */
		
		$iPage = $this->request()->getInt('page');
		$iPageSize = (int)Phpfox::getParam('quiz.quizzes_to_show');
		// general conditions array
		$aCond = array();
		// who is viewing
		$iGuest = (Phpfox::isUser() ? Phpfox::getUserId() : false);
		$iOwner = false;
		// first case: viewing a profile
		if ($this->getParam('bIsProfile') === true)
		{			
			$aUser = $this->getParam('aUser');
			$iOwner =  $aUser['user_id'];
			$aCond[] = 'q.user_id = ' . $iOwner;
			// Check if this user can approve
			if (!Phpfox::getUserParam('quiz.can_approve_quizzes'))
			{
				$aCond[] = ' AND (q.view_id = 0 OR (q.view_id = 1 AND q.user_id = '.Phpfox::getUserId().'))';
			}
		}
		else
		{			
			// if its not a profile then its the main section and we need only the public quizzes
			if (!Phpfox::getUserParam('quiz.can_approve_quizzes'))
			{
				$aCond[] = 'AND q.view_id = 0';
			}
		}
		
		if ($this->request()->get('view') == 'approval' && Phpfox::getUserParam('quiz.can_approve_quizzes'))
		{
			$aCond[] = 'AND q.view_id = 1';
		}
		
		list($iCnt, $aQuizzes) = Phpfox::getService('quiz')->get($aCond, $iPage, $iPageSize);
		
		Phpfox::getLib('pager')->set(array('page' => $iPage, 'size' => $iPageSize, 'count' => $iCnt));
		
		foreach ($aQuizzes as $aQuiz)
		{
			$this->template()->setMeta('keywords', $this->template()->getKeywords($aQuiz['title']));
		}

		$this->template()->setTitle((defined('PHPFOX_IS_USER_PROFILE') ? Phpfox::getPhrase('quiz.full_name_s_quizzes', array('full_name' => $aUser['full_name'])) : Phpfox::getPhrase('quiz.quizzes')))
			->setBreadcrumb((defined('PHPFOX_IS_USER_PROFILE') ? Phpfox::getPhrase('quiz.full_name_s_quizzes', array('full_name' => $aUser['full_name'])) : Phpfox::getPhrase('quiz.quizzes')), (defined('PHPFOX_IS_USER_PROFILE') ? $this->url()->makeUrl($aUser['user_name'], 'quiz') : $this->url()->makeUrl('quiz')))
			->setMeta('keywords', Phpfox::getParam('quiz.quiz_meta_keywords'))
			->setMeta('description', Phpfox::getParam('quiz.quiz_meta_description'))
			->setHeader('cache', array(
					'pager.css' => 'style_css',
					'quiz.js' => 'module_quiz',				
					'jquery/plugin/jquery.highlightFade.js' => 'static_script',	
				)
			)
			->setPhrase(array(
					'quiz.are_you_sure_you_want_to_delete_this_quiz'
				)
			)			
			->assign(array(
				'aQuizzes' => $aQuizzes,
				'sSuffix' =>  '_' . Phpfox::getParam('quiz.quiz_max_image_pic_size'),
				'bIsProfile' => (defined('PHPFOX_IS_USER_PROFILE') && PHPFOX_IS_USER_PROFILE) ? true : false
			)

		);
	}
	
	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('quiz.component_controller_index_clean')) ? eval($sPlugin) : false);
	}
}

?>