<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package  		Module_Video
 * @version 		$Id: index.class.php 2567 2011-04-27 09:48:50Z Miguel_Espinoza $
 */
class Video_Component_Controller_Index extends Phpfox_Component
{
	/**
	 * Class process method wnich is used to execute this component.
	 */
	public function process()
	{		
		Phpfox::getUserParam('video.can_access_videos', true);
		
		if (($iRedirectId = $this->request()->getInt('redirect'))
			&& ($aVideo = Phpfox::getService('video')->getVideo($iRedirectId, true))
			&& $aVideo['module_id'] != 'video'
			&& Phpfox::hasCallback($aVideo['module_id'], 'getVideoRedirect')
		)
		{
			if (($sForward = Phpfox::callback($aVideo['module_id'] . '.getVideoRedirect', $aVideo['video_id'])))
			{	
				$this->url()->forward($sForward);
			}
		}
		
		if (($iRedirectId = $this->request()->getInt('redirect')) && ($aVideo = Phpfox::getService('video')->getVideo($iRedirectId, true)))
		{
			$this->url()->send($aVideo['user_name'], array('video', $aVideo['title_url']));
		}
		
		if (($iDeleteId = $this->request()->getInt('delete')))
		{
			if (Phpfox::getService('video.process')->delete($iDeleteId))
			{
				$this->url()->send('video', null, Phpfox::getPhrase('video.video_successfully_deleted'));
			}
		}
		
		$oServiceVideoBrowse = Phpfox::getService('video.browse');
		$iPage = $this->request()->get('page');
		$sView = $this->request()->get('view');
		$sCategory = null;		
		$aCallback = $this->getParam('aCallback', false);		
		$iRequestCount = 0;	
		$this->setParam('sTagType', 'video');
		
		$aPages = array(12, 15, 18, 21);
		$aDisplays = array();
		foreach ($aPages as $iPageCnt)
		{
			$aDisplays[$iPageCnt] = Phpfox::getPhrase('core.per_page', array('total' => $iPageCnt));
		}		
	
		$aFilters = array(
			'display' => array(
				'type' => 'select',
				'options' => $aDisplays,
				'default' => '12'
			),
			'sort' => array(
				'type' => 'select',
				'options' => array(
					'time_stamp' => Phpfox::getPhrase('video.date_added'),
					'total_score' => Phpfox::getPhrase('video.popular'),
					'total_comment' => Phpfox::getPhrase('video.most_discussed'),
					'total_view' => Phpfox::getPhrase('video.most_viewed')
				),
				'default' => 'time_stamp',
				'alias' => 'm'
			),
			'sort_by' => array(
				'type' => 'select',
				'options' => array(
					'DESC' => Phpfox::getPhrase('core.descending'),
					'ASC' => Phpfox::getPhrase('core.ascending')
				),
				'default' => 'DESC'
			),
			'keyword' => array(
				'type' => 'input:text',
				'size' => 20,
				'search' => 'AND m.title LIKE \'%[VALUE]%\''
			)		
		);
		
		$oFilter = Phpfox::getLib('search')
			->set(array(
				'type' => 'browse',
				'filters' => $aFilters,
				'search' => 'keyword',
				'prepare' => false
			)
		);			
		
		if (defined('PHPFOX_IS_USER_PROFILE'))
		{
			$aUser = $this->getParam('aUser');
			
			$oFilter->setCondition('AND m.in_process = 0 AND m.view_id ' . ((Phpfox::getUserParam('video.can_approve_videos') || $aUser['user_id'] == Phpfox::getUserId()) ? 'IN(0,2)' : '= 0') . ' AND m.user_id = ' . (int) $aUser['user_id']);
		}
		else if (defined('PHPFOX_GROUP_VIEW'))
		{
			$oFilter->setCondition('AND m.in_process = 0 AND m.module_id = "group" ');
		}
		else
		{
			$oFilter->setCondition('AND m.in_process = 0 AND m.view_id ' . (Phpfox::getUserParam('video.can_approve_videos') ? 'IN(0,2)' : '= 0') . ' AND m.module_id = \'' . ($aCallback !== false ? $aCallback['module'] : 'video') . '\' AND m.item_id = ' . ($aCallback !== false ? (int) $aCallback['item'] : 0));
		}
		
		switch ($sView)
		{
			case 'featured':
				$oFilter->setCondition('AND m.is_featured = 1');
				break;
			case 'most-viewed':
				$oFilter->setSort('total_view');
				$oFilter->setCondition('AND m.total_view > 0');
				break;
			case 'popular':
				$oFilter->setSort('total_score');
				$oFilter->setCondition('AND m.total_score > 0');
				break;
			case 'most-discussed':
				$oFilter->setSort('total_comment');
				$oFilter->setCondition('AND m.total_comment > 0');
				break;
			case 'spotlight':
				$oFilter->setCondition('AND m.is_spotlight = 1');
				break;
			case 'pending':
				if (Phpfox::getUserParam('video.can_approve_videos'))
				{
					$oFilter->setCondition('AND m.view_id = 2');
				}
				break;
			default:
				
				break;
		}
		
		$aRequests = $this->request()->getRequests();		
		$sCategoryUrl = '';	
		foreach ($aRequests as $sKey => $sValue)
		{			
			if (!preg_match("/req[0-9]/", $sKey))
			{
				continue;
			}
			
			$iRequestCount++;			
			
			if ($iRequestCount < ($aCallback !== false ? $aCallback['category_request'] : 3))
			{
				continue;
			}		
			
			$this->url()->setParam($sKey, $sValue);
			
			$sCategory = $sValue;
			$sCategoryUrl .= '.' . $sValue;
		}				
		
		$sTagSearchValue = null;
		if (defined('PHPFOX_GROUP_VIEW') || defined('PHPFOX_IS_GROUP_VIEW'))
		{
			$sCategory = null;
			$sCategoryUrl = '';
			$sTagSearchValue = $this->request()->get('req5');
			$aGroup = $this->getParam('aGroup');
			$oFilter->setCondition('AND m.item_id = ' . $aGroup['group_id']);
		}
		else if ($this->request()->get('req2') == 'tag' && $this->request()->get('req3'))
		{
			$sCategory = null;
			$sCategoryUrl = '';
			$sTagSearchValue = $this->request()->get('req3');
		}
		
		$this->setParam('sCategory', $sCategory);
		if ($this->request()->getInt('sponsor') == 1)
		{
		    $oFilter->setCondition('AND m.is_sponsor != 1');
		    Phpfox::addMessage(Phpfox::getPhrase('video.sponsor_help'));
		}
		
		if(defined('PHPFOX_IS_GROUP_VIEW'))
		{
			$oServiceVideoBrowse->condition($oFilter->getConditions())
			->callback($aCallback)
			->order($oFilter->getSort())
			/* Change in the following two lines due to http://www.phpfox.com/tracker/view/6195/*/
			->category($sTagSearchValue)
			//->tag()
			->page($iPage)
			->size($oFilter->getDisplay())
			->execute();	
		}
		else
		{
		
			$oServiceVideoBrowse->condition($oFilter->getConditions())
			->callback($aCallback)
			->order($oFilter->getSort())
			->category($sCategory)
			->tag($sTagSearchValue)
			->page($iPage)
			->size($oFilter->getDisplay())
			->execute();		
		}	
		Phpfox::getLib('pager')->set(array('page' => $iPage, 'size' => $oFilter->getDisplay(), 'count' => $oFilter->getSearchTotal($oServiceVideoBrowse->getCount())));
		
		$iFilterCount = 0;
		$aFilterMenuCache = array();
		if ($aCallback === false && !defined('PHPFOX_IS_USER_PROFILE'))
		{
			$aFilterMenu = array(
				Phpfox::getPhrase('video.recent_videos') => '',
				Phpfox::getPhrase('video.featured') => 'featured',
				Phpfox::getPhrase('video.most_viewed') => 'most-viewed',
				Phpfox::getPhrase('video.popular') => 'popular',
				Phpfox::getPhrase('video.most_discussed') => 'most-discussed',
				Phpfox::getPhrase('video.spotlight') => 'spotlight'
			);
			
			if (Phpfox::getUserParam('video.can_approve_videos'))
			{
				$aFilterMenu[Phpfox::getPhrase('video.pending')] = 'pending';
			}			
			
			foreach ($aFilterMenu as $sMenuName => $sMenuLink)
			{
				$iFilterCount++;
				$aFilterMenuCache[] = array(
					'name' => $sMenuName,
					'link' => $this->url()->makeUrl('video' . (empty($sCategoryUrl) ? '' : '.category' . $sCategoryUrl), array('view' => $sMenuLink)),
					'active' => ($sView == $sMenuLink ? true : false),
					'last' => (count($aFilterMenu) === $iFilterCount ? true : false)
				);	
				
				if ($sView == $sMenuLink)
				{
					$this->template()->setTitle($sMenuName)->setBreadcrumb($sMenuName, null, true);
				}
			}	
			
			if (empty($sView))
			{				
				$this->template()->setTitle(Phpfox::getPhrase('video.recent_videos'))->setBreadcrumb(Phpfox::getPhrase('video.recent_videos'), null, true);
			}
		}
		
		$aSpotlightVideo = Phpfox::getService('video')->getSpotlight();
		$this->setParam('aSpotlightVideo', $aSpotlightVideo);

		if (defined('PHPFOX_IS_USER_PROFILE'))
		{
			$this->template()->setMeta('description', Phpfox::getPhrase('video.full_name_s_videos_full_name_has_total_video_s' , array('full_name' => $aUser['full_name'], 'total' => $oServiceVideoBrowse->getCount())));
		}
		
		$this->template()->setTitle((defined('PHPFOX_IS_USER_PROFILE') ? Phpfox::getPhrase('video.full_name_s_videos', array('full_name' => $aUser['full_name'])) : Phpfox::getPhrase('video.videos')))
			->setBreadcrumb((defined('PHPFOX_IS_USER_PROFILE') ? Phpfox::getPhrase('video.full_name_s_videos', array('full_name' => $aUser['full_name'])) : Phpfox::getPhrase('video.videos')), (defined('PHPFOX_IS_USER_PROFILE') ? $this->url()->makeUrl($aUser['user_name'], 'video') : ($aCallback === false ? $this->url()->makeUrl('video') : $this->url()->makeUrl($aCallback['url_home'][0], array_merge($aCallback['url_home'][1], array('video'))))))
			->setMeta('keywords', Phpfox::getParam('video.video_meta_keywords'))
			->setMeta('description', Phpfox::getParam('video.video_meta_description'))
			->setHeader('cache', array(
					'pager.css' => 'style_css',
					'video.js' => 'module_video',
					'video.css' => 'module_video'
				)
			)
			->assign(array(
					'aVideos' => $oServiceVideoBrowse->get(),
					'sParentLink' => ($aCallback !== false ? $aCallback['url_home'][0] . '.' . implode('.', $aCallback['url_home'][1]) . '.video' : 'video'),
					'aCallback' => $aCallback,
					'aFilterMenus' => $aFilterMenuCache,
					'sCategoryUrl' => $sCategoryUrl,
					'sValue' => $sValue,
					'aSpotlightVideo' => $aSpotlightVideo,
					'iVideoApproveCnt' => (Phpfox::getUserParam('video.can_approve_videos') ? Phpfox::getService('video')->getPendingTotal() : 0),
					'sLinkPendingVideos' => $this->url()->makeUrl('video.pending'),
					'sView' => $sView,
					'sPublicPhotoView' => $sView
				)
			);
			
		if ($aSpotlightVideo !== false)
		{
			$this->template()->setHeader(array(
					'player/' . Phpfox::getParam('core.default_music_player') . '/phpfox.js' => 'static_script',
					'<script type="text/javascript">$(function() { Phpfox.player.load({id: \'js_video_player\', auto: false, type: \'video\', play: \'' . (preg_match("/\{file\/videos\/(.*)\/(.*)\.flv\}/i", $aSpotlightVideo['destination'], $aMatches) ? Phpfox::getParam('core.path') . str_replace(array('{', '}'), '', $aMatches[0]) : Phpfox::getParam('video.url') . $aSpotlightVideo['destination']) . '\'}); });</script>'
				)
			);
		}
			
		if ($sCategory !== null)
		{
			$aCategories = Phpfox::getService('video.category')->getParentBreadcrumb($sCategory);
			$iCnt = 0;
			foreach ($aCategories as $aCategory)
			{
				$iCnt++;
				
				$this->template()->setTitle($aCategory[0]);					

				if ($aCallback !== false)
				{
					$sHomeUrl = '/' . $aCallback['url_home'][0] . '/' . implode('/', $aCallback['url_home'][1]) . '/video/';
					$aCategory[1] = preg_replace('/^http:\/\/(.*?)\/video\/(.*?)$/i', 'http://\\1' . $sHomeUrl . '\\2', $aCategory[1]);
				}

				$this->template()->setBreadcrumb($aCategory[0], $aCategory[1], ($iCnt === count($aCategories) ? true : false));
			}			
		}			
			
		if ($aCallback !== false)
		{
			$this->template()->rebuildMenu('video.index', $aCallback['url_home']);
		}
		
		foreach ($oServiceVideoBrowse->get() as $aVideo)
		{
			$this->template()->setMeta('keywords', $this->template()->getKeywords($aVideo['title']));
		}
		
		if (!empty($sTagSearchValue))
		{
			$this->template()->setBreadcrumb(Phpfox::getPhrase('video.tags'), $this->url()->makeUrl('video'));
			$this->template()->setBreadcrumb($sTagSearchValue, null, true);
		}
	}
	
	/**
	 * Garbage collector. Is executed after this class has completed
	 * its job and the template has also been displayed.
	 */
	public function clean()
	{
		(($sPlugin = Phpfox_Plugin::get('video.component_controller_index_clean')) ? eval($sPlugin) : false);
	}
}

?>