<?php
/**
 * [PHPFOX_HEADER]
 */

defined('PHPFOX') or exit('NO DICE!');

/**
 * 
 * 
 * @copyright		[PHPFOX_COPYRIGHT]
 * @author  		Raymond Benc
 * @package 		Phpfox_Service
 * @version 		$Id: browse.class.php 414 2009-04-17 23:31:59Z Raymond_Benc $
 */
class Video_Service_Browse extends Phpfox_Service 
{
	private $_aConditions = array();
	
	private $_iCnt = 0;
	
	private $_iPage = 0;
	
	private $_iPageSize = 25;
	
	private $_sOrder = 'm.is_featured DESC, m.time_stamp DESC';
	
	private $_aRows = array();
	
	private $_sCategory = null;	
	
	private $_aCallback = false;
	
	private $_sTag = null;
	
	private $_bFull = false;
	
	/**
	 * Class constructor
	 */	
	public function __construct()
	{	
		$this->_sTable = Phpfox::getT('video');
	}
	
	public function condition($aConditions)
	{
		$this->_aConditions = $aConditions;
		
		return $this;
	}
	
	public function page($iPage)
	{
		$this->_iPage = $iPage;
		
		return $this;
	}
	
	public function size($iPageSize)
	{
		$this->_iPageSize = $iPageSize;
		
		return $this;
	}
	
	public function category($sCategory)
	{
		$this->_sCategory = $sCategory;
		
		return $this;
	}
	
	public function callback($aCallback)
	{
		$this->_aCallback = $aCallback;
		
		return $this;
	}
	
	public function order($sOrder)
	{		
		if ($sOrder != 'm.time_stamp DESC')
		{		
			$this->_sOrder = $sOrder;
		}
		
		return $this;
	}
	
	public function tag($sTag)
	{
		$this->_sTag = $sTag;
		
		return $this;
	}
	
	public function full($bFull)
	{
		$this->_bFull = $bFull;
		
		return $this;
	}
	
	public function execute()
	{
		if ($this->_sCategory !== null)
		{
			$sCategories = Phpfox::getService('video.category')->getAllCategories($this->_sCategory);
		
			$this->database()->innerJoin(Phpfox::getT('video_category_data'), 'mcd', 'mcd.video_id = m.video_id');
			
			$this->_aConditions[] = ' AND mcd.category_id IN(' . $sCategories . ')';
		}		
		
		if ($this->_sTag != null)
		{
			//$this->database()->innerJoin(Phpfox::getT('tag'), 'tag', 'tag.item_id = m.video_id AND tag.category_id = \'video\' AND tag.tag_url = \'' . $this->database()->escape($this->_sTag) . '\'')->group('m.video_id');
			$this->database()->innerJoin(Phpfox::getT('tag'), 'tag', 'tag.item_id = m.video_id AND tag.category_id = \''.(defined('PHPFOX_GROUP_VIEW') ? 'video_group' : 'video').'\' AND tag.tag_url = \'' . $this->database()->escape($this->_sTag) . '\'')->group('m.video_id');
		}		

		if ($this->_sCategory !== null || $this->_sTag !== null)
		{
			$aVideos = $this->database()->select('DISTINCT m.video_id')
				->from($this->_sTable, 'm')
				->where($this->_aConditions)
				->execute('getSlaveRows');
			$this->_iCnt = count($aVideos);
		}
		else
		{
			$this->_iCnt = $this->database()->select((($this->_sCategory !== null || $this->_sTag !== null) ? 'COUNT(DISTINCT m.video_id)' : 'COUNT(*)'))
			->from($this->_sTable, 'm')
			->where($this->_aConditions)
			->execute('getSlaveField');
		}
		
		if ($this->_iCnt)
		{
			if ($this->_sCategory !== null)
			{			
				$this->database()->innerJoin(Phpfox::getT('video_category_data'), 'mcd', 'mcd.video_id = m.video_id')->group('m.video_id');
			}			
			
			if ($this->_sTag != null)
			{
				$this->database()->innerJoin(Phpfox::getT('tag'), 'tag', 'tag.item_id = m.video_id AND tag.category_id = \''.(defined('PHPFOX_GROUP_VIEW') ? 'video_group' : 'video').'\' AND tag.tag_url = \'' . $this->database()->escape($this->_sTag) . '\'')->group('m.video_id');
			}
			
			if ($this->_bFull === true)
			{
				$this->database()->select('vt.text_parsed AS text, ')->leftJoin(Phpfox::getT('video_text'), 'vt', 'vt.video_id = m.video_id');
			}
			
			$this->_aRows = $this->database()->select('m.*, ' . Phpfox::getUserField())
				->from($this->_sTable, 'm')
				->join(Phpfox::getT('user'), 'u', 'u.user_id = m.user_id')
				->where($this->_aConditions)
				->order($this->_sOrder)
				->limit($this->_iPage, $this->_iPageSize, $this->_iCnt)
				->execute('getSlaveRows');
			
			foreach ($this->_aRows as $iKey => $aRow)
			{				
				if ($this->_aCallback === false && $aRow['module_id'] != 'video')
				{
					$this->_aRows[$iKey]['link'] = Phpfox::getLib('url')->makeUrl('video', array('redirect' => $aRow['video_id']));
				}
				else 
				{
					$this->_aRows[$iKey]['link'] = ($this->_aCallback !== false ? Phpfox::getLib('url')->makeUrl($this->_aCallback['url'][0], array_merge($this->_aCallback['url'][1], array($aRow['title_url']))) : Phpfox::getService('video')->makeUrl($aRow['user_name'], $aRow['title_url']));
				}
			}
		}		
	}	
		
	public function get()
	{
		return $this->_aRows;
	}

	public function getCount()
	{
		return $this->_iCnt;
	}	
	
	/**
	 * If a call is made to an unknown method attempt to connect
	 * it to a specific plug-in with the same name thus allowing 
	 * plug-in developers the ability to extend classes.
	 *
	 * @param string $sMethod is the name of the method
	 * @param array $aArguments is the array of arguments of being passed
	 */
	public function __call($sMethod, $aArguments)
	{
		/**
		 * Check if such a plug-in exists and if it does call it.
		 */
		if ($sPlugin = Phpfox_Plugin::get('video.service_browse__call'))
		{
			return eval($sPlugin);
		}
			
		/**
		 * No method or plug-in found we must throw a error.
		 */
		Phpfox_Error::trigger('Call to undefined method ' . __CLASS__ . '::' . $sMethod . '()', E_USER_ERROR);
	}	
}

?>